Coverage for cuda/bindings/_internal/runtime.pyx: 60.00%
1630 statements
« prev ^ index » next coverage.py v7.16.2, created at 2026-10-16 01:23 +0000
« prev ^ index » next coverage.py v7.16.2, created at 2026-10-16 01:23 +0000
1# SPDX-FileCopyrightText: Copyright (c) 2021-2026 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
2#
3# SPDX-License-Identifier: Apache-2.0
4#
5# This code was automatically generated across versions from 12.9.0 to 13.4.1. Do not modify it directly.
7# CYTHON-BINDINGS-GENERATED-DO-NOT-MODIFY-THIS-FILE: format=1; content-sha256=8a9a7693abb19d9b8586773190de738ea06eff697d16683a49ce67bfa4426788
8import os
10from libc.stdint cimport uintptr_t
12from cuda.pathfinder import load_nvidia_dynamic_lib
13cimport cuda.bindings._lib.dlfcn as dlfcn
14cimport cuda.bindings._internal.runtime_ptds as ptds
15cimport cython
18###############################################################################
19# Per-thread default stream dispatch
20###############################################################################
22cdef bint __cudaPythonInit = False
23cdef bint __usePTDS = False
25cdef int _cudaPythonInit() except -1 nogil:
26 global __cudaPythonInit
27 global __usePTDS
28 with gil:
29 __usePTDS = bool(int(os.getenv('CUDA_PYTHON_CUDA_PER_THREAD_DEFAULT_STREAM', default=0)))
30 __cudaPythonInit = True
31 return __usePTDS
33cdef inline int cudaPythonInit() except -1 nogil:
34 if __cudaPythonInit: 2a R S T U m cbV dbW X } ebY Z 0 I u e J n v w s K Q fb~ L x y gbt f d z o l g p j b h k i q A B C D F E 1 c hbibM 2 jbkblbmb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H N @ [ O P ] ab^ _ ` { | r
35 return __usePTDS 2a R S T U m cbV dbW X } ebY Z 0 I u e J n v w s K Q fb~ L x y gbt f d z o l g p j b h k i q A B C D F E 1 c hbibM 2 jbkblbmb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H N @ [ O P ] ab^ _ ` { | r
36 return _cudaPythonInit()
39###############################################################################
40# EGL/GL/VDPAU helpers (implementations delegating to driver EGL/VDPAU/GL APIs)
41###############################################################################
43include "../_lib/cyruntime/cyruntime.pxi"
46###############################################################################
47# getLocalRuntimeVersion — dynamically loads cudart to read its own version
48###############################################################################
50cdef cudaError_t _getLocalRuntimeVersion(int* runtimeVersion) except ?cudaErrorCallRequiresNewerDriver nogil:
51 # Load cudart dynamically to read its embedded version number.
52 with gil: 2bb
53 loaded_dl = load_nvidia_dynamic_lib("cudart") 2bb
54 handle = <void *><uintptr_t>loaded_dl._handle_uint 2bb
56 cdef void* __cudaRuntimeGetVersion = dlfcn.dlsym(handle, 'cudaRuntimeGetVersion') 2bb
58 if __cudaRuntimeGetVersion == NULL: 2bb
59 with gil:
60 raise RuntimeError(f'Function "cudaRuntimeGetVersion" not found in {loaded_dl.abs_path}')
62 # We explicitly do *NOT* cleanup the library handle here, acknowledging
63 # that, yes, the handle leaks. The reason is that there's a
64 # `functools.cache` on the top-level caller of this function.
65 #
66 # This means this library would be opened once and then immediately closed,
67 # all the while remaining in the cache lurking there for people to call.
68 #
69 # Since we open the library one time (technically once per unique library name),
70 # there's not a ton of leakage, which we deem acceptable for the 1000x speedup
71 # achieved by caching (ultimately) `ctypes.CDLL` calls.
72 #
73 # Long(er)-term we can explore cleaning up the library using higher-level
74 # Python mechanisms, like `__del__` or `weakref.finalizer`s.
76 cdef cudaError_t err = cudaSuccess 2bb
77 err = (<cudaError_t (*)(int*) except ?cudaErrorCallRequiresNewerDriver nogil> __cudaRuntimeGetVersion)(runtimeVersion) 2bb
78 return err 2bb
81###############################################################################
82# C function declarations for static cudart (avoids infinite recursion through
83# the same-named Cython wrappers imported via `from ..cyruntime cimport *`)
84###############################################################################
86cdef extern from 'cuda_runtime_api.h' nogil:
87 cudaError_t _static_cudaDeviceReset "cudaDeviceReset" () noexcept
89cdef extern from 'cuda_runtime_api.h' nogil:
90 cudaError_t _static_cudaDeviceSynchronize "cudaDeviceSynchronize" () noexcept
92cdef extern from 'cuda_runtime_api.h' nogil:
93 cudaError_t _static_cudaDeviceSetLimit "cudaDeviceSetLimit" (cudaLimit limit, size_t value) noexcept
95cdef extern from 'cuda_runtime_api.h' nogil:
96 cudaError_t _static_cudaDeviceGetLimit "cudaDeviceGetLimit" (size_t* pValue, cudaLimit limit) noexcept
98cdef extern from 'cuda_runtime_api.h' nogil:
99 cudaError_t _static_cudaDeviceGetTexture1DLinearMaxWidth "cudaDeviceGetTexture1DLinearMaxWidth" (size_t* maxWidthInElements, const cudaChannelFormatDesc* fmtDesc, int device) noexcept
101cdef extern from 'cuda_runtime_api.h' nogil:
102 cudaError_t _static_cudaDeviceGetCacheConfig "cudaDeviceGetCacheConfig" (cudaFuncCache* pCacheConfig) noexcept
104cdef extern from 'cuda_runtime_api.h' nogil:
105 cudaError_t _static_cudaDeviceGetStreamPriorityRange "cudaDeviceGetStreamPriorityRange" (int* leastPriority, int* greatestPriority) noexcept
107cdef extern from 'cuda_runtime_api.h' nogil:
108 cudaError_t _static_cudaDeviceSetCacheConfig "cudaDeviceSetCacheConfig" (cudaFuncCache cacheConfig) noexcept
110cdef extern from 'cuda_runtime_api.h' nogil:
111 cudaError_t _static_cudaDeviceGetByPCIBusId "cudaDeviceGetByPCIBusId" (int* device, const char* pciBusId) noexcept
113cdef extern from 'cuda_runtime_api.h' nogil:
114 cudaError_t _static_cudaDeviceGetPCIBusId "cudaDeviceGetPCIBusId" (char* pciBusId, int len, int device) noexcept
116cdef extern from 'cuda_runtime_api.h' nogil:
117 cudaError_t _static_cudaIpcGetEventHandle "cudaIpcGetEventHandle" (cudaIpcEventHandle_t* handle, cudaEvent_t event) noexcept
119cdef extern from 'cuda_runtime_api.h' nogil:
120 cudaError_t _static_cudaIpcOpenEventHandle "cudaIpcOpenEventHandle" (cudaEvent_t* event, cudaIpcEventHandle_t handle) noexcept
122cdef extern from 'cuda_runtime_api.h' nogil:
123 cudaError_t _static_cudaIpcGetMemHandle "cudaIpcGetMemHandle" (cudaIpcMemHandle_t* handle, void* devPtr) noexcept
125cdef extern from 'cuda_runtime_api.h' nogil:
126 cudaError_t _static_cudaIpcOpenMemHandle "cudaIpcOpenMemHandle" (void** devPtr, cudaIpcMemHandle_t handle, unsigned int flags) noexcept
128cdef extern from 'cuda_runtime_api.h' nogil:
129 cudaError_t _static_cudaIpcCloseMemHandle "cudaIpcCloseMemHandle" (void* devPtr) noexcept
131cdef extern from 'cuda_runtime_api.h' nogil:
132 cudaError_t _static_cudaDeviceFlushGPUDirectRDMAWrites "cudaDeviceFlushGPUDirectRDMAWrites" (cudaFlushGPUDirectRDMAWritesTarget target, cudaFlushGPUDirectRDMAWritesScope scope) noexcept
134cdef extern from 'cuda_runtime_api.h' nogil:
135 cudaError_t _static_cudaDeviceRegisterAsyncNotification "cudaDeviceRegisterAsyncNotification" (int device, cudaAsyncCallback callbackFunc, void* userData, cudaAsyncCallbackHandle_t* callback) noexcept
137cdef extern from 'cuda_runtime_api.h' nogil:
138 cudaError_t _static_cudaDeviceUnregisterAsyncNotification "cudaDeviceUnregisterAsyncNotification" (int device, cudaAsyncCallbackHandle_t callback) noexcept
140cdef extern from 'cuda_runtime_api.h' nogil:
141 cudaError_t _static_cudaDeviceGetSharedMemConfig "cudaDeviceGetSharedMemConfig" (cudaSharedMemConfig* pConfig) noexcept
143cdef extern from 'cuda_runtime_api.h' nogil:
144 cudaError_t _static_cudaDeviceSetSharedMemConfig "cudaDeviceSetSharedMemConfig" (cudaSharedMemConfig config) noexcept
146cdef extern from 'cuda_runtime_api.h' nogil:
147 cudaError_t _static_cudaGetLastError "cudaGetLastError" () noexcept
149cdef extern from 'cuda_runtime_api.h' nogil:
150 cudaError_t _static_cudaPeekAtLastError "cudaPeekAtLastError" () noexcept
152cdef extern from 'cuda_runtime_api.h' nogil:
153 const char* _static_cudaGetErrorName "cudaGetErrorName" (cudaError_t error) noexcept
155cdef extern from 'cuda_runtime_api.h' nogil:
156 const char* _static_cudaGetErrorString "cudaGetErrorString" (cudaError_t error) noexcept
158cdef extern from 'cuda_runtime_api.h' nogil:
159 cudaError_t _static_cudaGetDeviceCount "cudaGetDeviceCount" (int* count) noexcept
161cdef extern from 'cuda_runtime_api.h' nogil:
162 cudaError_t _static_cudaDeviceGetAttribute "cudaDeviceGetAttribute" (int* value, cudaDeviceAttr attr, int device) noexcept
164cdef extern from 'cuda_runtime_api.h' nogil:
165 cudaError_t _static_cudaDeviceGetDefaultMemPool "cudaDeviceGetDefaultMemPool" (cudaMemPool_t* memPool, int device) noexcept
167cdef extern from 'cuda_runtime_api.h' nogil:
168 cudaError_t _static_cudaDeviceSetMemPool "cudaDeviceSetMemPool" (int device, cudaMemPool_t memPool) noexcept
170cdef extern from 'cuda_runtime_api.h' nogil:
171 cudaError_t _static_cudaDeviceGetMemPool "cudaDeviceGetMemPool" (cudaMemPool_t* memPool, int device) noexcept
173cdef extern from 'cuda_runtime_api.h' nogil:
174 cudaError_t _static_cudaDeviceGetNvSciSyncAttributes "cudaDeviceGetNvSciSyncAttributes" (void* nvSciSyncAttrList, int device, int flags) noexcept
176cdef extern from 'cuda_runtime_api.h' nogil:
177 cudaError_t _static_cudaDeviceGetP2PAttribute "cudaDeviceGetP2PAttribute" (int* value, cudaDeviceP2PAttr attr, int srcDevice, int dstDevice) noexcept
179cdef extern from 'cuda_runtime_api.h' nogil:
180 cudaError_t _static_cudaChooseDevice "cudaChooseDevice" (int* device, const cudaDeviceProp* prop) noexcept
182cdef extern from 'cuda_runtime_api.h' nogil:
183 cudaError_t _static_cudaInitDevice "cudaInitDevice" (int device, unsigned int deviceFlags, unsigned int flags) noexcept
185cdef extern from 'cuda_runtime_api.h' nogil:
186 cudaError_t _static_cudaSetDevice "cudaSetDevice" (int device) noexcept
188cdef extern from 'cuda_runtime_api.h' nogil:
189 cudaError_t _static_cudaGetDevice "cudaGetDevice" (int* device) noexcept
191cdef extern from 'cuda_runtime_api.h' nogil:
192 cudaError_t _static_cudaSetDeviceFlags "cudaSetDeviceFlags" (unsigned int flags) noexcept
194cdef extern from 'cuda_runtime_api.h' nogil:
195 cudaError_t _static_cudaGetDeviceFlags "cudaGetDeviceFlags" (unsigned int* flags) noexcept
197cdef extern from 'cuda_runtime_api.h' nogil:
198 cudaError_t _static_cudaStreamCreate "cudaStreamCreate" (cudaStream_t* pStream) noexcept
200cdef extern from 'cuda_runtime_api.h' nogil:
201 cudaError_t _static_cudaStreamCreateWithFlags "cudaStreamCreateWithFlags" (cudaStream_t* pStream, unsigned int flags) noexcept
203cdef extern from 'cuda_runtime_api.h' nogil:
204 cudaError_t _static_cudaStreamCreateWithPriority "cudaStreamCreateWithPriority" (cudaStream_t* pStream, unsigned int flags, int priority) noexcept
206cdef extern from 'cuda_runtime_api.h' nogil:
207 cudaError_t _static_cudaStreamGetPriority "cudaStreamGetPriority" (cudaStream_t hStream, int* priority) noexcept
209cdef extern from 'cuda_runtime_api.h' nogil:
210 cudaError_t _static_cudaStreamGetFlags "cudaStreamGetFlags" (cudaStream_t hStream, unsigned int* flags) noexcept
212cdef extern from 'cuda_runtime_api.h' nogil:
213 cudaError_t _static_cudaStreamGetId "cudaStreamGetId" (cudaStream_t hStream, unsigned long long* streamId) noexcept
215cdef extern from 'cuda_runtime_api.h' nogil:
216 cudaError_t _static_cudaStreamGetDevice "cudaStreamGetDevice" (cudaStream_t hStream, int* device) noexcept
218cdef extern from 'cuda_runtime_api.h' nogil:
219 cudaError_t _static_cudaCtxResetPersistingL2Cache "cudaCtxResetPersistingL2Cache" () noexcept
221cdef extern from 'cuda_runtime_api.h' nogil:
222 cudaError_t _static_cudaStreamCopyAttributes "cudaStreamCopyAttributes" (cudaStream_t dst, cudaStream_t src) noexcept
224cdef extern from 'cuda_runtime_api.h' nogil:
225 cudaError_t _static_cudaStreamGetAttribute "cudaStreamGetAttribute" (cudaStream_t hStream, cudaLaunchAttributeID attr, cudaLaunchAttributeValue* value_out) noexcept
227cdef extern from 'cuda_runtime_api.h' nogil:
228 cudaError_t _static_cudaStreamSetAttribute "cudaStreamSetAttribute" (cudaStream_t hStream, cudaLaunchAttributeID attr, const cudaLaunchAttributeValue* value) noexcept
230cdef extern from 'cuda_runtime_api.h' nogil:
231 cudaError_t _static_cudaStreamDestroy "cudaStreamDestroy" (cudaStream_t stream) noexcept
233cdef extern from 'cuda_runtime_api.h' nogil:
234 cudaError_t _static_cudaStreamWaitEvent "cudaStreamWaitEvent" (cudaStream_t stream, cudaEvent_t event, unsigned int flags) noexcept
236cdef extern from 'cuda_runtime_api.h' nogil:
237 cudaError_t _static_cudaStreamAddCallback "cudaStreamAddCallback" (cudaStream_t stream, cudaStreamCallback_t callback, void* userData, unsigned int flags) noexcept
239cdef extern from 'cuda_runtime_api.h' nogil:
240 cudaError_t _static_cudaStreamSynchronize "cudaStreamSynchronize" (cudaStream_t stream) noexcept
242cdef extern from 'cuda_runtime_api.h' nogil:
243 cudaError_t _static_cudaStreamQuery "cudaStreamQuery" (cudaStream_t stream) noexcept
245cdef extern from 'cuda_runtime_api.h' nogil:
246 cudaError_t _static_cudaStreamAttachMemAsync "cudaStreamAttachMemAsync" (cudaStream_t stream, void* devPtr, size_t length, unsigned int flags) noexcept
248cdef extern from 'cuda_runtime_api.h' nogil:
249 cudaError_t _static_cudaStreamBeginCapture "cudaStreamBeginCapture" (cudaStream_t stream, cudaStreamCaptureMode mode) noexcept
251cdef extern from 'cuda_runtime_api.h' nogil:
252 cudaError_t _static_cudaStreamBeginCaptureToGraph "cudaStreamBeginCaptureToGraph" (cudaStream_t stream, cudaGraph_t graph, const cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaStreamCaptureMode mode) noexcept
254cdef extern from 'cuda_runtime_api.h' nogil:
255 cudaError_t _static_cudaThreadExchangeStreamCaptureMode "cudaThreadExchangeStreamCaptureMode" (cudaStreamCaptureMode* mode) noexcept
257cdef extern from 'cuda_runtime_api.h' nogil:
258 cudaError_t _static_cudaStreamEndCapture "cudaStreamEndCapture" (cudaStream_t stream, cudaGraph_t* pGraph) noexcept
260cdef extern from 'cuda_runtime_api.h' nogil:
261 cudaError_t _static_cudaStreamIsCapturing "cudaStreamIsCapturing" (cudaStream_t stream, cudaStreamCaptureStatus* pCaptureStatus) noexcept
263cdef extern from 'cuda_runtime_api.h' nogil:
264 cudaError_t _static_cudaStreamUpdateCaptureDependencies "cudaStreamUpdateCaptureDependencies" (cudaStream_t stream, cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, unsigned int flags) noexcept
266cdef extern from 'cuda_runtime_api.h' nogil:
267 cudaError_t _static_cudaEventCreate "cudaEventCreate" (cudaEvent_t* event) noexcept
269cdef extern from 'cuda_runtime_api.h' nogil:
270 cudaError_t _static_cudaEventCreateWithFlags "cudaEventCreateWithFlags" (cudaEvent_t* event, unsigned int flags) noexcept
272cdef extern from 'cuda_runtime_api.h' nogil:
273 cudaError_t _static_cudaEventRecord "cudaEventRecord" (cudaEvent_t event, cudaStream_t stream) noexcept
275cdef extern from 'cuda_runtime_api.h' nogil:
276 cudaError_t _static_cudaEventRecordWithFlags "cudaEventRecordWithFlags" (cudaEvent_t event, cudaStream_t stream, unsigned int flags) noexcept
278cdef extern from 'cuda_runtime_api.h' nogil:
279 cudaError_t _static_cudaEventQuery "cudaEventQuery" (cudaEvent_t event) noexcept
281cdef extern from 'cuda_runtime_api.h' nogil:
282 cudaError_t _static_cudaEventSynchronize "cudaEventSynchronize" (cudaEvent_t event) noexcept
284cdef extern from 'cuda_runtime_api.h' nogil:
285 cudaError_t _static_cudaEventDestroy "cudaEventDestroy" (cudaEvent_t event) noexcept
287cdef extern from 'cuda_runtime_api.h' nogil:
288 cudaError_t _static_cudaEventElapsedTime "cudaEventElapsedTime" (float* ms, cudaEvent_t start, cudaEvent_t end) noexcept
290cdef extern from 'cuda_runtime_api.h' nogil:
291 cudaError_t _static_cudaImportExternalMemory "cudaImportExternalMemory" (cudaExternalMemory_t* extMem_out, const cudaExternalMemoryHandleDesc* memHandleDesc) noexcept
293cdef extern from 'cuda_runtime_api.h' nogil:
294 cudaError_t _static_cudaExternalMemoryGetMappedBuffer "cudaExternalMemoryGetMappedBuffer" (void** devPtr, cudaExternalMemory_t extMem, const cudaExternalMemoryBufferDesc* bufferDesc) noexcept
296cdef extern from 'cuda_runtime_api.h' nogil:
297 cudaError_t _static_cudaExternalMemoryGetMappedMipmappedArray "cudaExternalMemoryGetMappedMipmappedArray" (cudaMipmappedArray_t* mipmap, cudaExternalMemory_t extMem, const cudaExternalMemoryMipmappedArrayDesc* mipmapDesc) noexcept
299cdef extern from 'cuda_runtime_api.h' nogil:
300 cudaError_t _static_cudaDestroyExternalMemory "cudaDestroyExternalMemory" (cudaExternalMemory_t extMem) noexcept
302cdef extern from 'cuda_runtime_api.h' nogil:
303 cudaError_t _static_cudaImportExternalSemaphore "cudaImportExternalSemaphore" (cudaExternalSemaphore_t* extSem_out, const cudaExternalSemaphoreHandleDesc* semHandleDesc) noexcept
305cdef extern from 'cuda_runtime_api.h' nogil:
306 cudaError_t _static_cudaDestroyExternalSemaphore "cudaDestroyExternalSemaphore" (cudaExternalSemaphore_t extSem) noexcept
308cdef extern from 'cuda_runtime_api.h' nogil:
309 cudaError_t _static_cudaFuncSetCacheConfig "cudaFuncSetCacheConfig" (const void* func, cudaFuncCache cacheConfig) noexcept
311cdef extern from 'cuda_runtime_api.h' nogil:
312 cudaError_t _static_cudaFuncGetAttributes "cudaFuncGetAttributes" (cudaFuncAttributes* attr, const void* func) noexcept
314cdef extern from 'cuda_runtime_api.h' nogil:
315 cudaError_t _static_cudaFuncSetAttribute "cudaFuncSetAttribute" (const void* func, cudaFuncAttribute attr, int value) noexcept
317cdef extern from 'cuda_runtime_api.h' nogil:
318 cudaError_t _static_cudaFuncGetName "cudaFuncGetName" (const char** name, const void* func) noexcept
320cdef extern from 'cuda_runtime_api.h' nogil:
321 cudaError_t _static_cudaFuncGetParamInfo "cudaFuncGetParamInfo" (const void* func, size_t paramIndex, size_t* paramOffset, size_t* paramSize) noexcept
323cdef extern from 'cuda_runtime_api.h' nogil:
324 cudaError_t _static_cudaLaunchHostFunc "cudaLaunchHostFunc" (cudaStream_t stream, cudaHostFn_t fn, void* userData) noexcept
326cdef extern from 'cuda_runtime_api.h' nogil:
327 cudaError_t _static_cudaFuncSetSharedMemConfig "cudaFuncSetSharedMemConfig" (const void* func, cudaSharedMemConfig config) noexcept
329cdef extern from 'cuda_runtime_api.h' nogil:
330 cudaError_t _static_cudaOccupancyMaxActiveBlocksPerMultiprocessor "cudaOccupancyMaxActiveBlocksPerMultiprocessor" (int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize) noexcept
332cdef extern from 'cuda_runtime_api.h' nogil:
333 cudaError_t _static_cudaOccupancyAvailableDynamicSMemPerBlock "cudaOccupancyAvailableDynamicSMemPerBlock" (size_t* dynamicSmemSize, const void* func, int numBlocks, int blockSize) noexcept
335cdef extern from 'cuda_runtime_api.h' nogil:
336 cudaError_t _static_cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags "cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags" (int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize, unsigned int flags) noexcept
338cdef extern from 'cuda_runtime_api.h' nogil:
339 cudaError_t _static_cudaMallocManaged "cudaMallocManaged" (void** devPtr, size_t size, unsigned int flags) noexcept
341cdef extern from 'cuda_runtime_api.h' nogil:
342 cudaError_t _static_cudaMalloc "cudaMalloc" (void** devPtr, size_t size) noexcept
344cdef extern from 'cuda_runtime_api.h' nogil:
345 cudaError_t _static_cudaMallocHost "cudaMallocHost" (void** ptr, size_t size) noexcept
347cdef extern from 'cuda_runtime_api.h' nogil:
348 cudaError_t _static_cudaMallocPitch "cudaMallocPitch" (void** devPtr, size_t* pitch, size_t width, size_t height) noexcept
350cdef extern from 'cuda_runtime_api.h' nogil:
351 cudaError_t _static_cudaMallocArray "cudaMallocArray" (cudaArray_t* array, const cudaChannelFormatDesc* desc, size_t width, size_t height, unsigned int flags) noexcept
353cdef extern from 'cuda_runtime_api.h' nogil:
354 cudaError_t _static_cudaFree "cudaFree" (void* devPtr) noexcept
356cdef extern from 'cuda_runtime_api.h' nogil:
357 cudaError_t _static_cudaFreeHost "cudaFreeHost" (void* ptr) noexcept
359cdef extern from 'cuda_runtime_api.h' nogil:
360 cudaError_t _static_cudaFreeArray "cudaFreeArray" (cudaArray_t array) noexcept
362cdef extern from 'cuda_runtime_api.h' nogil:
363 cudaError_t _static_cudaFreeMipmappedArray "cudaFreeMipmappedArray" (cudaMipmappedArray_t mipmappedArray) noexcept
365cdef extern from 'cuda_runtime_api.h' nogil:
366 cudaError_t _static_cudaHostAlloc "cudaHostAlloc" (void** pHost, size_t size, unsigned int flags) noexcept
368cdef extern from 'cuda_runtime_api.h' nogil:
369 cudaError_t _static_cudaHostRegister "cudaHostRegister" (void* ptr, size_t size, unsigned int flags) noexcept
371cdef extern from 'cuda_runtime_api.h' nogil:
372 cudaError_t _static_cudaHostUnregister "cudaHostUnregister" (void* ptr) noexcept
374cdef extern from 'cuda_runtime_api.h' nogil:
375 cudaError_t _static_cudaHostGetDevicePointer "cudaHostGetDevicePointer" (void** pDevice, void* pHost, unsigned int flags) noexcept
377cdef extern from 'cuda_runtime_api.h' nogil:
378 cudaError_t _static_cudaHostGetFlags "cudaHostGetFlags" (unsigned int* pFlags, void* pHost) noexcept
380cdef extern from 'cuda_runtime_api.h' nogil:
381 cudaError_t _static_cudaMalloc3D "cudaMalloc3D" (cudaPitchedPtr* pitchedDevPtr, cudaExtent extent) noexcept
383cdef extern from 'cuda_runtime_api.h' nogil:
384 cudaError_t _static_cudaMalloc3DArray "cudaMalloc3DArray" (cudaArray_t* array, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int flags) noexcept
386cdef extern from 'cuda_runtime_api.h' nogil:
387 cudaError_t _static_cudaMallocMipmappedArray "cudaMallocMipmappedArray" (cudaMipmappedArray_t* mipmappedArray, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int numLevels, unsigned int flags) noexcept
389cdef extern from 'cuda_runtime_api.h' nogil:
390 cudaError_t _static_cudaGetMipmappedArrayLevel "cudaGetMipmappedArrayLevel" (cudaArray_t* levelArray, cudaMipmappedArray_const_t mipmappedArray, unsigned int level) noexcept
392cdef extern from 'cuda_runtime_api.h' nogil:
393 cudaError_t _static_cudaMemcpy3D "cudaMemcpy3D" (const cudaMemcpy3DParms* p) noexcept
395cdef extern from 'cuda_runtime_api.h' nogil:
396 cudaError_t _static_cudaMemcpy3DPeer "cudaMemcpy3DPeer" (const cudaMemcpy3DPeerParms* p) noexcept
398cdef extern from 'cuda_runtime_api.h' nogil:
399 cudaError_t _static_cudaMemcpy3DAsync "cudaMemcpy3DAsync" (const cudaMemcpy3DParms* p, cudaStream_t stream) noexcept
401cdef extern from 'cuda_runtime_api.h' nogil:
402 cudaError_t _static_cudaMemcpy3DPeerAsync "cudaMemcpy3DPeerAsync" (const cudaMemcpy3DPeerParms* p, cudaStream_t stream) noexcept
404cdef extern from 'cuda_runtime_api.h' nogil:
405 cudaError_t _static_cudaMemGetInfo "cudaMemGetInfo" (size_t* free, size_t* total) noexcept
407cdef extern from 'cuda_runtime_api.h' nogil:
408 cudaError_t _static_cudaArrayGetInfo "cudaArrayGetInfo" (cudaChannelFormatDesc* desc, cudaExtent* extent, unsigned int* flags, cudaArray_t array) noexcept
410cdef extern from 'cuda_runtime_api.h' nogil:
411 cudaError_t _static_cudaArrayGetPlane "cudaArrayGetPlane" (cudaArray_t* pPlaneArray, cudaArray_t hArray, unsigned int planeIdx) noexcept
413cdef extern from 'cuda_runtime_api.h' nogil:
414 cudaError_t _static_cudaArrayGetMemoryRequirements "cudaArrayGetMemoryRequirements" (cudaArrayMemoryRequirements* memoryRequirements, cudaArray_t array, int device) noexcept
416cdef extern from 'cuda_runtime_api.h' nogil:
417 cudaError_t _static_cudaMipmappedArrayGetMemoryRequirements "cudaMipmappedArrayGetMemoryRequirements" (cudaArrayMemoryRequirements* memoryRequirements, cudaMipmappedArray_t mipmap, int device) noexcept
419cdef extern from 'cuda_runtime_api.h' nogil:
420 cudaError_t _static_cudaArrayGetSparseProperties "cudaArrayGetSparseProperties" (cudaArraySparseProperties* sparseProperties, cudaArray_t array) noexcept
422cdef extern from 'cuda_runtime_api.h' nogil:
423 cudaError_t _static_cudaMipmappedArrayGetSparseProperties "cudaMipmappedArrayGetSparseProperties" (cudaArraySparseProperties* sparseProperties, cudaMipmappedArray_t mipmap) noexcept
425cdef extern from 'cuda_runtime_api.h' nogil:
426 cudaError_t _static_cudaMemcpy "cudaMemcpy" (void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
428cdef extern from 'cuda_runtime_api.h' nogil:
429 cudaError_t _static_cudaMemcpyPeer "cudaMemcpyPeer" (void* dst, int dstDevice, const void* src, int srcDevice, size_t count) noexcept
431cdef extern from 'cuda_runtime_api.h' nogil:
432 cudaError_t _static_cudaMemcpy2D "cudaMemcpy2D" (void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) noexcept
434cdef extern from 'cuda_runtime_api.h' nogil:
435 cudaError_t _static_cudaMemcpy2DToArray "cudaMemcpy2DToArray" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) noexcept
437cdef extern from 'cuda_runtime_api.h' nogil:
438 cudaError_t _static_cudaMemcpy2DFromArray "cudaMemcpy2DFromArray" (void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind) noexcept
440cdef extern from 'cuda_runtime_api.h' nogil:
441 cudaError_t _static_cudaMemcpy2DArrayToArray "cudaMemcpy2DArrayToArray" (cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t width, size_t height, cudaMemcpyKind kind) noexcept
443cdef extern from 'cuda_runtime_api.h' nogil:
444 cudaError_t _static_cudaMemcpyAsync "cudaMemcpyAsync" (void* dst, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) noexcept
446cdef extern from 'cuda_runtime_api.h' nogil:
447 cudaError_t _static_cudaMemcpyPeerAsync "cudaMemcpyPeerAsync" (void* dst, int dstDevice, const void* src, int srcDevice, size_t count, cudaStream_t stream) noexcept
449cdef extern from 'cuda_runtime_api.h' nogil:
450 cudaError_t _static_cudaMemcpyBatchAsync "cudaMemcpyBatchAsync" (void** dsts, const void** srcs, const size_t* sizes, size_t count, cudaMemcpyAttributes* attrs, size_t* attrsIdxs, size_t numAttrs, cudaStream_t stream) noexcept
452cdef extern from 'cuda_runtime_api.h' nogil:
453 cudaError_t _static_cudaMemcpy3DBatchAsync "cudaMemcpy3DBatchAsync" (size_t numOps, cudaMemcpy3DBatchOp* opList, unsigned long long flags, cudaStream_t stream) noexcept
455cdef extern from 'cuda_runtime_api.h' nogil:
456 cudaError_t _static_cudaMemcpy2DAsync "cudaMemcpy2DAsync" (void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) noexcept
458cdef extern from 'cuda_runtime_api.h' nogil:
459 cudaError_t _static_cudaMemcpy2DToArrayAsync "cudaMemcpy2DToArrayAsync" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) noexcept
461cdef extern from 'cuda_runtime_api.h' nogil:
462 cudaError_t _static_cudaMemcpy2DFromArrayAsync "cudaMemcpy2DFromArrayAsync" (void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) noexcept
464cdef extern from 'cuda_runtime_api.h' nogil:
465 cudaError_t _static_cudaMemset "cudaMemset" (void* devPtr, int value, size_t count) noexcept
467cdef extern from 'cuda_runtime_api.h' nogil:
468 cudaError_t _static_cudaMemset2D "cudaMemset2D" (void* devPtr, size_t pitch, int value, size_t width, size_t height) noexcept
470cdef extern from 'cuda_runtime_api.h' nogil:
471 cudaError_t _static_cudaMemset3D "cudaMemset3D" (cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent) noexcept
473cdef extern from 'cuda_runtime_api.h' nogil:
474 cudaError_t _static_cudaMemsetAsync "cudaMemsetAsync" (void* devPtr, int value, size_t count, cudaStream_t stream) noexcept
476cdef extern from 'cuda_runtime_api.h' nogil:
477 cudaError_t _static_cudaMemset2DAsync "cudaMemset2DAsync" (void* devPtr, size_t pitch, int value, size_t width, size_t height, cudaStream_t stream) noexcept
479cdef extern from 'cuda_runtime_api.h' nogil:
480 cudaError_t _static_cudaMemset3DAsync "cudaMemset3DAsync" (cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent, cudaStream_t stream) noexcept
482cdef extern from 'cuda_runtime_api.h' nogil:
483 cudaError_t _static_cudaMemPrefetchAsync "cudaMemPrefetchAsync" (const void* devPtr, size_t count, cudaMemLocation location, unsigned int flags, cudaStream_t stream) noexcept
485cdef extern from 'cuda_runtime_api.h' nogil:
486 cudaError_t _static_cudaMemAdvise "cudaMemAdvise" (const void* devPtr, size_t count, cudaMemoryAdvise advice, cudaMemLocation location) noexcept
488cdef extern from 'cuda_runtime_api.h' nogil:
489 cudaError_t _static_cudaMemRangeGetAttribute "cudaMemRangeGetAttribute" (void* data, size_t dataSize, cudaMemRangeAttribute attribute, const void* devPtr, size_t count) noexcept
491cdef extern from 'cuda_runtime_api.h' nogil:
492 cudaError_t _static_cudaMemRangeGetAttributes "cudaMemRangeGetAttributes" (void** data, size_t* dataSizes, cudaMemRangeAttribute* attributes, size_t numAttributes, const void* devPtr, size_t count) noexcept
494cdef extern from 'cuda_runtime_api.h' nogil:
495 cudaError_t _static_cudaMemcpyToArray "cudaMemcpyToArray" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind) noexcept
497cdef extern from 'cuda_runtime_api.h' nogil:
498 cudaError_t _static_cudaMemcpyFromArray "cudaMemcpyFromArray" (void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind) noexcept
500cdef extern from 'cuda_runtime_api.h' nogil:
501 cudaError_t _static_cudaMemcpyArrayToArray "cudaMemcpyArrayToArray" (cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t count, cudaMemcpyKind kind) noexcept
503cdef extern from 'cuda_runtime_api.h' nogil:
504 cudaError_t _static_cudaMemcpyToArrayAsync "cudaMemcpyToArrayAsync" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) noexcept
506cdef extern from 'cuda_runtime_api.h' nogil:
507 cudaError_t _static_cudaMemcpyFromArrayAsync "cudaMemcpyFromArrayAsync" (void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind, cudaStream_t stream) noexcept
509cdef extern from 'cuda_runtime_api.h' nogil:
510 cudaError_t _static_cudaMallocAsync "cudaMallocAsync" (void** devPtr, size_t size, cudaStream_t hStream) noexcept
512cdef extern from 'cuda_runtime_api.h' nogil:
513 cudaError_t _static_cudaFreeAsync "cudaFreeAsync" (void* devPtr, cudaStream_t hStream) noexcept
515cdef extern from 'cuda_runtime_api.h' nogil:
516 cudaError_t _static_cudaMemPoolTrimTo "cudaMemPoolTrimTo" (cudaMemPool_t memPool, size_t minBytesToKeep) noexcept
518cdef extern from 'cuda_runtime_api.h' nogil:
519 cudaError_t _static_cudaMemPoolSetAttribute "cudaMemPoolSetAttribute" (cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) noexcept
521cdef extern from 'cuda_runtime_api.h' nogil:
522 cudaError_t _static_cudaMemPoolGetAttribute "cudaMemPoolGetAttribute" (cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) noexcept
524cdef extern from 'cuda_runtime_api.h' nogil:
525 cudaError_t _static_cudaMemPoolSetAccess "cudaMemPoolSetAccess" (cudaMemPool_t memPool, const cudaMemAccessDesc* descList, size_t count) noexcept
527cdef extern from 'cuda_runtime_api.h' nogil:
528 cudaError_t _static_cudaMemPoolGetAccess "cudaMemPoolGetAccess" (cudaMemAccessFlags* flags, cudaMemPool_t memPool, cudaMemLocation* location) noexcept
530cdef extern from 'cuda_runtime_api.h' nogil:
531 cudaError_t _static_cudaMemPoolCreate "cudaMemPoolCreate" (cudaMemPool_t* memPool, const cudaMemPoolProps* poolProps) noexcept
533cdef extern from 'cuda_runtime_api.h' nogil:
534 cudaError_t _static_cudaMemPoolDestroy "cudaMemPoolDestroy" (cudaMemPool_t memPool) noexcept
536cdef extern from 'cuda_runtime_api.h' nogil:
537 cudaError_t _static_cudaMallocFromPoolAsync "cudaMallocFromPoolAsync" (void** ptr, size_t size, cudaMemPool_t memPool, cudaStream_t stream) noexcept
539cdef extern from 'cuda_runtime_api.h' nogil:
540 cudaError_t _static_cudaMemPoolExportToShareableHandle "cudaMemPoolExportToShareableHandle" (void* shareableHandle, cudaMemPool_t memPool, cudaMemAllocationHandleType handleType, unsigned int flags) noexcept
542cdef extern from 'cuda_runtime_api.h' nogil:
543 cudaError_t _static_cudaMemPoolImportFromShareableHandle "cudaMemPoolImportFromShareableHandle" (cudaMemPool_t* memPool, void* shareableHandle, cudaMemAllocationHandleType handleType, unsigned int flags) noexcept
545cdef extern from 'cuda_runtime_api.h' nogil:
546 cudaError_t _static_cudaMemPoolExportPointer "cudaMemPoolExportPointer" (cudaMemPoolPtrExportData* exportData, void* ptr) noexcept
548cdef extern from 'cuda_runtime_api.h' nogil:
549 cudaError_t _static_cudaMemPoolImportPointer "cudaMemPoolImportPointer" (void** ptr, cudaMemPool_t memPool, cudaMemPoolPtrExportData* exportData) noexcept
551cdef extern from 'cuda_runtime_api.h' nogil:
552 cudaError_t _static_cudaPointerGetAttributes "cudaPointerGetAttributes" (cudaPointerAttributes* attributes, const void* ptr) noexcept
554cdef extern from 'cuda_runtime_api.h' nogil:
555 cudaError_t _static_cudaDeviceCanAccessPeer "cudaDeviceCanAccessPeer" (int* canAccessPeer, int device, int peerDevice) noexcept
557cdef extern from 'cuda_runtime_api.h' nogil:
558 cudaError_t _static_cudaDeviceEnablePeerAccess "cudaDeviceEnablePeerAccess" (int peerDevice, unsigned int flags) noexcept
560cdef extern from 'cuda_runtime_api.h' nogil:
561 cudaError_t _static_cudaDeviceDisablePeerAccess "cudaDeviceDisablePeerAccess" (int peerDevice) noexcept
563cdef extern from 'cuda_runtime_api.h' nogil:
564 cudaError_t _static_cudaGraphicsUnregisterResource "cudaGraphicsUnregisterResource" (cudaGraphicsResource_t resource) noexcept
566cdef extern from 'cuda_runtime_api.h' nogil:
567 cudaError_t _static_cudaGraphicsResourceSetMapFlags "cudaGraphicsResourceSetMapFlags" (cudaGraphicsResource_t resource, unsigned int flags) noexcept
569cdef extern from 'cuda_runtime_api.h' nogil:
570 cudaError_t _static_cudaGraphicsMapResources "cudaGraphicsMapResources" (int count, cudaGraphicsResource_t* resources, cudaStream_t stream) noexcept
572cdef extern from 'cuda_runtime_api.h' nogil:
573 cudaError_t _static_cudaGraphicsUnmapResources "cudaGraphicsUnmapResources" (int count, cudaGraphicsResource_t* resources, cudaStream_t stream) noexcept
575cdef extern from 'cuda_runtime_api.h' nogil:
576 cudaError_t _static_cudaGraphicsResourceGetMappedPointer "cudaGraphicsResourceGetMappedPointer" (void** devPtr, size_t* size, cudaGraphicsResource_t resource) noexcept
578cdef extern from 'cuda_runtime_api.h' nogil:
579 cudaError_t _static_cudaGraphicsSubResourceGetMappedArray "cudaGraphicsSubResourceGetMappedArray" (cudaArray_t* array, cudaGraphicsResource_t resource, unsigned int arrayIndex, unsigned int mipLevel) noexcept
581cdef extern from 'cuda_runtime_api.h' nogil:
582 cudaError_t _static_cudaGraphicsResourceGetMappedMipmappedArray "cudaGraphicsResourceGetMappedMipmappedArray" (cudaMipmappedArray_t* mipmappedArray, cudaGraphicsResource_t resource) noexcept
584cdef extern from 'cuda_runtime_api.h' nogil:
585 cudaError_t _static_cudaGetChannelDesc "cudaGetChannelDesc" (cudaChannelFormatDesc* desc, cudaArray_const_t array) noexcept
587cdef extern from 'cuda_runtime_api.h' nogil:
588 cudaChannelFormatDesc _static_cudaCreateChannelDesc "cudaCreateChannelDesc" (int x, int y, int z, int w, cudaChannelFormatKind f) noexcept
590cdef extern from 'cuda_runtime_api.h' nogil:
591 cudaError_t _static_cudaCreateTextureObject "cudaCreateTextureObject" (cudaTextureObject_t* pTexObject, const cudaResourceDesc* pResDesc, const cudaTextureDesc* pTexDesc, const cudaResourceViewDesc* pResViewDesc) noexcept
593cdef extern from 'cuda_runtime_api.h' nogil:
594 cudaError_t _static_cudaDestroyTextureObject "cudaDestroyTextureObject" (cudaTextureObject_t texObject) noexcept
596cdef extern from 'cuda_runtime_api.h' nogil:
597 cudaError_t _static_cudaGetTextureObjectResourceDesc "cudaGetTextureObjectResourceDesc" (cudaResourceDesc* pResDesc, cudaTextureObject_t texObject) noexcept
599cdef extern from 'cuda_runtime_api.h' nogil:
600 cudaError_t _static_cudaGetTextureObjectTextureDesc "cudaGetTextureObjectTextureDesc" (cudaTextureDesc* pTexDesc, cudaTextureObject_t texObject) noexcept
602cdef extern from 'cuda_runtime_api.h' nogil:
603 cudaError_t _static_cudaGetTextureObjectResourceViewDesc "cudaGetTextureObjectResourceViewDesc" (cudaResourceViewDesc* pResViewDesc, cudaTextureObject_t texObject) noexcept
605cdef extern from 'cuda_runtime_api.h' nogil:
606 cudaError_t _static_cudaCreateSurfaceObject "cudaCreateSurfaceObject" (cudaSurfaceObject_t* pSurfObject, const cudaResourceDesc* pResDesc) noexcept
608cdef extern from 'cuda_runtime_api.h' nogil:
609 cudaError_t _static_cudaDestroySurfaceObject "cudaDestroySurfaceObject" (cudaSurfaceObject_t surfObject) noexcept
611cdef extern from 'cuda_runtime_api.h' nogil:
612 cudaError_t _static_cudaGetSurfaceObjectResourceDesc "cudaGetSurfaceObjectResourceDesc" (cudaResourceDesc* pResDesc, cudaSurfaceObject_t surfObject) noexcept
614cdef extern from 'cuda_runtime_api.h' nogil:
615 cudaError_t _static_cudaDriverGetVersion "cudaDriverGetVersion" (int* driverVersion) noexcept
617cdef extern from 'cuda_runtime_api.h' nogil:
618 cudaError_t _static_cudaRuntimeGetVersion "cudaRuntimeGetVersion" (int* runtimeVersion) noexcept
620cdef extern from 'cuda_runtime_api.h' nogil:
621 cudaError_t _static_cudaGraphCreate "cudaGraphCreate" (cudaGraph_t* pGraph, unsigned int flags) noexcept
623cdef extern from 'cuda_runtime_api.h' nogil:
624 cudaError_t _static_cudaGraphAddKernelNode "cudaGraphAddKernelNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaKernelNodeParams* pNodeParams) noexcept
626cdef extern from 'cuda_runtime_api.h' nogil:
627 cudaError_t _static_cudaGraphKernelNodeGetParams "cudaGraphKernelNodeGetParams" (cudaGraphNode_t node, cudaKernelNodeParams* pNodeParams) noexcept
629cdef extern from 'cuda_runtime_api.h' nogil:
630 cudaError_t _static_cudaGraphKernelNodeSetParams "cudaGraphKernelNodeSetParams" (cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) noexcept
632cdef extern from 'cuda_runtime_api.h' nogil:
633 cudaError_t _static_cudaGraphKernelNodeCopyAttributes "cudaGraphKernelNodeCopyAttributes" (cudaGraphNode_t hDst, cudaGraphNode_t hSrc) noexcept
635cdef extern from 'cuda_runtime_api.h' nogil:
636 cudaError_t _static_cudaGraphKernelNodeGetAttribute "cudaGraphKernelNodeGetAttribute" (cudaGraphNode_t hNode, cudaLaunchAttributeID attr, cudaLaunchAttributeValue* value_out) noexcept
638cdef extern from 'cuda_runtime_api.h' nogil:
639 cudaError_t _static_cudaGraphKernelNodeSetAttribute "cudaGraphKernelNodeSetAttribute" (cudaGraphNode_t hNode, cudaLaunchAttributeID attr, const cudaLaunchAttributeValue* value) noexcept
641cdef extern from 'cuda_runtime_api.h' nogil:
642 cudaError_t _static_cudaGraphAddMemcpyNode "cudaGraphAddMemcpyNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemcpy3DParms* pCopyParams) noexcept
644cdef extern from 'cuda_runtime_api.h' nogil:
645 cudaError_t _static_cudaGraphAddMemcpyNode1D "cudaGraphAddMemcpyNode1D" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
647cdef extern from 'cuda_runtime_api.h' nogil:
648 cudaError_t _static_cudaGraphMemcpyNodeGetParams "cudaGraphMemcpyNodeGetParams" (cudaGraphNode_t node, cudaMemcpy3DParms* pNodeParams) noexcept
650cdef extern from 'cuda_runtime_api.h' nogil:
651 cudaError_t _static_cudaGraphMemcpyNodeSetParams "cudaGraphMemcpyNodeSetParams" (cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) noexcept
653cdef extern from 'cuda_runtime_api.h' nogil:
654 cudaError_t _static_cudaGraphMemcpyNodeSetParams1D "cudaGraphMemcpyNodeSetParams1D" (cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
656cdef extern from 'cuda_runtime_api.h' nogil:
657 cudaError_t _static_cudaGraphAddMemsetNode "cudaGraphAddMemsetNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemsetParams* pMemsetParams) noexcept
659cdef extern from 'cuda_runtime_api.h' nogil:
660 cudaError_t _static_cudaGraphMemsetNodeGetParams "cudaGraphMemsetNodeGetParams" (cudaGraphNode_t node, cudaMemsetParams* pNodeParams) noexcept
662cdef extern from 'cuda_runtime_api.h' nogil:
663 cudaError_t _static_cudaGraphMemsetNodeSetParams "cudaGraphMemsetNodeSetParams" (cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) noexcept
665cdef extern from 'cuda_runtime_api.h' nogil:
666 cudaError_t _static_cudaGraphAddHostNode "cudaGraphAddHostNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaHostNodeParams* pNodeParams) noexcept
668cdef extern from 'cuda_runtime_api.h' nogil:
669 cudaError_t _static_cudaGraphHostNodeGetParams "cudaGraphHostNodeGetParams" (cudaGraphNode_t node, cudaHostNodeParams* pNodeParams) noexcept
671cdef extern from 'cuda_runtime_api.h' nogil:
672 cudaError_t _static_cudaGraphHostNodeSetParams "cudaGraphHostNodeSetParams" (cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) noexcept
674cdef extern from 'cuda_runtime_api.h' nogil:
675 cudaError_t _static_cudaGraphAddChildGraphNode "cudaGraphAddChildGraphNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaGraph_t childGraph) noexcept
677cdef extern from 'cuda_runtime_api.h' nogil:
678 cudaError_t _static_cudaGraphChildGraphNodeGetGraph "cudaGraphChildGraphNodeGetGraph" (cudaGraphNode_t node, cudaGraph_t* pGraph) noexcept
680cdef extern from 'cuda_runtime_api.h' nogil:
681 cudaError_t _static_cudaGraphAddEmptyNode "cudaGraphAddEmptyNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies) noexcept
683cdef extern from 'cuda_runtime_api.h' nogil:
684 cudaError_t _static_cudaGraphAddEventRecordNode "cudaGraphAddEventRecordNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) noexcept
686cdef extern from 'cuda_runtime_api.h' nogil:
687 cudaError_t _static_cudaGraphEventRecordNodeGetEvent "cudaGraphEventRecordNodeGetEvent" (cudaGraphNode_t node, cudaEvent_t* event_out) noexcept
689cdef extern from 'cuda_runtime_api.h' nogil:
690 cudaError_t _static_cudaGraphEventRecordNodeSetEvent "cudaGraphEventRecordNodeSetEvent" (cudaGraphNode_t node, cudaEvent_t event) noexcept
692cdef extern from 'cuda_runtime_api.h' nogil:
693 cudaError_t _static_cudaGraphAddEventWaitNode "cudaGraphAddEventWaitNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) noexcept
695cdef extern from 'cuda_runtime_api.h' nogil:
696 cudaError_t _static_cudaGraphEventWaitNodeGetEvent "cudaGraphEventWaitNodeGetEvent" (cudaGraphNode_t node, cudaEvent_t* event_out) noexcept
698cdef extern from 'cuda_runtime_api.h' nogil:
699 cudaError_t _static_cudaGraphEventWaitNodeSetEvent "cudaGraphEventWaitNodeSetEvent" (cudaGraphNode_t node, cudaEvent_t event) noexcept
701cdef extern from 'cuda_runtime_api.h' nogil:
702 cudaError_t _static_cudaGraphAddExternalSemaphoresSignalNode "cudaGraphAddExternalSemaphoresSignalNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreSignalNodeParams* nodeParams) noexcept
704cdef extern from 'cuda_runtime_api.h' nogil:
705 cudaError_t _static_cudaGraphExternalSemaphoresSignalNodeGetParams "cudaGraphExternalSemaphoresSignalNodeGetParams" (cudaGraphNode_t hNode, cudaExternalSemaphoreSignalNodeParams* params_out) noexcept
707cdef extern from 'cuda_runtime_api.h' nogil:
708 cudaError_t _static_cudaGraphExternalSemaphoresSignalNodeSetParams "cudaGraphExternalSemaphoresSignalNodeSetParams" (cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) noexcept
710cdef extern from 'cuda_runtime_api.h' nogil:
711 cudaError_t _static_cudaGraphAddExternalSemaphoresWaitNode "cudaGraphAddExternalSemaphoresWaitNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreWaitNodeParams* nodeParams) noexcept
713cdef extern from 'cuda_runtime_api.h' nogil:
714 cudaError_t _static_cudaGraphExternalSemaphoresWaitNodeGetParams "cudaGraphExternalSemaphoresWaitNodeGetParams" (cudaGraphNode_t hNode, cudaExternalSemaphoreWaitNodeParams* params_out) noexcept
716cdef extern from 'cuda_runtime_api.h' nogil:
717 cudaError_t _static_cudaGraphExternalSemaphoresWaitNodeSetParams "cudaGraphExternalSemaphoresWaitNodeSetParams" (cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) noexcept
719cdef extern from 'cuda_runtime_api.h' nogil:
720 cudaError_t _static_cudaGraphAddMemAllocNode "cudaGraphAddMemAllocNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaMemAllocNodeParams* nodeParams) noexcept
722cdef extern from 'cuda_runtime_api.h' nogil:
723 cudaError_t _static_cudaGraphMemAllocNodeGetParams "cudaGraphMemAllocNodeGetParams" (cudaGraphNode_t node, cudaMemAllocNodeParams* params_out) noexcept
725cdef extern from 'cuda_runtime_api.h' nogil:
726 cudaError_t _static_cudaGraphAddMemFreeNode "cudaGraphAddMemFreeNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dptr) noexcept
728cdef extern from 'cuda_runtime_api.h' nogil:
729 cudaError_t _static_cudaGraphMemFreeNodeGetParams "cudaGraphMemFreeNodeGetParams" (cudaGraphNode_t node, void* dptr_out) noexcept
731cdef extern from 'cuda_runtime_api.h' nogil:
732 cudaError_t _static_cudaDeviceGraphMemTrim "cudaDeviceGraphMemTrim" (int device) noexcept
734cdef extern from 'cuda_runtime_api.h' nogil:
735 cudaError_t _static_cudaDeviceGetGraphMemAttribute "cudaDeviceGetGraphMemAttribute" (int device, cudaGraphMemAttributeType attr, void* value) noexcept
737cdef extern from 'cuda_runtime_api.h' nogil:
738 cudaError_t _static_cudaDeviceSetGraphMemAttribute "cudaDeviceSetGraphMemAttribute" (int device, cudaGraphMemAttributeType attr, void* value) noexcept
740cdef extern from 'cuda_runtime_api.h' nogil:
741 cudaError_t _static_cudaGraphClone "cudaGraphClone" (cudaGraph_t* pGraphClone, cudaGraph_t originalGraph) noexcept
743cdef extern from 'cuda_runtime_api.h' nogil:
744 cudaError_t _static_cudaGraphNodeFindInClone "cudaGraphNodeFindInClone" (cudaGraphNode_t* pNode, cudaGraphNode_t originalNode, cudaGraph_t clonedGraph) noexcept
746cdef extern from 'cuda_runtime_api.h' nogil:
747 cudaError_t _static_cudaGraphNodeGetType "cudaGraphNodeGetType" (cudaGraphNode_t node, cudaGraphNodeType* pType) noexcept
749cdef extern from 'cuda_runtime_api.h' nogil:
750 cudaError_t _static_cudaGraphGetNodes "cudaGraphGetNodes" (cudaGraph_t graph, cudaGraphNode_t* nodes, size_t* numNodes) noexcept
752cdef extern from 'cuda_runtime_api.h' nogil:
753 cudaError_t _static_cudaGraphGetRootNodes "cudaGraphGetRootNodes" (cudaGraph_t graph, cudaGraphNode_t* pRootNodes, size_t* pNumRootNodes) noexcept
755cdef extern from 'cuda_runtime_api.h' nogil:
756 cudaError_t _static_cudaGraphGetEdges "cudaGraphGetEdges" (cudaGraph_t graph, cudaGraphNode_t* from_, cudaGraphNode_t* to, cudaGraphEdgeData* edgeData, size_t* numEdges) noexcept
758cdef extern from 'cuda_runtime_api.h' nogil:
759 cudaError_t _static_cudaGraphNodeGetDependencies "cudaGraphNodeGetDependencies" (cudaGraphNode_t node, cudaGraphNode_t* pDependencies, cudaGraphEdgeData* edgeData, size_t* pNumDependencies) noexcept
761cdef extern from 'cuda_runtime_api.h' nogil:
762 cudaError_t _static_cudaGraphNodeGetDependentNodes "cudaGraphNodeGetDependentNodes" (cudaGraphNode_t node, cudaGraphNode_t* pDependentNodes, cudaGraphEdgeData* edgeData, size_t* pNumDependentNodes) noexcept
764cdef extern from 'cuda_runtime_api.h' nogil:
765 cudaError_t _static_cudaGraphAddDependencies "cudaGraphAddDependencies" (cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) noexcept
767cdef extern from 'cuda_runtime_api.h' nogil:
768 cudaError_t _static_cudaGraphRemoveDependencies "cudaGraphRemoveDependencies" (cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) noexcept
770cdef extern from 'cuda_runtime_api.h' nogil:
771 cudaError_t _static_cudaGraphDestroyNode "cudaGraphDestroyNode" (cudaGraphNode_t node) noexcept
773cdef extern from 'cuda_runtime_api.h' nogil:
774 cudaError_t _static_cudaGraphInstantiate "cudaGraphInstantiate" (cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) noexcept
776cdef extern from 'cuda_runtime_api.h' nogil:
777 cudaError_t _static_cudaGraphInstantiateWithFlags "cudaGraphInstantiateWithFlags" (cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) noexcept
779cdef extern from 'cuda_runtime_api.h' nogil:
780 cudaError_t _static_cudaGraphInstantiateWithParams "cudaGraphInstantiateWithParams" (cudaGraphExec_t* pGraphExec, cudaGraph_t graph, cudaGraphInstantiateParams* instantiateParams) noexcept
782cdef extern from 'cuda_runtime_api.h' nogil:
783 cudaError_t _static_cudaGraphExecGetFlags "cudaGraphExecGetFlags" (cudaGraphExec_t graphExec, unsigned long long* flags) noexcept
785cdef extern from 'cuda_runtime_api.h' nogil:
786 cudaError_t _static_cudaGraphExecKernelNodeSetParams "cudaGraphExecKernelNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) noexcept
788cdef extern from 'cuda_runtime_api.h' nogil:
789 cudaError_t _static_cudaGraphExecMemcpyNodeSetParams "cudaGraphExecMemcpyNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) noexcept
791cdef extern from 'cuda_runtime_api.h' nogil:
792 cudaError_t _static_cudaGraphExecMemcpyNodeSetParams1D "cudaGraphExecMemcpyNodeSetParams1D" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
794cdef extern from 'cuda_runtime_api.h' nogil:
795 cudaError_t _static_cudaGraphExecMemsetNodeSetParams "cudaGraphExecMemsetNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) noexcept
797cdef extern from 'cuda_runtime_api.h' nogil:
798 cudaError_t _static_cudaGraphExecHostNodeSetParams "cudaGraphExecHostNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) noexcept
800cdef extern from 'cuda_runtime_api.h' nogil:
801 cudaError_t _static_cudaGraphExecChildGraphNodeSetParams "cudaGraphExecChildGraphNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, cudaGraph_t childGraph) noexcept
803cdef extern from 'cuda_runtime_api.h' nogil:
804 cudaError_t _static_cudaGraphExecEventRecordNodeSetEvent "cudaGraphExecEventRecordNodeSetEvent" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) noexcept
806cdef extern from 'cuda_runtime_api.h' nogil:
807 cudaError_t _static_cudaGraphExecEventWaitNodeSetEvent "cudaGraphExecEventWaitNodeSetEvent" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) noexcept
809cdef extern from 'cuda_runtime_api.h' nogil:
810 cudaError_t _static_cudaGraphExecExternalSemaphoresSignalNodeSetParams "cudaGraphExecExternalSemaphoresSignalNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) noexcept
812cdef extern from 'cuda_runtime_api.h' nogil:
813 cudaError_t _static_cudaGraphExecExternalSemaphoresWaitNodeSetParams "cudaGraphExecExternalSemaphoresWaitNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) noexcept
815cdef extern from 'cuda_runtime_api.h' nogil:
816 cudaError_t _static_cudaGraphNodeSetEnabled "cudaGraphNodeSetEnabled" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int isEnabled) noexcept
818cdef extern from 'cuda_runtime_api.h' nogil:
819 cudaError_t _static_cudaGraphNodeGetEnabled "cudaGraphNodeGetEnabled" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int* isEnabled) noexcept
821cdef extern from 'cuda_runtime_api.h' nogil:
822 cudaError_t _static_cudaGraphExecUpdate "cudaGraphExecUpdate" (cudaGraphExec_t hGraphExec, cudaGraph_t hGraph, cudaGraphExecUpdateResultInfo* resultInfo) noexcept
824cdef extern from 'cuda_runtime_api.h' nogil:
825 cudaError_t _static_cudaGraphUpload "cudaGraphUpload" (cudaGraphExec_t graphExec, cudaStream_t stream) noexcept
827cdef extern from 'cuda_runtime_api.h' nogil:
828 cudaError_t _static_cudaGraphLaunch "cudaGraphLaunch" (cudaGraphExec_t graphExec, cudaStream_t stream) noexcept
830cdef extern from 'cuda_runtime_api.h' nogil:
831 cudaError_t _static_cudaGraphExecDestroy "cudaGraphExecDestroy" (cudaGraphExec_t graphExec) noexcept
833cdef extern from 'cuda_runtime_api.h' nogil:
834 cudaError_t _static_cudaGraphDestroy "cudaGraphDestroy" (cudaGraph_t graph) noexcept
836cdef extern from 'cuda_runtime_api.h' nogil:
837 cudaError_t _static_cudaGraphDebugDotPrint "cudaGraphDebugDotPrint" (cudaGraph_t graph, const char* path, unsigned int flags) noexcept
839cdef extern from 'cuda_runtime_api.h' nogil:
840 cudaError_t _static_cudaUserObjectCreate "cudaUserObjectCreate" (cudaUserObject_t* object_out, void* ptr, cudaHostFn_t destroy, unsigned int initialRefcount, unsigned int flags) noexcept
842cdef extern from 'cuda_runtime_api.h' nogil:
843 cudaError_t _static_cudaUserObjectRetain "cudaUserObjectRetain" (cudaUserObject_t object, unsigned int count) noexcept
845cdef extern from 'cuda_runtime_api.h' nogil:
846 cudaError_t _static_cudaUserObjectRelease "cudaUserObjectRelease" (cudaUserObject_t object, unsigned int count) noexcept
848cdef extern from 'cuda_runtime_api.h' nogil:
849 cudaError_t _static_cudaGraphRetainUserObject "cudaGraphRetainUserObject" (cudaGraph_t graph, cudaUserObject_t object, unsigned int count, unsigned int flags) noexcept
851cdef extern from 'cuda_runtime_api.h' nogil:
852 cudaError_t _static_cudaGraphReleaseUserObject "cudaGraphReleaseUserObject" (cudaGraph_t graph, cudaUserObject_t object, unsigned int count) noexcept
854cdef extern from 'cuda_runtime_api.h' nogil:
855 cudaError_t _static_cudaGraphAddNode "cudaGraphAddNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaGraphNodeParams* nodeParams) noexcept
857cdef extern from 'cuda_runtime_api.h' nogil:
858 cudaError_t _static_cudaGraphNodeSetParams "cudaGraphNodeSetParams" (cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) noexcept
860cdef extern from 'cuda_runtime_api.h' nogil:
861 cudaError_t _static_cudaGraphExecNodeSetParams "cudaGraphExecNodeSetParams" (cudaGraphExec_t graphExec, cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) noexcept
863cdef extern from 'cuda_runtime_api.h' nogil:
864 cudaError_t _static_cudaGraphConditionalHandleCreate "cudaGraphConditionalHandleCreate" (cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, unsigned int defaultLaunchValue, unsigned int flags) noexcept
866cdef extern from 'cuda_runtime_api.h' nogil:
867 cudaError_t _static_cudaGetDriverEntryPoint "cudaGetDriverEntryPoint" (const char* symbol, void** funcPtr, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) noexcept
869cdef extern from 'cuda_runtime_api.h' nogil:
870 cudaError_t _static_cudaGetDriverEntryPointByVersion "cudaGetDriverEntryPointByVersion" (const char* symbol, void** funcPtr, unsigned int cudaVersion, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) noexcept
872cdef extern from 'cuda_runtime_api.h' nogil:
873 cudaError_t _static_cudaLibraryLoadData "cudaLibraryLoadData" (cudaLibrary_t* library, const void* code, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) noexcept
875cdef extern from 'cuda_runtime_api.h' nogil:
876 cudaError_t _static_cudaLibraryLoadFromFile "cudaLibraryLoadFromFile" (cudaLibrary_t* library, const char* fileName, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) noexcept
878cdef extern from 'cuda_runtime_api.h' nogil:
879 cudaError_t _static_cudaLibraryUnload "cudaLibraryUnload" (cudaLibrary_t library) noexcept
881cdef extern from 'cuda_runtime_api.h' nogil:
882 cudaError_t _static_cudaLibraryGetKernel "cudaLibraryGetKernel" (cudaKernel_t* pKernel, cudaLibrary_t library, const char* name) noexcept
884cdef extern from 'cuda_runtime_api.h' nogil:
885 cudaError_t _static_cudaLibraryGetGlobal "cudaLibraryGetGlobal" (void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) noexcept
887cdef extern from 'cuda_runtime_api.h' nogil:
888 cudaError_t _static_cudaLibraryGetManaged "cudaLibraryGetManaged" (void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) noexcept
890cdef extern from 'cuda_runtime_api.h' nogil:
891 cudaError_t _static_cudaLibraryGetUnifiedFunction "cudaLibraryGetUnifiedFunction" (void** fptr, cudaLibrary_t library, const char* symbol) noexcept
893cdef extern from 'cuda_runtime_api.h' nogil:
894 cudaError_t _static_cudaLibraryGetKernelCount "cudaLibraryGetKernelCount" (unsigned int* count, cudaLibrary_t lib) noexcept
896cdef extern from 'cuda_runtime_api.h' nogil:
897 cudaError_t _static_cudaLibraryEnumerateKernels "cudaLibraryEnumerateKernels" (cudaKernel_t* kernels, unsigned int numKernels, cudaLibrary_t lib) noexcept
899cdef extern from 'cuda_runtime_api.h' nogil:
900 cudaError_t _static_cudaKernelSetAttributeForDevice "cudaKernelSetAttributeForDevice" (cudaKernel_t kernel, cudaFuncAttribute attr, int value, int device) noexcept
902cdef extern from 'cuda_runtime_api.h' nogil:
903 cudaError_t _static_cudaGetExportTable "cudaGetExportTable" (const void** ppExportTable, const cudaUUID_t* pExportTableId) noexcept
905cdef extern from 'cuda_runtime_api.h' nogil:
906 cudaError_t _static_cudaGetKernel "cudaGetKernel" (cudaKernel_t* kernelPtr, const void* entryFuncAddr) noexcept
908cdef extern from 'cuda_profiler_api.h' nogil:
909 cudaError_t _static_cudaProfilerStart "cudaProfilerStart" () noexcept
911cdef extern from 'cuda_profiler_api.h' nogil:
912 cudaError_t _static_cudaProfilerStop "cudaProfilerStop" () noexcept
914cdef extern from 'cuda_runtime_api.h' nogil:
915 cudaError_t _static_cudaGetDeviceProperties "cudaGetDeviceProperties" (cudaDeviceProp* prop, int device) noexcept
917cdef extern from 'cuda_runtime_api.h' nogil:
918 cudaError_t _static_cudaDeviceGetHostAtomicCapabilities "cudaDeviceGetHostAtomicCapabilities" (unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int device) noexcept
920cdef extern from 'cuda_runtime_api.h' nogil:
921 cudaError_t _static_cudaDeviceGetP2PAtomicCapabilities "cudaDeviceGetP2PAtomicCapabilities" (unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int srcDevice, int dstDevice) noexcept
923cdef extern from 'cuda_runtime_api.h' nogil:
924 cudaError_t _static_cudaStreamGetCaptureInfo "cudaStreamGetCaptureInfo" (cudaStream_t stream, cudaStreamCaptureStatus* captureStatus_out, unsigned long long* id_out, cudaGraph_t* graph_out, const cudaGraphNode_t** dependencies_out, const cudaGraphEdgeData** edgeData_out, size_t* numDependencies_out) noexcept
926cdef extern from 'cuda_runtime_api.h' nogil:
927 cudaError_t _static_cudaSignalExternalSemaphoresAsync "cudaSignalExternalSemaphoresAsync" (const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreSignalParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) noexcept
929cdef extern from 'cuda_runtime_api.h' nogil:
930 cudaError_t _static_cudaWaitExternalSemaphoresAsync "cudaWaitExternalSemaphoresAsync" (const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreWaitParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) noexcept
932cdef extern from 'cuda_runtime_api.h' nogil:
933 cudaError_t _static_cudaMemPrefetchBatchAsync "cudaMemPrefetchBatchAsync" (void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) noexcept
935cdef extern from 'cuda_runtime_api.h' nogil:
936 cudaError_t _static_cudaMemDiscardBatchAsync "cudaMemDiscardBatchAsync" (void** dptrs, size_t* sizes, size_t count, unsigned long long flags, cudaStream_t stream) noexcept
938cdef extern from 'cuda_runtime_api.h' nogil:
939 cudaError_t _static_cudaMemDiscardAndPrefetchBatchAsync "cudaMemDiscardAndPrefetchBatchAsync" (void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) noexcept
941cdef extern from 'cuda_runtime_api.h' nogil:
942 cudaError_t _static_cudaMemGetDefaultMemPool "cudaMemGetDefaultMemPool" (cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) noexcept
944cdef extern from 'cuda_runtime_api.h' nogil:
945 cudaError_t _static_cudaMemGetMemPool "cudaMemGetMemPool" (cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) noexcept
947cdef extern from 'cuda_runtime_api.h' nogil:
948 cudaError_t _static_cudaMemSetMemPool "cudaMemSetMemPool" (cudaMemLocation* location, cudaMemAllocationType type, cudaMemPool_t memPool) noexcept
950cdef extern from 'cuda_runtime_api.h' nogil:
951 cudaError_t _static_cudaLogsRegisterCallback "cudaLogsRegisterCallback" (cudaLogsCallback_t callbackFunc, void* userData, cudaLogsCallbackHandle* callback_out) noexcept
953cdef extern from 'cuda_runtime_api.h' nogil:
954 cudaError_t _static_cudaLogsUnregisterCallback "cudaLogsUnregisterCallback" (cudaLogsCallbackHandle callback) noexcept
956cdef extern from 'cuda_runtime_api.h' nogil:
957 cudaError_t _static_cudaLogsCurrent "cudaLogsCurrent" (cudaLogIterator* iterator_out, unsigned int flags) noexcept
959cdef extern from 'cuda_runtime_api.h' nogil:
960 cudaError_t _static_cudaLogsDumpToFile "cudaLogsDumpToFile" (cudaLogIterator* iterator, const char* pathToFile, unsigned int flags) noexcept
962cdef extern from 'cuda_runtime_api.h' nogil:
963 cudaError_t _static_cudaLogsDumpToMemory "cudaLogsDumpToMemory" (cudaLogIterator* iterator, char* buffer, size_t* size, unsigned int flags) noexcept
965cdef extern from 'cuda_runtime_api.h' nogil:
966 cudaError_t _static_cudaGraphNodeGetContainingGraph "cudaGraphNodeGetContainingGraph" (cudaGraphNode_t hNode, cudaGraph_t* phGraph) noexcept
968cdef extern from 'cuda_runtime_api.h' nogil:
969 cudaError_t _static_cudaGraphNodeGetLocalId "cudaGraphNodeGetLocalId" (cudaGraphNode_t hNode, unsigned int* nodeId) noexcept
971cdef extern from 'cuda_runtime_api.h' nogil:
972 cudaError_t _static_cudaGraphNodeGetToolsId "cudaGraphNodeGetToolsId" (cudaGraphNode_t hNode, unsigned long long* toolsNodeId) noexcept
974cdef extern from 'cuda_runtime_api.h' nogil:
975 cudaError_t _static_cudaGraphGetId "cudaGraphGetId" (cudaGraph_t hGraph, unsigned int* graphID) noexcept
977cdef extern from 'cuda_runtime_api.h' nogil:
978 cudaError_t _static_cudaGraphExecGetId "cudaGraphExecGetId" (cudaGraphExec_t hGraphExec, unsigned int* graphID) noexcept
980cdef extern from 'cuda_runtime_api.h' nogil:
981 cudaError_t _static_cudaGraphConditionalHandleCreate_v2 "cudaGraphConditionalHandleCreate_v2" (cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, cudaExecutionContext_t ctx, unsigned int defaultLaunchValue, unsigned int flags) noexcept
983cdef extern from 'cuda_runtime_api.h' nogil:
984 cudaError_t _static_cudaDeviceGetDevResource "cudaDeviceGetDevResource" (int device, cudaDevResource* resource, cudaDevResourceType type) noexcept
986cdef extern from 'cuda_runtime_api.h' nogil:
987 cudaError_t _static_cudaDevSmResourceSplitByCount "cudaDevSmResourceSplitByCount" (cudaDevResource* result, unsigned int* nbGroups, const cudaDevResource* input, cudaDevResource* remaining, unsigned int flags, unsigned int minCount) noexcept
989cdef extern from 'cuda_runtime_api.h' nogil:
990 cudaError_t _static_cudaDevSmResourceSplit "cudaDevSmResourceSplit" (cudaDevResource* result, unsigned int nbGroups, const cudaDevResource* input, cudaDevResource* remainder, unsigned int flags, cudaDevSmResourceGroupParams* groupParams) noexcept
992cdef extern from 'cuda_runtime_api.h' nogil:
993 cudaError_t _static_cudaDevResourceGenerateDesc "cudaDevResourceGenerateDesc" (cudaDevResourceDesc_t* phDesc, cudaDevResource* resources, unsigned int nbResources) noexcept
995cdef extern from 'cuda_runtime_api.h' nogil:
996 cudaError_t _static_cudaGreenCtxCreate "cudaGreenCtxCreate" (cudaExecutionContext_t* phCtx, cudaDevResourceDesc_t desc, int device, unsigned int flags) noexcept
998cdef extern from 'cuda_runtime_api.h' nogil:
999 cudaError_t _static_cudaExecutionCtxDestroy "cudaExecutionCtxDestroy" (cudaExecutionContext_t ctx) noexcept
1001cdef extern from 'cuda_runtime_api.h' nogil:
1002 cudaError_t _static_cudaExecutionCtxGetDevResource "cudaExecutionCtxGetDevResource" (cudaExecutionContext_t ctx, cudaDevResource* resource, cudaDevResourceType type) noexcept
1004cdef extern from 'cuda_runtime_api.h' nogil:
1005 cudaError_t _static_cudaExecutionCtxGetDevice "cudaExecutionCtxGetDevice" (int* device, cudaExecutionContext_t ctx) noexcept
1007cdef extern from 'cuda_runtime_api.h' nogil:
1008 cudaError_t _static_cudaExecutionCtxGetId "cudaExecutionCtxGetId" (cudaExecutionContext_t ctx, unsigned long long* ctxId) noexcept
1010cdef extern from 'cuda_runtime_api.h' nogil:
1011 cudaError_t _static_cudaExecutionCtxStreamCreate "cudaExecutionCtxStreamCreate" (cudaStream_t* phStream, cudaExecutionContext_t ctx, unsigned int flags, int priority) noexcept
1013cdef extern from 'cuda_runtime_api.h' nogil:
1014 cudaError_t _static_cudaExecutionCtxSynchronize "cudaExecutionCtxSynchronize" (cudaExecutionContext_t ctx) noexcept
1016cdef extern from 'cuda_runtime_api.h' nogil:
1017 cudaError_t _static_cudaStreamGetDevResource "cudaStreamGetDevResource" (cudaStream_t hStream, cudaDevResource* resource, cudaDevResourceType type) noexcept
1019cdef extern from 'cuda_runtime_api.h' nogil:
1020 cudaError_t _static_cudaExecutionCtxRecordEvent "cudaExecutionCtxRecordEvent" (cudaExecutionContext_t ctx, cudaEvent_t event) noexcept
1022cdef extern from 'cuda_runtime_api.h' nogil:
1023 cudaError_t _static_cudaExecutionCtxWaitEvent "cudaExecutionCtxWaitEvent" (cudaExecutionContext_t ctx, cudaEvent_t event) noexcept
1025cdef extern from 'cuda_runtime_api.h' nogil:
1026 cudaError_t _static_cudaDeviceGetExecutionCtx "cudaDeviceGetExecutionCtx" (cudaExecutionContext_t* ctx, int device) noexcept
1028cdef extern from 'cuda_runtime_api.h' nogil:
1029 cudaError_t _static_cudaFuncGetParamCount "cudaFuncGetParamCount" (const void* func, size_t* paramCount) noexcept
1031cdef extern from 'cuda_runtime_api.h' nogil:
1032 cudaError_t _static_cudaLaunchHostFunc_v2 "cudaLaunchHostFunc_v2" (cudaStream_t stream, cudaHostFn_t fn, void* userData, unsigned int syncMode) noexcept
1034cdef extern from 'cuda_runtime_api.h' nogil:
1035 cudaError_t _static_cudaMemcpyWithAttributesAsync "cudaMemcpyWithAttributesAsync" (void* dst, const void* src, size_t size, cudaMemcpyAttributes* attr, cudaStream_t stream) noexcept
1037cdef extern from 'cuda_runtime_api.h' nogil:
1038 cudaError_t _static_cudaMemcpy3DWithAttributesAsync "cudaMemcpy3DWithAttributesAsync" (cudaMemcpy3DBatchOp* op, unsigned long long flags, cudaStream_t stream) noexcept
1040cdef extern from 'cuda_runtime_api.h' nogil:
1041 cudaError_t _static_cudaGraphNodeGetParams "cudaGraphNodeGetParams" (cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) noexcept
1043cdef extern from 'cuda_runtime_api.h' nogil:
1044 cudaError_t _static_cudaStreamBeginRecaptureToGraph "cudaStreamBeginRecaptureToGraph" (cudaStream_t stream, cudaStreamCaptureMode mode, cudaGraph_t graph, cudaGraphRecaptureCallbackData* callbackData) noexcept
1046cdef extern from 'cuda_runtime_api.h' nogil:
1047 cudaError_t _static_cudaMemGetLocationInfo "cudaMemGetLocationInfo" (void* devPtr, size_t size, size_t summaryGranularity, size_t samplingGranularity, cudaMemLocation* location_out) noexcept
1050###############################################################################
1051# Wrapper functions
1052###############################################################################
1054cdef cudaError_t _cudaDeviceReset() except ?cudaErrorCallRequiresNewerDriver nogil:
1055 cdef bint usePTDS = cudaPythonInit()
1056 if usePTDS:
1057 return ptds._cudaDeviceReset()
1058 return _static_cudaDeviceReset()
1061cdef cudaError_t _cudaDeviceSynchronize() except ?cudaErrorCallRequiresNewerDriver nogil:
1062 cdef bint usePTDS = cudaPythonInit()
1063 if usePTDS:
1064 return ptds._cudaDeviceSynchronize()
1065 return _static_cudaDeviceSynchronize()
1068cdef cudaError_t _cudaDeviceSetLimit(cudaLimit limit, size_t value) except ?cudaErrorCallRequiresNewerDriver nogil:
1069 cdef bint usePTDS = cudaPythonInit()
1070 if usePTDS:
1071 return ptds._cudaDeviceSetLimit(limit, value)
1072 return _static_cudaDeviceSetLimit(limit, value)
1075cdef cudaError_t _cudaDeviceGetLimit(size_t* pValue, cudaLimit limit) except ?cudaErrorCallRequiresNewerDriver nogil:
1076 cdef bint usePTDS = cudaPythonInit()
1077 if usePTDS:
1078 return ptds._cudaDeviceGetLimit(pValue, limit)
1079 return _static_cudaDeviceGetLimit(pValue, limit)
1082cdef cudaError_t _cudaDeviceGetTexture1DLinearMaxWidth(size_t* maxWidthInElements, const cudaChannelFormatDesc* fmtDesc, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1083 cdef bint usePTDS = cudaPythonInit()
1084 if usePTDS:
1085 return ptds._cudaDeviceGetTexture1DLinearMaxWidth(maxWidthInElements, fmtDesc, device)
1086 return _static_cudaDeviceGetTexture1DLinearMaxWidth(maxWidthInElements, fmtDesc, device)
1089cdef cudaError_t _cudaDeviceGetCacheConfig(cudaFuncCache* pCacheConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1090 cdef bint usePTDS = cudaPythonInit()
1091 if usePTDS:
1092 return ptds._cudaDeviceGetCacheConfig(pCacheConfig)
1093 return _static_cudaDeviceGetCacheConfig(pCacheConfig)
1096cdef cudaError_t _cudaDeviceGetStreamPriorityRange(int* leastPriority, int* greatestPriority) except ?cudaErrorCallRequiresNewerDriver nogil:
1097 cdef bint usePTDS = cudaPythonInit()
1098 if usePTDS:
1099 return ptds._cudaDeviceGetStreamPriorityRange(leastPriority, greatestPriority)
1100 return _static_cudaDeviceGetStreamPriorityRange(leastPriority, greatestPriority)
1103cdef cudaError_t _cudaDeviceSetCacheConfig(cudaFuncCache cacheConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1104 cdef bint usePTDS = cudaPythonInit()
1105 if usePTDS:
1106 return ptds._cudaDeviceSetCacheConfig(cacheConfig) 2cblbmb
1107 return _static_cudaDeviceSetCacheConfig(cacheConfig) 2cblbmb
1110cdef cudaError_t _cudaDeviceGetByPCIBusId(int* device, const char* pciBusId) except ?cudaErrorCallRequiresNewerDriver nogil:
1111 cdef bint usePTDS = cudaPythonInit()
1112 if usePTDS:
1113 return ptds._cudaDeviceGetByPCIBusId(device, pciBusId)
1114 return _static_cudaDeviceGetByPCIBusId(device, pciBusId)
1117cdef cudaError_t _cudaDeviceGetPCIBusId(char* pciBusId, int len, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1118 cdef bint usePTDS = cudaPythonInit() 2cblbmb
1119 if usePTDS: 2a cblbmb
1120 return ptds._cudaDeviceGetPCIBusId(pciBusId, len, device)
1121 return _static_cudaDeviceGetPCIBusId(pciBusId, len, device) 2cblbmb
1124cdef cudaError_t _cudaIpcGetEventHandle(cudaIpcEventHandle_t* handle, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1125 cdef bint usePTDS = cudaPythonInit()
1126 if usePTDS:
1127 return ptds._cudaIpcGetEventHandle(handle, event)
1128 return _static_cudaIpcGetEventHandle(handle, event)
1131cdef cudaError_t _cudaIpcOpenEventHandle(cudaEvent_t* event, cudaIpcEventHandle_t handle) except ?cudaErrorCallRequiresNewerDriver nogil:
1132 cdef bint usePTDS = cudaPythonInit()
1133 if usePTDS:
1134 return ptds._cudaIpcOpenEventHandle(event, handle)
1135 return _static_cudaIpcOpenEventHandle(event, handle)
1138cdef cudaError_t _cudaIpcGetMemHandle(cudaIpcMemHandle_t* handle, void* devPtr) except ?cudaErrorCallRequiresNewerDriver nogil:
1139 cdef bint usePTDS = cudaPythonInit()
1140 if usePTDS:
1141 return ptds._cudaIpcGetMemHandle(handle, devPtr)
1142 return _static_cudaIpcGetMemHandle(handle, devPtr)
1145cdef cudaError_t _cudaIpcOpenMemHandle(void** devPtr, cudaIpcMemHandle_t handle, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1146 cdef bint usePTDS = cudaPythonInit()
1147 if usePTDS:
1148 return ptds._cudaIpcOpenMemHandle(devPtr, handle, flags)
1149 return _static_cudaIpcOpenMemHandle(devPtr, handle, flags)
1152cdef cudaError_t _cudaIpcCloseMemHandle(void* devPtr) except ?cudaErrorCallRequiresNewerDriver nogil:
1153 cdef bint usePTDS = cudaPythonInit()
1154 if usePTDS:
1155 return ptds._cudaIpcCloseMemHandle(devPtr)
1156 return _static_cudaIpcCloseMemHandle(devPtr)
1159cdef cudaError_t _cudaDeviceFlushGPUDirectRDMAWrites(cudaFlushGPUDirectRDMAWritesTarget target, cudaFlushGPUDirectRDMAWritesScope scope) except ?cudaErrorCallRequiresNewerDriver nogil:
1160 cdef bint usePTDS = cudaPythonInit()
1161 if usePTDS:
1162 return ptds._cudaDeviceFlushGPUDirectRDMAWrites(target, scope)
1163 return _static_cudaDeviceFlushGPUDirectRDMAWrites(target, scope)
1166cdef cudaError_t _cudaDeviceRegisterAsyncNotification(int device, cudaAsyncCallback callbackFunc, void* userData, cudaAsyncCallbackHandle_t* callback) except ?cudaErrorCallRequiresNewerDriver nogil:
1167 cdef bint usePTDS = cudaPythonInit()
1168 if usePTDS:
1169 return ptds._cudaDeviceRegisterAsyncNotification(device, callbackFunc, userData, callback)
1170 return _static_cudaDeviceRegisterAsyncNotification(device, callbackFunc, userData, callback)
1173cdef cudaError_t _cudaDeviceUnregisterAsyncNotification(int device, cudaAsyncCallbackHandle_t callback) except ?cudaErrorCallRequiresNewerDriver nogil:
1174 cdef bint usePTDS = cudaPythonInit()
1175 if usePTDS:
1176 return ptds._cudaDeviceUnregisterAsyncNotification(device, callback)
1177 return _static_cudaDeviceUnregisterAsyncNotification(device, callback)
1180cdef cudaError_t _cudaDeviceGetSharedMemConfig(cudaSharedMemConfig* pConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1181 cdef bint usePTDS = cudaPythonInit()
1182 if usePTDS:
1183 return ptds._cudaDeviceGetSharedMemConfig(pConfig)
1184 return _static_cudaDeviceGetSharedMemConfig(pConfig)
1187cdef cudaError_t _cudaDeviceSetSharedMemConfig(cudaSharedMemConfig config) except ?cudaErrorCallRequiresNewerDriver nogil:
1188 cdef bint usePTDS = cudaPythonInit()
1189 if usePTDS:
1190 return ptds._cudaDeviceSetSharedMemConfig(config)
1191 return _static_cudaDeviceSetSharedMemConfig(config)
1194cdef cudaError_t _cudaGetLastError() except ?cudaErrorCallRequiresNewerDriver nogil:
1195 cdef bint usePTDS = cudaPythonInit()
1196 if usePTDS:
1197 return ptds._cudaGetLastError() 1VN
1198 return _static_cudaGetLastError() 1VN
1201cdef cudaError_t _cudaPeekAtLastError() except ?cudaErrorCallRequiresNewerDriver nogil:
1202 cdef bint usePTDS = cudaPythonInit()
1203 if usePTDS:
1204 return ptds._cudaPeekAtLastError() 2V dbN
1205 return _static_cudaPeekAtLastError() 2V dbN
1208cdef const char* _cudaGetErrorName(cudaError_t error) except?NULL nogil:
1209 cdef bint usePTDS = cudaPythonInit() 1VGHN
1210 if usePTDS: 1aVGHN
1211 return ptds._cudaGetErrorName(error)
1212 return _static_cudaGetErrorName(error) 1aVGHN
1215cdef const char* _cudaGetErrorString(cudaError_t error) except?NULL nogil:
1216 cdef bint usePTDS = cudaPythonInit() 2V dbN
1217 if usePTDS: 2a V dbN
1218 return ptds._cudaGetErrorString(error) 2a jb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1219 return _static_cudaGetErrorString(error) 2a V dbjb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H N
1222cdef cudaError_t _cudaGetDeviceCount(int* count) except ?cudaErrorCallRequiresNewerDriver nogil:
1223 cdef bint usePTDS = cudaPythonInit()
1224 if usePTDS:
1225 return ptds._cudaGetDeviceCount(count)
1226 return _static_cudaGetDeviceCount(count)
1229cdef cudaError_t _cudaDeviceGetAttribute(int* value, cudaDeviceAttr attr, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1230 cdef bint usePTDS = cudaPythonInit() 2a jb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1231 if usePTDS: 2a jb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1232 return ptds._cudaDeviceGetAttribute(value, attr, device)
1233 return _static_cudaDeviceGetAttribute(value, attr, device) 2a jb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1236cdef cudaError_t _cudaDeviceGetDefaultMemPool(cudaMemPool_t* memPool, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1237 cdef bint usePTDS = cudaPythonInit()
1238 if usePTDS:
1239 return ptds._cudaDeviceGetDefaultMemPool(memPool, device)
1240 return _static_cudaDeviceGetDefaultMemPool(memPool, device)
1243cdef cudaError_t _cudaDeviceSetMemPool(int device, cudaMemPool_t memPool) except ?cudaErrorCallRequiresNewerDriver nogil:
1244 cdef bint usePTDS = cudaPythonInit() 2ab
1245 if usePTDS: 2a ab
1246 return ptds._cudaDeviceSetMemPool(device, memPool)
1247 return _static_cudaDeviceSetMemPool(device, memPool) 2ab
1250cdef cudaError_t _cudaDeviceGetMemPool(cudaMemPool_t* memPool, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1251 cdef bint usePTDS = cudaPythonInit() 2ab
1252 if usePTDS: 2a ab
1253 return ptds._cudaDeviceGetMemPool(memPool, device)
1254 return _static_cudaDeviceGetMemPool(memPool, device) 2ab
1257cdef cudaError_t _cudaDeviceGetNvSciSyncAttributes(void* nvSciSyncAttrList, int device, int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1258 cdef bint usePTDS = cudaPythonInit()
1259 if usePTDS:
1260 return ptds._cudaDeviceGetNvSciSyncAttributes(nvSciSyncAttrList, device, flags)
1261 return _static_cudaDeviceGetNvSciSyncAttributes(nvSciSyncAttrList, device, flags)
1264cdef cudaError_t _cudaDeviceGetP2PAttribute(int* value, cudaDeviceP2PAttr attr, int srcDevice, int dstDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
1265 cdef bint usePTDS = cudaPythonInit()
1266 if usePTDS:
1267 return ptds._cudaDeviceGetP2PAttribute(value, attr, srcDevice, dstDevice)
1268 return _static_cudaDeviceGetP2PAttribute(value, attr, srcDevice, dstDevice)
1271cdef cudaError_t _cudaChooseDevice(int* device, const cudaDeviceProp* prop) except ?cudaErrorCallRequiresNewerDriver nogil:
1272 cdef bint usePTDS = cudaPythonInit()
1273 if usePTDS:
1274 return ptds._cudaChooseDevice(device, prop) 1s
1275 return _static_cudaChooseDevice(device, prop) 1s
1278cdef cudaError_t _cudaInitDevice(int device, unsigned int deviceFlags, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1279 cdef bint usePTDS = cudaPythonInit()
1280 if usePTDS:
1281 return ptds._cudaInitDevice(device, deviceFlags, flags) 2kb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1282 return _static_cudaInitDevice(device, deviceFlags, flags) 2kb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1285cdef cudaError_t _cudaSetDevice(int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1286 cdef bint usePTDS = cudaPythonInit() 1s
1287 if usePTDS: 1as
1288 return ptds._cudaSetDevice(device)
1289 return _static_cudaSetDevice(device) 1s
1292cdef cudaError_t _cudaGetDevice(int* device) except ?cudaErrorCallRequiresNewerDriver nogil:
1293 cdef bint usePTDS = cudaPythonInit() 2kb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1294 if usePTDS: 2a kb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1295 return ptds._cudaGetDevice(device)
1296 return _static_cudaGetDevice(device) 2kb3 4 5 6 7 8 9 ! # $ % ' ( ) * + , - . / : ; = ? G H
1299cdef cudaError_t _cudaSetDeviceFlags(unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1300 cdef bint usePTDS = cudaPythonInit()
1301 if usePTDS:
1302 return ptds._cudaSetDeviceFlags(flags) 1eKfdjbCDFc^
1303 return _static_cudaSetDeviceFlags(flags) 1eKfdjbCDFc^
1306cdef cudaError_t _cudaGetDeviceFlags(unsigned int* flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1307 cdef bint usePTDS = cudaPythonInit()
1308 if usePTDS:
1309 return ptds._cudaGetDeviceFlags(flags) 1E
1310 return _static_cudaGetDeviceFlags(flags) 1E
1313cdef cudaError_t _cudaStreamCreate(cudaStream_t* pStream) except ?cudaErrorCallRequiresNewerDriver nogil:
1314 cdef bint usePTDS = cudaPythonInit() 1eKfdjbCDFc^
1315 if usePTDS: 1aeKfdjbCDFc^
1316 return ptds._cudaStreamCreate(pStream)
1317 return _static_cudaStreamCreate(pStream) 1eKfdjbCDFc^
1320cdef cudaError_t _cudaStreamCreateWithFlags(cudaStream_t* pStream, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1321 cdef bint usePTDS = cudaPythonInit() 1E
1322 if usePTDS: 1aE
1323 return ptds._cudaStreamCreateWithFlags(pStream, flags)
1324 return _static_cudaStreamCreateWithFlags(pStream, flags) 1E
1327cdef cudaError_t _cudaStreamCreateWithPriority(cudaStream_t* pStream, unsigned int flags, int priority) except ?cudaErrorCallRequiresNewerDriver nogil:
1328 cdef bint usePTDS = cudaPythonInit()
1329 if usePTDS:
1330 return ptds._cudaStreamCreateWithPriority(pStream, flags, priority)
1331 return _static_cudaStreamCreateWithPriority(pStream, flags, priority)
1334cdef cudaError_t _cudaStreamGetPriority(cudaStream_t hStream, int* priority) except ?cudaErrorCallRequiresNewerDriver nogil:
1335 cdef bint usePTDS = cudaPythonInit()
1336 if usePTDS:
1337 return ptds._cudaStreamGetPriority(hStream, priority)
1338 return _static_cudaStreamGetPriority(hStream, priority)
1341cdef cudaError_t _cudaStreamGetFlags(cudaStream_t hStream, unsigned int* flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1342 cdef bint usePTDS = cudaPythonInit()
1343 if usePTDS:
1344 return ptds._cudaStreamGetFlags(hStream, flags)
1345 return _static_cudaStreamGetFlags(hStream, flags)
1348cdef cudaError_t _cudaStreamGetId(cudaStream_t hStream, unsigned long long* streamId) except ?cudaErrorCallRequiresNewerDriver nogil:
1349 cdef bint usePTDS = cudaPythonInit()
1350 if usePTDS:
1351 return ptds._cudaStreamGetId(hStream, streamId)
1352 return _static_cudaStreamGetId(hStream, streamId)
1355cdef cudaError_t _cudaStreamGetDevice(cudaStream_t hStream, int* device) except ?cudaErrorCallRequiresNewerDriver nogil:
1356 cdef bint usePTDS = cudaPythonInit()
1357 if usePTDS:
1358 return ptds._cudaStreamGetDevice(hStream, device)
1359 return _static_cudaStreamGetDevice(hStream, device)
1362cdef cudaError_t _cudaCtxResetPersistingL2Cache() except ?cudaErrorCallRequiresNewerDriver nogil:
1363 cdef bint usePTDS = cudaPythonInit()
1364 if usePTDS:
1365 return ptds._cudaCtxResetPersistingL2Cache()
1366 return _static_cudaCtxResetPersistingL2Cache()
1369cdef cudaError_t _cudaStreamCopyAttributes(cudaStream_t dst, cudaStream_t src) except ?cudaErrorCallRequiresNewerDriver nogil:
1370 cdef bint usePTDS = cudaPythonInit()
1371 if usePTDS:
1372 return ptds._cudaStreamCopyAttributes(dst, src)
1373 return _static_cudaStreamCopyAttributes(dst, src)
1376cdef cudaError_t _cudaStreamGetAttribute(cudaStream_t hStream, cudaStreamAttrID attr, cudaStreamAttrValue* value_out) except ?cudaErrorCallRequiresNewerDriver nogil:
1377 cdef bint usePTDS = cudaPythonInit()
1378 if usePTDS:
1379 return ptds._cudaStreamGetAttribute(hStream, attr, value_out) 1IeKDFc^
1380 return _static_cudaStreamGetAttribute(hStream, attr, value_out) 1IeKDFc^
1383cdef cudaError_t _cudaStreamSetAttribute(cudaStream_t hStream, cudaStreamAttrID attr, const cudaStreamAttrValue* value) except ?cudaErrorCallRequiresNewerDriver nogil:
1384 cdef bint usePTDS = cudaPythonInit()
1385 if usePTDS:
1386 return ptds._cudaStreamSetAttribute(hStream, attr, value)
1387 return _static_cudaStreamSetAttribute(hStream, attr, value)
1390cdef cudaError_t _cudaStreamDestroy(cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1391 cdef bint usePTDS = cudaPythonInit() 1IeKDFc^
1392 if usePTDS: 1aIeKDFc^
1393 return ptds._cudaStreamDestroy(stream) 1F
1394 return _static_cudaStreamDestroy(stream) 1IeKDFc^
1397cdef cudaError_t _cudaStreamWaitEvent(cudaStream_t stream, cudaEvent_t event, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1398 cdef bint usePTDS = cudaPythonInit()
1399 if usePTDS:
1400 return ptds._cudaStreamWaitEvent(stream, event, flags) 1fdjbDFc
1401 return _static_cudaStreamWaitEvent(stream, event, flags) 1fdjbDFc
1404cdef cudaError_t _cudaStreamAddCallback(cudaStream_t stream, cudaStreamCallback_t callback, void* userData, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1405 cdef bint usePTDS = cudaPythonInit() 1F
1406 if usePTDS: 1aF
1407 return ptds._cudaStreamAddCallback(stream, callback, userData, flags)
1408 return _static_cudaStreamAddCallback(stream, callback, userData, flags) 1F
1411cdef cudaError_t _cudaStreamSynchronize(cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1412 cdef bint usePTDS = cudaPythonInit() 1fdjbDFc
1413 if usePTDS: 1afdjbDFc
1414 return ptds._cudaStreamSynchronize(stream)
1415 return _static_cudaStreamSynchronize(stream) 1fdjbDFc
1418cdef cudaError_t _cudaStreamQuery(cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1419 cdef bint usePTDS = cudaPythonInit()
1420 if usePTDS:
1421 return ptds._cudaStreamQuery(stream) 1Cc
1422 return _static_cudaStreamQuery(stream) 1Cc
1425cdef cudaError_t _cudaStreamAttachMemAsync(cudaStream_t stream, void* devPtr, size_t length, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1426 cdef bint usePTDS = cudaPythonInit()
1427 if usePTDS:
1428 return ptds._cudaStreamAttachMemAsync(stream, devPtr, length, flags)
1429 return _static_cudaStreamAttachMemAsync(stream, devPtr, length, flags)
1432cdef cudaError_t _cudaStreamBeginCapture(cudaStream_t stream, cudaStreamCaptureMode mode) except ?cudaErrorCallRequiresNewerDriver nogil:
1433 cdef bint usePTDS = cudaPythonInit() 1Cc
1434 if usePTDS: 1aCc
1435 return ptds._cudaStreamBeginCapture(stream, mode) 2fb
1436 return _static_cudaStreamBeginCapture(stream, mode) 2fbC c
1439cdef cudaError_t _cudaStreamBeginCaptureToGraph(cudaStream_t stream, cudaGraph_t graph, const cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaStreamCaptureMode mode) except ?cudaErrorCallRequiresNewerDriver nogil:
1440 cdef bint usePTDS = cudaPythonInit()
1441 if usePTDS:
1442 return ptds._cudaStreamBeginCaptureToGraph(stream, graph, dependencies, dependencyData, numDependencies, mode) 1Cc
1443 return _static_cudaStreamBeginCaptureToGraph(stream, graph, dependencies, dependencyData, numDependencies, mode) 1Cc
1446cdef cudaError_t _cudaThreadExchangeStreamCaptureMode(cudaStreamCaptureMode* mode) except ?cudaErrorCallRequiresNewerDriver nogil:
1447 cdef bint usePTDS = cudaPythonInit() 2fb
1448 if usePTDS: 2a fb
1449 return ptds._cudaThreadExchangeStreamCaptureMode(mode)
1450 return _static_cudaThreadExchangeStreamCaptureMode(mode) 2fb
1453cdef cudaError_t _cudaStreamEndCapture(cudaStream_t stream, cudaGraph_t* pGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
1454 cdef bint usePTDS = cudaPythonInit() 1Cc
1455 if usePTDS: 1aCc
1456 return ptds._cudaStreamEndCapture(stream, pGraph)
1457 return _static_cudaStreamEndCapture(stream, pGraph) 1Cc
1460cdef cudaError_t _cudaStreamIsCapturing(cudaStream_t stream, cudaStreamCaptureStatus* pCaptureStatus) except ?cudaErrorCallRequiresNewerDriver nogil:
1461 cdef bint usePTDS = cudaPythonInit()
1462 if usePTDS:
1463 return ptds._cudaStreamIsCapturing(stream, pCaptureStatus) 1[
1464 return _static_cudaStreamIsCapturing(stream, pCaptureStatus) 1[
1467cdef cudaError_t _cudaStreamUpdateCaptureDependencies(cudaStream_t stream, cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1468 cdef bint usePTDS = cudaPythonInit()
1469 if usePTDS:
1470 return ptds._cudaStreamUpdateCaptureDependencies(stream, dependencies, dependencyData, numDependencies, flags)
1471 return _static_cudaStreamUpdateCaptureDependencies(stream, dependencies, dependencyData, numDependencies, flags)
1474cdef cudaError_t _cudaEventCreate(cudaEvent_t* event) except ?cudaErrorCallRequiresNewerDriver nogil:
1475 cdef bint usePTDS = cudaPythonInit() 1[
1476 if usePTDS: 1a[
1477 return ptds._cudaEventCreate(event)
1478 return _static_cudaEventCreate(event) 1[
1481cdef cudaError_t _cudaEventCreateWithFlags(cudaEvent_t* event, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1482 cdef bint usePTDS = cudaPythonInit()
1483 if usePTDS:
1484 return ptds._cudaEventCreateWithFlags(event, flags)
1485 return _static_cudaEventCreateWithFlags(event, flags)
1488cdef cudaError_t _cudaEventRecord(cudaEvent_t event, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1489 cdef bint usePTDS = cudaPythonInit()
1490 if usePTDS:
1491 return ptds._cudaEventRecord(event, stream)
1492 return _static_cudaEventRecord(event, stream)
1495cdef cudaError_t _cudaEventRecordWithFlags(cudaEvent_t event, cudaStream_t stream, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1496 cdef bint usePTDS = cudaPythonInit()
1497 if usePTDS:
1498 return ptds._cudaEventRecordWithFlags(event, stream, flags)
1499 return _static_cudaEventRecordWithFlags(event, stream, flags)
1502cdef cudaError_t _cudaEventQuery(cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1503 cdef bint usePTDS = cudaPythonInit()
1504 if usePTDS:
1505 return ptds._cudaEventQuery(event) 1[
1506 return _static_cudaEventQuery(event) 1[
1509cdef cudaError_t _cudaEventSynchronize(cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1510 cdef bint usePTDS = cudaPythonInit()
1511 if usePTDS:
1512 return ptds._cudaEventSynchronize(event)
1513 return _static_cudaEventSynchronize(event)
1516cdef cudaError_t _cudaEventDestroy(cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1517 cdef bint usePTDS = cudaPythonInit() 1[
1518 if usePTDS: 1a[
1519 return ptds._cudaEventDestroy(event)
1520 return _static_cudaEventDestroy(event) 1[
1523cdef cudaError_t _cudaEventElapsedTime(float* ms, cudaEvent_t start, cudaEvent_t end) except ?cudaErrorCallRequiresNewerDriver nogil:
1524 cdef bint usePTDS = cudaPythonInit()
1525 if usePTDS:
1526 return ptds._cudaEventElapsedTime(ms, start, end)
1527 return _static_cudaEventElapsedTime(ms, start, end)
1530cdef cudaError_t _cudaImportExternalMemory(cudaExternalMemory_t* extMem_out, const cudaExternalMemoryHandleDesc* memHandleDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1531 cdef bint usePTDS = cudaPythonInit()
1532 if usePTDS:
1533 return ptds._cudaImportExternalMemory(extMem_out, memHandleDesc)
1534 return _static_cudaImportExternalMemory(extMem_out, memHandleDesc)
1537cdef cudaError_t _cudaExternalMemoryGetMappedBuffer(void** devPtr, cudaExternalMemory_t extMem, const cudaExternalMemoryBufferDesc* bufferDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1538 cdef bint usePTDS = cudaPythonInit()
1539 if usePTDS:
1540 return ptds._cudaExternalMemoryGetMappedBuffer(devPtr, extMem, bufferDesc)
1541 return _static_cudaExternalMemoryGetMappedBuffer(devPtr, extMem, bufferDesc)
1544cdef cudaError_t _cudaExternalMemoryGetMappedMipmappedArray(cudaMipmappedArray_t* mipmap, cudaExternalMemory_t extMem, const cudaExternalMemoryMipmappedArrayDesc* mipmapDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1545 cdef bint usePTDS = cudaPythonInit()
1546 if usePTDS:
1547 return ptds._cudaExternalMemoryGetMappedMipmappedArray(mipmap, extMem, mipmapDesc)
1548 return _static_cudaExternalMemoryGetMappedMipmappedArray(mipmap, extMem, mipmapDesc)
1551cdef cudaError_t _cudaDestroyExternalMemory(cudaExternalMemory_t extMem) except ?cudaErrorCallRequiresNewerDriver nogil:
1552 cdef bint usePTDS = cudaPythonInit()
1553 if usePTDS:
1554 return ptds._cudaDestroyExternalMemory(extMem)
1555 return _static_cudaDestroyExternalMemory(extMem)
1558cdef cudaError_t _cudaImportExternalSemaphore(cudaExternalSemaphore_t* extSem_out, const cudaExternalSemaphoreHandleDesc* semHandleDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1559 cdef bint usePTDS = cudaPythonInit()
1560 if usePTDS:
1561 return ptds._cudaImportExternalSemaphore(extSem_out, semHandleDesc)
1562 return _static_cudaImportExternalSemaphore(extSem_out, semHandleDesc)
1565cdef cudaError_t _cudaDestroyExternalSemaphore(cudaExternalSemaphore_t extSem) except ?cudaErrorCallRequiresNewerDriver nogil:
1566 cdef bint usePTDS = cudaPythonInit()
1567 if usePTDS:
1568 return ptds._cudaDestroyExternalSemaphore(extSem)
1569 return _static_cudaDestroyExternalSemaphore(extSem)
1572cdef cudaError_t _cudaFuncSetCacheConfig(const void* func, cudaFuncCache cacheConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1573 cdef bint usePTDS = cudaPythonInit()
1574 if usePTDS:
1575 return ptds._cudaFuncSetCacheConfig(func, cacheConfig)
1576 return _static_cudaFuncSetCacheConfig(func, cacheConfig)
1579cdef cudaError_t _cudaFuncGetAttributes(cudaFuncAttributes* attr, const void* func) except ?cudaErrorCallRequiresNewerDriver nogil:
1580 cdef bint usePTDS = cudaPythonInit()
1581 if usePTDS:
1582 return ptds._cudaFuncGetAttributes(attr, func)
1583 return _static_cudaFuncGetAttributes(attr, func)
1586cdef cudaError_t _cudaFuncSetAttribute(const void* func, cudaFuncAttribute attr, int value) except ?cudaErrorCallRequiresNewerDriver nogil:
1587 cdef bint usePTDS = cudaPythonInit()
1588 if usePTDS:
1589 return ptds._cudaFuncSetAttribute(func, attr, value)
1590 return _static_cudaFuncSetAttribute(func, attr, value)
1593cdef cudaError_t _cudaFuncGetName(const char** name, const void* func) except ?cudaErrorCallRequiresNewerDriver nogil:
1594 cdef bint usePTDS = cudaPythonInit()
1595 if usePTDS:
1596 return ptds._cudaFuncGetName(name, func) 1Dc
1597 return _static_cudaFuncGetName(name, func) 1Dc
1600cdef cudaError_t _cudaFuncGetParamInfo(const void* func, size_t paramIndex, size_t* paramOffset, size_t* paramSize) except ?cudaErrorCallRequiresNewerDriver nogil:
1601 cdef bint usePTDS = cudaPythonInit()
1602 if usePTDS:
1603 return ptds._cudaFuncGetParamInfo(func, paramIndex, paramOffset, paramSize)
1604 return _static_cudaFuncGetParamInfo(func, paramIndex, paramOffset, paramSize)
1607cdef cudaError_t _cudaLaunchHostFunc(cudaStream_t stream, cudaHostFn_t fn, void* userData) except ?cudaErrorCallRequiresNewerDriver nogil:
1608 cdef bint usePTDS = cudaPythonInit() 1Dc
1609 if usePTDS: 1aDc
1610 return ptds._cudaLaunchHostFunc(stream, fn, userData)
1611 return _static_cudaLaunchHostFunc(stream, fn, userData) 1Dc
1614cdef cudaError_t _cudaFuncSetSharedMemConfig(const void* func, cudaSharedMemConfig config) except ?cudaErrorCallRequiresNewerDriver nogil:
1615 cdef bint usePTDS = cudaPythonInit()
1616 if usePTDS:
1617 return ptds._cudaFuncSetSharedMemConfig(func, config)
1618 return _static_cudaFuncSetSharedMemConfig(func, config)
1621cdef cudaError_t _cudaOccupancyMaxActiveBlocksPerMultiprocessor(int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize) except ?cudaErrorCallRequiresNewerDriver nogil:
1622 cdef bint usePTDS = cudaPythonInit()
1623 if usePTDS:
1624 return ptds._cudaOccupancyMaxActiveBlocksPerMultiprocessor(numBlocks, func, blockSize, dynamicSMemSize)
1625 return _static_cudaOccupancyMaxActiveBlocksPerMultiprocessor(numBlocks, func, blockSize, dynamicSMemSize)
1628cdef cudaError_t _cudaOccupancyAvailableDynamicSMemPerBlock(size_t* dynamicSmemSize, const void* func, int numBlocks, int blockSize) except ?cudaErrorCallRequiresNewerDriver nogil:
1629 cdef bint usePTDS = cudaPythonInit()
1630 if usePTDS:
1631 return ptds._cudaOccupancyAvailableDynamicSMemPerBlock(dynamicSmemSize, func, numBlocks, blockSize)
1632 return _static_cudaOccupancyAvailableDynamicSMemPerBlock(dynamicSmemSize, func, numBlocks, blockSize)
1635cdef cudaError_t _cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags(int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1636 cdef bint usePTDS = cudaPythonInit()
1637 if usePTDS:
1638 return ptds._cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags(numBlocks, func, blockSize, dynamicSMemSize, flags) 1mfdgbhiMr
1639 return _static_cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags(numBlocks, func, blockSize, dynamicSMemSize, flags) 1mfdgbhiMr
1642cdef cudaError_t _cudaMallocManaged(void** devPtr, size_t size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1643 cdef bint usePTDS = cudaPythonInit()
1644 if usePTDS:
1645 return ptds._cudaMallocManaged(devPtr, size, flags)
1646 return _static_cudaMallocManaged(devPtr, size, flags)
1649cdef cudaError_t _cudaMalloc(void** devPtr, size_t size) except ?cudaErrorCallRequiresNewerDriver nogil:
1650 cdef bint usePTDS = cudaPythonInit() 1mfdgbhiMr
1651 if usePTDS: 1amfdgbhiMr
1652 return ptds._cudaMalloc(devPtr, size)
1653 return _static_cudaMalloc(devPtr, size) 1mfdgbhiMr
1656cdef cudaError_t _cudaMallocHost(void** ptr, size_t size) except ?cudaErrorCallRequiresNewerDriver nogil:
1657 cdef bint usePTDS = cudaPythonInit()
1658 if usePTDS:
1659 return ptds._cudaMallocHost(ptr, size) 1xytlgpjbhkiq
1660 return _static_cudaMallocHost(ptr, size) 1xytlgpjbhkiq
1663cdef cudaError_t _cudaMallocPitch(void** devPtr, size_t* pitch, size_t width, size_t height) except ?cudaErrorCallRequiresNewerDriver nogil:
1664 cdef bint usePTDS = cudaPythonInit()
1665 if usePTDS:
1666 return ptds._cudaMallocPitch(devPtr, pitch, width, height) 1mfdgbhiABMNr
1667 return _static_cudaMallocPitch(devPtr, pitch, width, height) 1mfdgbhiABMNr
1670cdef cudaError_t _cudaMallocArray(cudaArray_t* array, const cudaChannelFormatDesc* desc, size_t width, size_t height, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1671 cdef bint usePTDS = cudaPythonInit() 1xytlgpjbhkiq
1672 if usePTDS: 1axytlgpjbhkiq
1673 return ptds._cudaMallocArray(array, desc, width, height, flags) 1RSTUm_`{|r
1674 return _static_cudaMallocArray(array, desc, width, height, flags) 1RSTUmxytlgpjbhkiq_`{|r
1677cdef cudaError_t _cudaFree(void* devPtr) except ?cudaErrorCallRequiresNewerDriver nogil:
1678 cdef bint usePTDS = cudaPythonInit() 1mfdgbhiABMGHNr
1679 if usePTDS: 1amfdgbhiABMGHNr
1680 return ptds._cudaFree(devPtr) 1xylgpjbhkiq
1681 return _static_cudaFree(devPtr) 1mxyfdlgpjbhkiqABMGHNr
1684cdef cudaError_t _cudaFreeHost(void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
1685 cdef bint usePTDS = cudaPythonInit() 1RSTUm_`{|r
1686 if usePTDS: 1aRSTUm_`{|r
1687 return ptds._cudaFreeHost(ptr)
1688 return _static_cudaFreeHost(ptr) 1RSTUm_`{|r
1691cdef cudaError_t _cudaFreeArray(cudaArray_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
1692 cdef bint usePTDS = cudaPythonInit() 1xylgpjbhkiq
1693 if usePTDS: 1axylgpjbhkiq
1694 return ptds._cudaFreeArray(array) 1RSTUm_`{|r
1695 return _static_cudaFreeArray(array) 1RSTUmxylgpjbhkiq_`{|r
1698cdef cudaError_t _cudaFreeMipmappedArray(cudaMipmappedArray_t mipmappedArray) except ?cudaErrorCallRequiresNewerDriver nogil:
1699 cdef bint usePTDS = cudaPythonInit() 1~
1700 if usePTDS: 1a~
1701 return ptds._cudaFreeMipmappedArray(mipmappedArray) 11
1702 return _static_cudaFreeMipmappedArray(mipmappedArray) 1~1
1705cdef cudaError_t _cudaHostAlloc(void** pHost, size_t size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1706 cdef bint usePTDS = cudaPythonInit() 1RSTUm_`{|r
1707 if usePTDS: 1aRSTUm_`{|r
1708 return ptds._cudaHostAlloc(pHost, size, flags) 11
1709 return _static_cudaHostAlloc(pHost, size, flags) 1RSTUm1_`{|r
1712cdef cudaError_t _cudaHostRegister(void* ptr, size_t size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1713 cdef bint usePTDS = cudaPythonInit() 11
1714 if usePTDS: 1a1
1715 return ptds._cudaHostRegister(ptr, size, flags)
1716 return _static_cudaHostRegister(ptr, size, flags) 11
1719cdef cudaError_t _cudaHostUnregister(void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
1720 cdef bint usePTDS = cudaPythonInit() 11
1721 if usePTDS: 1a1
1722 return ptds._cudaHostUnregister(ptr)
1723 return _static_cudaHostUnregister(ptr) 11
1726cdef cudaError_t _cudaHostGetDevicePointer(void** pDevice, void* pHost, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1727 cdef bint usePTDS = cudaPythonInit()
1728 if usePTDS:
1729 return ptds._cudaHostGetDevicePointer(pDevice, pHost, flags) 1AB
1730 return _static_cudaHostGetDevicePointer(pDevice, pHost, flags) 1AB
1733cdef cudaError_t _cudaHostGetFlags(unsigned int* pFlags, void* pHost) except ?cudaErrorCallRequiresNewerDriver nogil:
1734 cdef bint usePTDS = cudaPythonInit()
1735 if usePTDS:
1736 return ptds._cudaHostGetFlags(pFlags, pHost)
1737 return _static_cudaHostGetFlags(pFlags, pHost)
1740cdef cudaError_t _cudaMalloc3D(cudaPitchedPtr* pitchedDevPtr, cudaExtent extent) except ?cudaErrorCallRequiresNewerDriver nogil:
1741 cdef bint usePTDS = cudaPythonInit() 1AB
1742 if usePTDS: 1aAB
1743 return ptds._cudaMalloc3D(pitchedDevPtr, extent)
1744 return _static_cudaMalloc3D(pitchedDevPtr, extent) 1AB
1747cdef cudaError_t _cudaMalloc3DArray(cudaArray_t* array, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1748 cdef bint usePTDS = cudaPythonInit()
1749 if usePTDS:
1750 return ptds._cudaMalloc3DArray(array, desc, extent, flags)
1751 return _static_cudaMalloc3DArray(array, desc, extent, flags)
1754cdef cudaError_t _cudaMallocMipmappedArray(cudaMipmappedArray_t* mipmappedArray, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int numLevels, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1755 cdef bint usePTDS = cudaPythonInit() 1~
1756 if usePTDS: 1a~
1757 return ptds._cudaMallocMipmappedArray(mipmappedArray, desc, extent, numLevels, flags)
1758 return _static_cudaMallocMipmappedArray(mipmappedArray, desc, extent, numLevels, flags) 1~
1761cdef cudaError_t _cudaGetMipmappedArrayLevel(cudaArray_t* levelArray, cudaMipmappedArray_const_t mipmappedArray, unsigned int level) except ?cudaErrorCallRequiresNewerDriver nogil:
1762 cdef bint usePTDS = cudaPythonInit()
1763 if usePTDS:
1764 return ptds._cudaGetMipmappedArrayLevel(levelArray, mipmappedArray, level) 1h
1765 return _static_cudaGetMipmappedArrayLevel(levelArray, mipmappedArray, level) 1h
1768cdef cudaError_t _cudaMemcpy3D(const cudaMemcpy3DParms* p) except ?cudaErrorCallRequiresNewerDriver nogil:
1769 cdef bint usePTDS = cudaPythonInit()
1770 if usePTDS:
1771 return ptds._cudaMemcpy3D(p) 1j
1772 return _static_cudaMemcpy3D(p) 1j
1775cdef cudaError_t _cudaMemcpy3DPeer(const cudaMemcpy3DPeerParms* p) except ?cudaErrorCallRequiresNewerDriver nogil:
1776 cdef bint usePTDS = cudaPythonInit() 1h
1777 if usePTDS: 1ah
1778 return ptds._cudaMemcpy3DPeer(p) 1b
1779 return _static_cudaMemcpy3DPeer(p) 1bh
1782cdef cudaError_t _cudaMemcpy3DAsync(const cudaMemcpy3DParms* p, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1783 cdef bint usePTDS = cudaPythonInit() 1j
1784 if usePTDS: 1aj
1785 return ptds._cudaMemcpy3DAsync(p, stream)
1786 return _static_cudaMemcpy3DAsync(p, stream) 1j
1789cdef cudaError_t _cudaMemcpy3DPeerAsync(const cudaMemcpy3DPeerParms* p, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1790 cdef bint usePTDS = cudaPythonInit() 1b
1791 if usePTDS: 1ab
1792 return ptds._cudaMemcpy3DPeerAsync(p, stream) 1x
1793 return _static_cudaMemcpy3DPeerAsync(p, stream) 1xb
1796cdef cudaError_t _cudaMemGetInfo(size_t* free, size_t* total) except ?cudaErrorCallRequiresNewerDriver nogil:
1797 cdef bint usePTDS = cudaPythonInit()
1798 if usePTDS:
1799 return ptds._cudaMemGetInfo(free, total)
1800 return _static_cudaMemGetInfo(free, total)
1803cdef cudaError_t _cudaArrayGetInfo(cudaChannelFormatDesc* desc, cudaExtent* extent, unsigned int* flags, cudaArray_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
1804 cdef bint usePTDS = cudaPythonInit() 1x
1805 if usePTDS: 1ax
1806 return ptds._cudaArrayGetInfo(desc, extent, flags, array)
1807 return _static_cudaArrayGetInfo(desc, extent, flags, array) 1x
1810cdef cudaError_t _cudaArrayGetPlane(cudaArray_t* pPlaneArray, cudaArray_t hArray, unsigned int planeIdx) except ?cudaErrorCallRequiresNewerDriver nogil:
1811 cdef bint usePTDS = cudaPythonInit()
1812 if usePTDS:
1813 return ptds._cudaArrayGetPlane(pPlaneArray, hArray, planeIdx)
1814 return _static_cudaArrayGetPlane(pPlaneArray, hArray, planeIdx)
1817cdef cudaError_t _cudaArrayGetMemoryRequirements(cudaArrayMemoryRequirements* memoryRequirements, cudaArray_t array, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1818 cdef bint usePTDS = cudaPythonInit()
1819 if usePTDS:
1820 return ptds._cudaArrayGetMemoryRequirements(memoryRequirements, array, device)
1821 return _static_cudaArrayGetMemoryRequirements(memoryRequirements, array, device)
1824cdef cudaError_t _cudaMipmappedArrayGetMemoryRequirements(cudaArrayMemoryRequirements* memoryRequirements, cudaMipmappedArray_t mipmap, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1825 cdef bint usePTDS = cudaPythonInit()
1826 if usePTDS:
1827 return ptds._cudaMipmappedArrayGetMemoryRequirements(memoryRequirements, mipmap, device)
1828 return _static_cudaMipmappedArrayGetMemoryRequirements(memoryRequirements, mipmap, device)
1831cdef cudaError_t _cudaArrayGetSparseProperties(cudaArraySparseProperties* sparseProperties, cudaArray_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
1832 cdef bint usePTDS = cudaPythonInit()
1833 if usePTDS:
1834 return ptds._cudaArrayGetSparseProperties(sparseProperties, array) 1gbhiABM@
1835 return _static_cudaArrayGetSparseProperties(sparseProperties, array) 1gbhiABM@
1838cdef cudaError_t _cudaMipmappedArrayGetSparseProperties(cudaArraySparseProperties* sparseProperties, cudaMipmappedArray_t mipmap) except ?cudaErrorCallRequiresNewerDriver nogil:
1839 cdef bint usePTDS = cudaPythonInit() 1~
1840 if usePTDS: 1a~
1841 return ptds._cudaMipmappedArrayGetSparseProperties(sparseProperties, mipmap)
1842 return _static_cudaMipmappedArrayGetSparseProperties(sparseProperties, mipmap) 1~
1845cdef cudaError_t _cudaMemcpy(void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1846 cdef bint usePTDS = cudaPythonInit() 1gbhiABM@
1847 if usePTDS: 1agbhiABM@
1848 return ptds._cudaMemcpy(dst, src, count, kind)
1849 return _static_cudaMemcpy(dst, src, count, kind) 1gbhiABM@
1852cdef cudaError_t _cudaMemcpyPeer(void* dst, int dstDevice, const void* src, int srcDevice, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
1853 cdef bint usePTDS = cudaPythonInit()
1854 if usePTDS:
1855 return ptds._cudaMemcpyPeer(dst, dstDevice, src, srcDevice, count) 1lgpk
1856 return _static_cudaMemcpyPeer(dst, dstDevice, src, srcDevice, count) 1lgpk
1859cdef cudaError_t _cudaMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1860 cdef bint usePTDS = cudaPythonInit()
1861 if usePTDS:
1862 return ptds._cudaMemcpy2D(dst, dpitch, src, spitch, width, height, kind) 1lgpjbhk
1863 return _static_cudaMemcpy2D(dst, dpitch, src, spitch, width, height, kind) 1lgpjbhk
1866cdef cudaError_t _cudaMemcpy2DToArray(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1867 cdef bint usePTDS = cudaPythonInit() 1lgpk
1868 if usePTDS: 1algpk
1869 return ptds._cudaMemcpy2DToArray(dst, wOffset, hOffset, src, spitch, width, height, kind) 1l
1870 return _static_cudaMemcpy2DToArray(dst, wOffset, hOffset, src, spitch, width, height, kind) 1lgpk
1873cdef cudaError_t _cudaMemcpy2DFromArray(void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1874 cdef bint usePTDS = cudaPythonInit() 1lgpjbhk
1875 if usePTDS: 1algpjbhk
1876 return ptds._cudaMemcpy2DFromArray(dst, dpitch, src, wOffset, hOffset, width, height, kind) 1mr
1877 return _static_cudaMemcpy2DFromArray(dst, dpitch, src, wOffset, hOffset, width, height, kind) 1mlgpjbhkr
1880cdef cudaError_t _cudaMemcpy2DArrayToArray(cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1881 cdef bint usePTDS = cudaPythonInit() 1l
1882 if usePTDS: 1al
1883 return ptds._cudaMemcpy2DArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, width, height, kind)
1884 return _static_cudaMemcpy2DArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, width, height, kind) 1l
1887cdef cudaError_t _cudaMemcpyAsync(void* dst, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1888 cdef bint usePTDS = cudaPythonInit() 1mr
1889 if usePTDS: 1amr
1890 return ptds._cudaMemcpyAsync(dst, src, count, kind, stream)
1891 return _static_cudaMemcpyAsync(dst, src, count, kind, stream) 1mr
1894cdef cudaError_t _cudaMemcpyPeerAsync(void* dst, int dstDevice, const void* src, int srcDevice, size_t count, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1895 cdef bint usePTDS = cudaPythonInit()
1896 if usePTDS:
1897 return ptds._cudaMemcpyPeerAsync(dst, dstDevice, src, srcDevice, count, stream)
1898 return _static_cudaMemcpyPeerAsync(dst, dstDevice, src, srcDevice, count, stream)
1901cdef cudaError_t _cudaMemcpyBatchAsync(const void** dsts, const void** srcs, const size_t* sizes, size_t count, cudaMemcpyAttributes* attrs, size_t* attrsIdxs, size_t numAttrs, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1902 cdef bint usePTDS = cudaPythonInit()
1903 if usePTDS:
1904 return ptds._cudaMemcpyBatchAsync(dsts, srcs, sizes, count, attrs, attrsIdxs, numAttrs, stream)
1905 return _static_cudaMemcpyBatchAsync(dsts, srcs, sizes, count, attrs, attrsIdxs, numAttrs, stream)
1908cdef cudaError_t _cudaMemcpy3DBatchAsync(size_t numOps, cudaMemcpy3DBatchOp* opList, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1909 cdef bint usePTDS = cudaPythonInit()
1910 if usePTDS:
1911 return ptds._cudaMemcpy3DBatchAsync(numOps, opList, flags, stream)
1912 return _static_cudaMemcpy3DBatchAsync(numOps, opList, flags, stream)
1915cdef cudaError_t _cudaMemcpy2DAsync(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1916 cdef bint usePTDS = cudaPythonInit()
1917 if usePTDS:
1918 return ptds._cudaMemcpy2DAsync(dst, dpitch, src, spitch, width, height, kind, stream)
1919 return _static_cudaMemcpy2DAsync(dst, dpitch, src, spitch, width, height, kind, stream)
1922cdef cudaError_t _cudaMemcpy2DToArrayAsync(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1923 cdef bint usePTDS = cudaPythonInit()
1924 if usePTDS:
1925 return ptds._cudaMemcpy2DToArrayAsync(dst, wOffset, hOffset, src, spitch, width, height, kind, stream) 1@
1926 return _static_cudaMemcpy2DToArrayAsync(dst, wOffset, hOffset, src, spitch, width, height, kind, stream) 1@
1929cdef cudaError_t _cudaMemcpy2DFromArrayAsync(void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1930 cdef bint usePTDS = cudaPythonInit()
1931 if usePTDS:
1932 return ptds._cudaMemcpy2DFromArrayAsync(dst, dpitch, src, wOffset, hOffset, width, height, kind, stream)
1933 return _static_cudaMemcpy2DFromArrayAsync(dst, dpitch, src, wOffset, hOffset, width, height, kind, stream)
1936cdef cudaError_t _cudaMemset(void* devPtr, int value, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
1937 cdef bint usePTDS = cudaPythonInit() 1@
1938 if usePTDS: 1a@
1939 return ptds._cudaMemset(devPtr, value, count) 1AB
1940 return _static_cudaMemset(devPtr, value, count) 1AB@
1943cdef cudaError_t _cudaMemset2D(void* devPtr, size_t pitch, int value, size_t width, size_t height) except ?cudaErrorCallRequiresNewerDriver nogil:
1944 cdef bint usePTDS = cudaPythonInit()
1945 if usePTDS:
1946 return ptds._cudaMemset2D(devPtr, pitch, value, width, height)
1947 return _static_cudaMemset2D(devPtr, pitch, value, width, height)
1950cdef cudaError_t _cudaMemset3D(cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent) except ?cudaErrorCallRequiresNewerDriver nogil:
1951 cdef bint usePTDS = cudaPythonInit() 1AB
1952 if usePTDS: 1aAB
1953 return ptds._cudaMemset3D(pitchedDevPtr, value, extent)
1954 return _static_cudaMemset3D(pitchedDevPtr, value, extent) 1AB
1957cdef cudaError_t _cudaMemsetAsync(void* devPtr, int value, size_t count, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1958 cdef bint usePTDS = cudaPythonInit()
1959 if usePTDS:
1960 return ptds._cudaMemsetAsync(devPtr, value, count, stream)
1961 return _static_cudaMemsetAsync(devPtr, value, count, stream)
1964cdef cudaError_t _cudaMemset2DAsync(void* devPtr, size_t pitch, int value, size_t width, size_t height, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1965 cdef bint usePTDS = cudaPythonInit()
1966 if usePTDS:
1967 return ptds._cudaMemset2DAsync(devPtr, pitch, value, width, height, stream)
1968 return _static_cudaMemset2DAsync(devPtr, pitch, value, width, height, stream)
1971cdef cudaError_t _cudaMemset3DAsync(cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1972 cdef bint usePTDS = cudaPythonInit()
1973 if usePTDS:
1974 return ptds._cudaMemset3DAsync(pitchedDevPtr, value, extent, stream)
1975 return _static_cudaMemset3DAsync(pitchedDevPtr, value, extent, stream)
1978cdef cudaError_t _cudaMemPrefetchAsync(const void* devPtr, size_t count, cudaMemLocation location, unsigned int flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1979 cdef bint usePTDS = cudaPythonInit()
1980 if usePTDS:
1981 return ptds._cudaMemPrefetchAsync(devPtr, count, location, flags, stream)
1982 return _static_cudaMemPrefetchAsync(devPtr, count, location, flags, stream)
1985cdef cudaError_t _cudaMemAdvise(const void* devPtr, size_t count, cudaMemoryAdvise advice, cudaMemLocation location) except ?cudaErrorCallRequiresNewerDriver nogil:
1986 cdef bint usePTDS = cudaPythonInit()
1987 if usePTDS:
1988 return ptds._cudaMemAdvise(devPtr, count, advice, location)
1989 return _static_cudaMemAdvise(devPtr, count, advice, location)
1992cdef cudaError_t _cudaMemRangeGetAttribute(void* data, size_t dataSize, cudaMemRangeAttribute attribute, const void* devPtr, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
1993 cdef bint usePTDS = cudaPythonInit()
1994 if usePTDS:
1995 return ptds._cudaMemRangeGetAttribute(data, dataSize, attribute, devPtr, count) 1iq
1996 return _static_cudaMemRangeGetAttribute(data, dataSize, attribute, devPtr, count) 1iq
1999cdef cudaError_t _cudaMemRangeGetAttributes(void** data, size_t* dataSizes, cudaMemRangeAttribute* attributes, size_t numAttributes, const void* devPtr, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
2000 cdef bint usePTDS = cudaPythonInit()
2001 if usePTDS:
2002 return ptds._cudaMemRangeGetAttributes(data, dataSizes, attributes, numAttributes, devPtr, count) 1iq
2003 return _static_cudaMemRangeGetAttributes(data, dataSizes, attributes, numAttributes, devPtr, count) 1iq
2006cdef cudaError_t _cudaMemcpyToArray(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2007 cdef bint usePTDS = cudaPythonInit() 1iq
2008 if usePTDS: 1aiq
2009 return ptds._cudaMemcpyToArray(dst, wOffset, hOffset, src, count, kind) 1k
2010 return _static_cudaMemcpyToArray(dst, wOffset, hOffset, src, count, kind) 1kiq
2013cdef cudaError_t _cudaMemcpyFromArray(void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2014 cdef bint usePTDS = cudaPythonInit() 1iq
2015 if usePTDS: 1aiq
2016 return ptds._cudaMemcpyFromArray(dst, src, wOffset, hOffset, count, kind)
2017 return _static_cudaMemcpyFromArray(dst, src, wOffset, hOffset, count, kind) 1iq
2020cdef cudaError_t _cudaMemcpyArrayToArray(cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2021 cdef bint usePTDS = cudaPythonInit() 1k
2022 if usePTDS: 1ak
2023 return ptds._cudaMemcpyArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, count, kind)
2024 return _static_cudaMemcpyArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, count, kind) 1k
2027cdef cudaError_t _cudaMemcpyToArrayAsync(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2028 cdef bint usePTDS = cudaPythonInit()
2029 if usePTDS:
2030 return ptds._cudaMemcpyToArrayAsync(dst, wOffset, hOffset, src, count, kind, stream)
2031 return _static_cudaMemcpyToArrayAsync(dst, wOffset, hOffset, src, count, kind, stream)
2034cdef cudaError_t _cudaMemcpyFromArrayAsync(void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2035 cdef bint usePTDS = cudaPythonInit()
2036 if usePTDS:
2037 return ptds._cudaMemcpyFromArrayAsync(dst, src, wOffset, hOffset, count, kind, stream)
2038 return _static_cudaMemcpyFromArrayAsync(dst, src, wOffset, hOffset, count, kind, stream)
2041cdef cudaError_t _cudaMallocAsync(void** devPtr, size_t size, cudaStream_t hStream) except ?cudaErrorCallRequiresNewerDriver nogil:
2042 cdef bint usePTDS = cudaPythonInit()
2043 if usePTDS:
2044 return ptds._cudaMallocAsync(devPtr, size, hStream)
2045 return _static_cudaMallocAsync(devPtr, size, hStream)
2048cdef cudaError_t _cudaFreeAsync(void* devPtr, cudaStream_t hStream) except ?cudaErrorCallRequiresNewerDriver nogil:
2049 cdef bint usePTDS = cudaPythonInit()
2050 if usePTDS:
2051 return ptds._cudaFreeAsync(devPtr, hStream)
2052 return _static_cudaFreeAsync(devPtr, hStream)
2055cdef cudaError_t _cudaMemPoolTrimTo(cudaMemPool_t memPool, size_t minBytesToKeep) except ?cudaErrorCallRequiresNewerDriver nogil:
2056 cdef bint usePTDS = cudaPythonInit()
2057 if usePTDS:
2058 return ptds._cudaMemPoolTrimTo(memPool, minBytesToKeep)
2059 return _static_cudaMemPoolTrimTo(memPool, minBytesToKeep)
2062cdef cudaError_t _cudaMemPoolSetAttribute(cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2063 cdef bint usePTDS = cudaPythonInit() 1Q
2064 if usePTDS: 1aQ
2065 return ptds._cudaMemPoolSetAttribute(memPool, attr, value)
2066 return _static_cudaMemPoolSetAttribute(memPool, attr, value) 1Q
2069cdef cudaError_t _cudaMemPoolGetAttribute(cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2070 cdef bint usePTDS = cudaPythonInit() 1Q
2071 if usePTDS: 1aQ
2072 return ptds._cudaMemPoolGetAttribute(memPool, attr, value)
2073 return _static_cudaMemPoolGetAttribute(memPool, attr, value) 1Q
2076cdef cudaError_t _cudaMemPoolSetAccess(cudaMemPool_t memPool, const cudaMemAccessDesc* descList, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
2077 cdef bint usePTDS = cudaPythonInit()
2078 if usePTDS:
2079 return ptds._cudaMemPoolSetAccess(memPool, descList, count)
2080 return _static_cudaMemPoolSetAccess(memPool, descList, count)
2083cdef cudaError_t _cudaMemPoolGetAccess(cudaMemAccessFlags* flags, cudaMemPool_t memPool, cudaMemLocation* location) except ?cudaErrorCallRequiresNewerDriver nogil:
2084 cdef bint usePTDS = cudaPythonInit()
2085 if usePTDS:
2086 return ptds._cudaMemPoolGetAccess(flags, memPool, location)
2087 return _static_cudaMemPoolGetAccess(flags, memPool, location)
2090cdef cudaError_t _cudaMemPoolCreate(cudaMemPool_t* memPool, const cudaMemPoolProps* poolProps) except ?cudaErrorCallRequiresNewerDriver nogil:
2091 cdef bint usePTDS = cudaPythonInit() 1Q
2092 if usePTDS: 1aQ
2093 return ptds._cudaMemPoolCreate(memPool, poolProps)
2094 return _static_cudaMemPoolCreate(memPool, poolProps) 1Q
2097cdef cudaError_t _cudaMemPoolDestroy(cudaMemPool_t memPool) except ?cudaErrorCallRequiresNewerDriver nogil:
2098 cdef bint usePTDS = cudaPythonInit() 1Q
2099 if usePTDS: 1aQ
2100 return ptds._cudaMemPoolDestroy(memPool)
2101 return _static_cudaMemPoolDestroy(memPool) 1Q
2104cdef cudaError_t _cudaMallocFromPoolAsync(void** ptr, size_t size, cudaMemPool_t memPool, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2105 cdef bint usePTDS = cudaPythonInit()
2106 if usePTDS:
2107 return ptds._cudaMallocFromPoolAsync(ptr, size, memPool, stream)
2108 return _static_cudaMallocFromPoolAsync(ptr, size, memPool, stream)
2111cdef cudaError_t _cudaMemPoolExportToShareableHandle(void* shareableHandle, cudaMemPool_t memPool, cudaMemAllocationHandleType handleType, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2112 cdef bint usePTDS = cudaPythonInit()
2113 if usePTDS:
2114 return ptds._cudaMemPoolExportToShareableHandle(shareableHandle, memPool, handleType, flags)
2115 return _static_cudaMemPoolExportToShareableHandle(shareableHandle, memPool, handleType, flags)
2118cdef cudaError_t _cudaMemPoolImportFromShareableHandle(cudaMemPool_t* memPool, void* shareableHandle, cudaMemAllocationHandleType handleType, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2119 cdef bint usePTDS = cudaPythonInit()
2120 if usePTDS:
2121 return ptds._cudaMemPoolImportFromShareableHandle(memPool, shareableHandle, handleType, flags)
2122 return _static_cudaMemPoolImportFromShareableHandle(memPool, shareableHandle, handleType, flags)
2125cdef cudaError_t _cudaMemPoolExportPointer(cudaMemPoolPtrExportData* exportData, void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
2126 cdef bint usePTDS = cudaPythonInit()
2127 if usePTDS:
2128 return ptds._cudaMemPoolExportPointer(exportData, ptr)
2129 return _static_cudaMemPoolExportPointer(exportData, ptr)
2132cdef cudaError_t _cudaMemPoolImportPointer(void** ptr, cudaMemPool_t memPool, cudaMemPoolPtrExportData* exportData) except ?cudaErrorCallRequiresNewerDriver nogil:
2133 cdef bint usePTDS = cudaPythonInit()
2134 if usePTDS:
2135 return ptds._cudaMemPoolImportPointer(ptr, memPool, exportData)
2136 return _static_cudaMemPoolImportPointer(ptr, memPool, exportData)
2139cdef cudaError_t _cudaPointerGetAttributes(cudaPointerAttributes* attributes, const void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
2140 cdef bint usePTDS = cudaPythonInit()
2141 if usePTDS:
2142 return ptds._cudaPointerGetAttributes(attributes, ptr)
2143 return _static_cudaPointerGetAttributes(attributes, ptr)
2146cdef cudaError_t _cudaDeviceCanAccessPeer(int* canAccessPeer, int device, int peerDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
2147 cdef bint usePTDS = cudaPythonInit()
2148 if usePTDS:
2149 return ptds._cudaDeviceCanAccessPeer(canAccessPeer, device, peerDevice)
2150 return _static_cudaDeviceCanAccessPeer(canAccessPeer, device, peerDevice)
2153cdef cudaError_t _cudaDeviceEnablePeerAccess(int peerDevice, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2154 cdef bint usePTDS = cudaPythonInit()
2155 if usePTDS:
2156 return ptds._cudaDeviceEnablePeerAccess(peerDevice, flags)
2157 return _static_cudaDeviceEnablePeerAccess(peerDevice, flags)
2160cdef cudaError_t _cudaDeviceDisablePeerAccess(int peerDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
2161 cdef bint usePTDS = cudaPythonInit()
2162 if usePTDS:
2163 return ptds._cudaDeviceDisablePeerAccess(peerDevice)
2164 return _static_cudaDeviceDisablePeerAccess(peerDevice)
2167cdef cudaError_t _cudaGraphicsUnregisterResource(cudaGraphicsResource_t resource) except ?cudaErrorCallRequiresNewerDriver nogil:
2168 cdef bint usePTDS = cudaPythonInit() 1GH
2169 if usePTDS: 1aGH
2170 return ptds._cudaGraphicsUnregisterResource(resource)
2171 return _static_cudaGraphicsUnregisterResource(resource) 1GH
2174cdef cudaError_t _cudaGraphicsResourceSetMapFlags(cudaGraphicsResource_t resource, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2175 cdef bint usePTDS = cudaPythonInit()
2176 if usePTDS:
2177 return ptds._cudaGraphicsResourceSetMapFlags(resource, flags)
2178 return _static_cudaGraphicsResourceSetMapFlags(resource, flags)
2181cdef cudaError_t _cudaGraphicsMapResources(int count, cudaGraphicsResource_t* resources, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2182 cdef bint usePTDS = cudaPythonInit()
2183 if usePTDS:
2184 return ptds._cudaGraphicsMapResources(count, resources, stream)
2185 return _static_cudaGraphicsMapResources(count, resources, stream)
2188cdef cudaError_t _cudaGraphicsUnmapResources(int count, cudaGraphicsResource_t* resources, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2189 cdef bint usePTDS = cudaPythonInit()
2190 if usePTDS:
2191 return ptds._cudaGraphicsUnmapResources(count, resources, stream)
2192 return _static_cudaGraphicsUnmapResources(count, resources, stream)
2195cdef cudaError_t _cudaGraphicsResourceGetMappedPointer(void** devPtr, size_t* size, cudaGraphicsResource_t resource) except ?cudaErrorCallRequiresNewerDriver nogil:
2196 cdef bint usePTDS = cudaPythonInit()
2197 if usePTDS:
2198 return ptds._cudaGraphicsResourceGetMappedPointer(devPtr, size, resource)
2199 return _static_cudaGraphicsResourceGetMappedPointer(devPtr, size, resource)
2202cdef cudaError_t _cudaGraphicsSubResourceGetMappedArray(cudaArray_t* array, cudaGraphicsResource_t resource, unsigned int arrayIndex, unsigned int mipLevel) except ?cudaErrorCallRequiresNewerDriver nogil:
2203 cdef bint usePTDS = cudaPythonInit()
2204 if usePTDS:
2205 return ptds._cudaGraphicsSubResourceGetMappedArray(array, resource, arrayIndex, mipLevel) 1y
2206 return _static_cudaGraphicsSubResourceGetMappedArray(array, resource, arrayIndex, mipLevel) 1y
2209cdef cudaError_t _cudaGraphicsResourceGetMappedMipmappedArray(cudaMipmappedArray_t* mipmappedArray, cudaGraphicsResource_t resource) except ?cudaErrorCallRequiresNewerDriver nogil:
2210 cdef bint usePTDS = cudaPythonInit()
2211 if usePTDS:
2212 return ptds._cudaGraphicsResourceGetMappedMipmappedArray(mipmappedArray, resource) 2x y t l g p j b h k i q ib
2213 return _static_cudaGraphicsResourceGetMappedMipmappedArray(mipmappedArray, resource) 2x y t l g p j b h k i q ib
2216cdef cudaError_t _cudaGetChannelDesc(cudaChannelFormatDesc* desc, cudaArray_const_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
2217 cdef bint usePTDS = cudaPythonInit() 1y
2218 if usePTDS: 1ay
2219 return ptds._cudaGetChannelDesc(desc, array) 1t
2220 return _static_cudaGetChannelDesc(desc, array) 1yt
2223cdef cudaChannelFormatDesc _cudaCreateChannelDesc(int x, int y, int z, int w, cudaChannelFormatKind f) except* nogil:
2224 cdef bint usePTDS = cudaPythonInit() 2x y t l g p j b h k i q ib
2225 if usePTDS: 2a x y t l g p j b h k i q ib
2226 return ptds._cudaCreateChannelDesc(x, y, z, w, f) 1t
2227 return _static_cudaCreateChannelDesc(x, y, z, w, f) 2x y t l g p j b h k i q ib
2230cdef cudaError_t _cudaCreateTextureObject(cudaTextureObject_t* pTexObject, const cudaResourceDesc* pResDesc, const cudaTextureDesc* pTexDesc, const cudaResourceViewDesc* pResViewDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
2231 cdef bint usePTDS = cudaPythonInit() 1t
2232 if usePTDS: 1at
2233 return ptds._cudaCreateTextureObject(pTexObject, pResDesc, pTexDesc, pResViewDesc)
2234 return _static_cudaCreateTextureObject(pTexObject, pResDesc, pTexDesc, pResViewDesc) 1t
2237cdef cudaError_t _cudaDestroyTextureObject(cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2238 cdef bint usePTDS = cudaPythonInit() 1t
2239 if usePTDS: 1at
2240 return ptds._cudaDestroyTextureObject(texObject) 1t
2241 return _static_cudaDestroyTextureObject(texObject) 1t
2244cdef cudaError_t _cudaGetTextureObjectResourceDesc(cudaResourceDesc* pResDesc, cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2245 cdef bint usePTDS = cudaPythonInit()
2246 if usePTDS:
2247 return ptds._cudaGetTextureObjectResourceDesc(pResDesc, texObject)
2248 return _static_cudaGetTextureObjectResourceDesc(pResDesc, texObject)
2251cdef cudaError_t _cudaGetTextureObjectTextureDesc(cudaTextureDesc* pTexDesc, cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2252 cdef bint usePTDS = cudaPythonInit() 1t
2253 if usePTDS: 1at
2254 return ptds._cudaGetTextureObjectTextureDesc(pTexDesc, texObject)
2255 return _static_cudaGetTextureObjectTextureDesc(pTexDesc, texObject) 1t
2258cdef cudaError_t _cudaGetTextureObjectResourceViewDesc(cudaResourceViewDesc* pResViewDesc, cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2259 cdef bint usePTDS = cudaPythonInit()
2260 if usePTDS:
2261 return ptds._cudaGetTextureObjectResourceViewDesc(pResViewDesc, texObject)
2262 return _static_cudaGetTextureObjectResourceViewDesc(pResViewDesc, texObject)
2265cdef cudaError_t _cudaCreateSurfaceObject(cudaSurfaceObject_t* pSurfObject, const cudaResourceDesc* pResDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
2266 cdef bint usePTDS = cudaPythonInit()
2267 if usePTDS:
2268 return ptds._cudaCreateSurfaceObject(pSurfObject, pResDesc)
2269 return _static_cudaCreateSurfaceObject(pSurfObject, pResDesc)
2272cdef cudaError_t _cudaDestroySurfaceObject(cudaSurfaceObject_t surfObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2273 cdef bint usePTDS = cudaPythonInit()
2274 if usePTDS:
2275 return ptds._cudaDestroySurfaceObject(surfObject)
2276 return _static_cudaDestroySurfaceObject(surfObject)
2279cdef cudaError_t _cudaGetSurfaceObjectResourceDesc(cudaResourceDesc* pResDesc, cudaSurfaceObject_t surfObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2280 cdef bint usePTDS = cudaPythonInit()
2281 if usePTDS:
2282 return ptds._cudaGetSurfaceObjectResourceDesc(pResDesc, surfObject)
2283 return _static_cudaGetSurfaceObjectResourceDesc(pResDesc, surfObject)
2286cdef cudaError_t _cudaDriverGetVersion(int* driverVersion) except ?cudaErrorCallRequiresNewerDriver nogil:
2287 cdef bint usePTDS = cudaPythonInit()
2288 if usePTDS:
2289 return ptds._cudaDriverGetVersion(driverVersion) 1ueJnvwLfdzoE]
2290 return _static_cudaDriverGetVersion(driverVersion) 1ueJnvwLfdzoE]
2293cdef cudaError_t _cudaRuntimeGetVersion(int* runtimeVersion) except ?cudaErrorCallRequiresNewerDriver nogil:
2294 cdef bint usePTDS = cudaPythonInit()
2295 if usePTDS:
2296 return ptds._cudaRuntimeGetVersion(runtimeVersion)
2297 return _static_cudaRuntimeGetVersion(runtimeVersion)
2300cdef cudaError_t _cudaGraphCreate(cudaGraph_t* pGraph, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2301 cdef bint usePTDS = cudaPythonInit() 1ueJnvwLfdzoE]
2302 if usePTDS: 1aueJnvwLfdzoE]
2303 return ptds._cudaGraphCreate(pGraph, flags)
2304 return _static_cudaGraphCreate(pGraph, flags) 1ueJnvwLfdzoE]
2307cdef cudaError_t _cudaGraphAddKernelNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2308 cdef bint usePTDS = cudaPythonInit()
2309 if usePTDS:
2310 return ptds._cudaGraphAddKernelNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2311 return _static_cudaGraphAddKernelNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2314cdef cudaError_t _cudaGraphKernelNodeGetParams(cudaGraphNode_t node, cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2315 cdef bint usePTDS = cudaPythonInit()
2316 if usePTDS:
2317 return ptds._cudaGraphKernelNodeGetParams(node, pNodeParams)
2318 return _static_cudaGraphKernelNodeGetParams(node, pNodeParams)
2321cdef cudaError_t _cudaGraphKernelNodeSetParams(cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2322 cdef bint usePTDS = cudaPythonInit()
2323 if usePTDS:
2324 return ptds._cudaGraphKernelNodeSetParams(node, pNodeParams)
2325 return _static_cudaGraphKernelNodeSetParams(node, pNodeParams)
2328cdef cudaError_t _cudaGraphKernelNodeCopyAttributes(cudaGraphNode_t hDst, cudaGraphNode_t hSrc) except ?cudaErrorCallRequiresNewerDriver nogil:
2329 cdef bint usePTDS = cudaPythonInit()
2330 if usePTDS:
2331 return ptds._cudaGraphKernelNodeCopyAttributes(hDst, hSrc)
2332 return _static_cudaGraphKernelNodeCopyAttributes(hDst, hSrc)
2335cdef cudaError_t _cudaGraphKernelNodeGetAttribute(cudaGraphNode_t hNode, cudaKernelNodeAttrID attr, cudaKernelNodeAttrValue* value_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2336 cdef bint usePTDS = cudaPythonInit()
2337 if usePTDS:
2338 return ptds._cudaGraphKernelNodeGetAttribute(hNode, attr, value_out)
2339 return _static_cudaGraphKernelNodeGetAttribute(hNode, attr, value_out)
2342cdef cudaError_t _cudaGraphKernelNodeSetAttribute(cudaGraphNode_t hNode, cudaKernelNodeAttrID attr, const cudaKernelNodeAttrValue* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2343 cdef bint usePTDS = cudaPythonInit()
2344 if usePTDS:
2345 return ptds._cudaGraphKernelNodeSetAttribute(hNode, attr, value) 1fd
2346 return _static_cudaGraphKernelNodeSetAttribute(hNode, attr, value) 1fd
2349cdef cudaError_t _cudaGraphAddMemcpyNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemcpy3DParms* pCopyParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2350 cdef bint usePTDS = cudaPythonInit()
2351 if usePTDS:
2352 return ptds._cudaGraphAddMemcpyNode(pGraphNode, graph, pDependencies, numDependencies, pCopyParams)
2353 return _static_cudaGraphAddMemcpyNode(pGraphNode, graph, pDependencies, numDependencies, pCopyParams)
2356cdef cudaError_t _cudaGraphAddMemcpyNode1D(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2357 cdef bint usePTDS = cudaPythonInit() 1fd
2358 if usePTDS: 1afd
2359 return ptds._cudaGraphAddMemcpyNode1D(pGraphNode, graph, pDependencies, numDependencies, dst, src, count, kind)
2360 return _static_cudaGraphAddMemcpyNode1D(pGraphNode, graph, pDependencies, numDependencies, dst, src, count, kind) 1fd
2363cdef cudaError_t _cudaGraphMemcpyNodeGetParams(cudaGraphNode_t node, cudaMemcpy3DParms* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2364 cdef bint usePTDS = cudaPythonInit()
2365 if usePTDS:
2366 return ptds._cudaGraphMemcpyNodeGetParams(node, pNodeParams)
2367 return _static_cudaGraphMemcpyNodeGetParams(node, pNodeParams)
2370cdef cudaError_t _cudaGraphMemcpyNodeSetParams(cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2371 cdef bint usePTDS = cudaPythonInit()
2372 if usePTDS:
2373 return ptds._cudaGraphMemcpyNodeSetParams(node, pNodeParams) 1d
2374 return _static_cudaGraphMemcpyNodeSetParams(node, pNodeParams) 1d
2377cdef cudaError_t _cudaGraphMemcpyNodeSetParams1D(cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2378 cdef bint usePTDS = cudaPythonInit()
2379 if usePTDS:
2380 return ptds._cudaGraphMemcpyNodeSetParams1D(node, dst, src, count, kind)
2381 return _static_cudaGraphMemcpyNodeSetParams1D(node, dst, src, count, kind)
2384cdef cudaError_t _cudaGraphAddMemsetNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemsetParams* pMemsetParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2385 cdef bint usePTDS = cudaPythonInit() 1d
2386 if usePTDS: 1ad
2387 return ptds._cudaGraphAddMemsetNode(pGraphNode, graph, pDependencies, numDependencies, pMemsetParams)
2388 return _static_cudaGraphAddMemsetNode(pGraphNode, graph, pDependencies, numDependencies, pMemsetParams) 1d
2391cdef cudaError_t _cudaGraphMemsetNodeGetParams(cudaGraphNode_t node, cudaMemsetParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2392 cdef bint usePTDS = cudaPythonInit()
2393 if usePTDS:
2394 return ptds._cudaGraphMemsetNodeGetParams(node, pNodeParams)
2395 return _static_cudaGraphMemsetNodeGetParams(node, pNodeParams)
2398cdef cudaError_t _cudaGraphMemsetNodeSetParams(cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2399 cdef bint usePTDS = cudaPythonInit()
2400 if usePTDS:
2401 return ptds._cudaGraphMemsetNodeSetParams(node, pNodeParams)
2402 return _static_cudaGraphMemsetNodeSetParams(node, pNodeParams)
2405cdef cudaError_t _cudaGraphAddHostNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2406 cdef bint usePTDS = cudaPythonInit()
2407 if usePTDS:
2408 return ptds._cudaGraphAddHostNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2409 return _static_cudaGraphAddHostNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2412cdef cudaError_t _cudaGraphHostNodeGetParams(cudaGraphNode_t node, cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2413 cdef bint usePTDS = cudaPythonInit()
2414 if usePTDS:
2415 return ptds._cudaGraphHostNodeGetParams(node, pNodeParams)
2416 return _static_cudaGraphHostNodeGetParams(node, pNodeParams)
2419cdef cudaError_t _cudaGraphHostNodeSetParams(cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2420 cdef bint usePTDS = cudaPythonInit()
2421 if usePTDS:
2422 return ptds._cudaGraphHostNodeSetParams(node, pNodeParams)
2423 return _static_cudaGraphHostNodeSetParams(node, pNodeParams)
2426cdef cudaError_t _cudaGraphAddChildGraphNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaGraph_t childGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2427 cdef bint usePTDS = cudaPythonInit()
2428 if usePTDS:
2429 return ptds._cudaGraphAddChildGraphNode(pGraphNode, graph, pDependencies, numDependencies, childGraph) 1envwzoEP
2430 return _static_cudaGraphAddChildGraphNode(pGraphNode, graph, pDependencies, numDependencies, childGraph) 1envwzoEP
2433cdef cudaError_t _cudaGraphChildGraphNodeGetGraph(cudaGraphNode_t node, cudaGraph_t* pGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2434 cdef bint usePTDS = cudaPythonInit()
2435 if usePTDS:
2436 return ptds._cudaGraphChildGraphNodeGetGraph(node, pGraph)
2437 return _static_cudaGraphChildGraphNodeGetGraph(node, pGraph)
2440cdef cudaError_t _cudaGraphAddEmptyNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2441 cdef bint usePTDS = cudaPythonInit() 1envwzoEP
2442 if usePTDS: 1aenvwzoEP
2443 return ptds._cudaGraphAddEmptyNode(pGraphNode, graph, pDependencies, numDependencies)
2444 return _static_cudaGraphAddEmptyNode(pGraphNode, graph, pDependencies, numDependencies) 1envwzoEP
2447cdef cudaError_t _cudaGraphAddEventRecordNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2448 cdef bint usePTDS = cudaPythonInit()
2449 if usePTDS:
2450 return ptds._cudaGraphAddEventRecordNode(pGraphNode, graph, pDependencies, numDependencies, event)
2451 return _static_cudaGraphAddEventRecordNode(pGraphNode, graph, pDependencies, numDependencies, event)
2454cdef cudaError_t _cudaGraphEventRecordNodeGetEvent(cudaGraphNode_t node, cudaEvent_t* event_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2455 cdef bint usePTDS = cudaPythonInit()
2456 if usePTDS:
2457 return ptds._cudaGraphEventRecordNodeGetEvent(node, event_out)
2458 return _static_cudaGraphEventRecordNodeGetEvent(node, event_out)
2461cdef cudaError_t _cudaGraphEventRecordNodeSetEvent(cudaGraphNode_t node, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2462 cdef bint usePTDS = cudaPythonInit()
2463 if usePTDS:
2464 return ptds._cudaGraphEventRecordNodeSetEvent(node, event)
2465 return _static_cudaGraphEventRecordNodeSetEvent(node, event)
2468cdef cudaError_t _cudaGraphAddEventWaitNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2469 cdef bint usePTDS = cudaPythonInit()
2470 if usePTDS:
2471 return ptds._cudaGraphAddEventWaitNode(pGraphNode, graph, pDependencies, numDependencies, event)
2472 return _static_cudaGraphAddEventWaitNode(pGraphNode, graph, pDependencies, numDependencies, event)
2475cdef cudaError_t _cudaGraphEventWaitNodeGetEvent(cudaGraphNode_t node, cudaEvent_t* event_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2476 cdef bint usePTDS = cudaPythonInit()
2477 if usePTDS:
2478 return ptds._cudaGraphEventWaitNodeGetEvent(node, event_out)
2479 return _static_cudaGraphEventWaitNodeGetEvent(node, event_out)
2482cdef cudaError_t _cudaGraphEventWaitNodeSetEvent(cudaGraphNode_t node, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2483 cdef bint usePTDS = cudaPythonInit()
2484 if usePTDS:
2485 return ptds._cudaGraphEventWaitNodeSetEvent(node, event)
2486 return _static_cudaGraphEventWaitNodeSetEvent(node, event)
2489cdef cudaError_t _cudaGraphAddExternalSemaphoresSignalNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreSignalNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2490 cdef bint usePTDS = cudaPythonInit()
2491 if usePTDS:
2492 return ptds._cudaGraphAddExternalSemaphoresSignalNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2493 return _static_cudaGraphAddExternalSemaphoresSignalNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2496cdef cudaError_t _cudaGraphExternalSemaphoresSignalNodeGetParams(cudaGraphNode_t hNode, cudaExternalSemaphoreSignalNodeParams* params_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2497 cdef bint usePTDS = cudaPythonInit()
2498 if usePTDS:
2499 return ptds._cudaGraphExternalSemaphoresSignalNodeGetParams(hNode, params_out)
2500 return _static_cudaGraphExternalSemaphoresSignalNodeGetParams(hNode, params_out)
2503cdef cudaError_t _cudaGraphExternalSemaphoresSignalNodeSetParams(cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2504 cdef bint usePTDS = cudaPythonInit()
2505 if usePTDS:
2506 return ptds._cudaGraphExternalSemaphoresSignalNodeSetParams(hNode, nodeParams)
2507 return _static_cudaGraphExternalSemaphoresSignalNodeSetParams(hNode, nodeParams)
2510cdef cudaError_t _cudaGraphAddExternalSemaphoresWaitNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreWaitNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2511 cdef bint usePTDS = cudaPythonInit()
2512 if usePTDS:
2513 return ptds._cudaGraphAddExternalSemaphoresWaitNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2514 return _static_cudaGraphAddExternalSemaphoresWaitNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2517cdef cudaError_t _cudaGraphExternalSemaphoresWaitNodeGetParams(cudaGraphNode_t hNode, cudaExternalSemaphoreWaitNodeParams* params_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2518 cdef bint usePTDS = cudaPythonInit()
2519 if usePTDS:
2520 return ptds._cudaGraphExternalSemaphoresWaitNodeGetParams(hNode, params_out)
2521 return _static_cudaGraphExternalSemaphoresWaitNodeGetParams(hNode, params_out)
2524cdef cudaError_t _cudaGraphExternalSemaphoresWaitNodeSetParams(cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2525 cdef bint usePTDS = cudaPythonInit()
2526 if usePTDS:
2527 return ptds._cudaGraphExternalSemaphoresWaitNodeSetParams(hNode, nodeParams)
2528 return _static_cudaGraphExternalSemaphoresWaitNodeSetParams(hNode, nodeParams)
2531cdef cudaError_t _cudaGraphAddMemAllocNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaMemAllocNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2532 cdef bint usePTDS = cudaPythonInit()
2533 if usePTDS:
2534 return ptds._cudaGraphAddMemAllocNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2535 return _static_cudaGraphAddMemAllocNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2538cdef cudaError_t _cudaGraphMemAllocNodeGetParams(cudaGraphNode_t node, cudaMemAllocNodeParams* params_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2539 cdef bint usePTDS = cudaPythonInit()
2540 if usePTDS:
2541 return ptds._cudaGraphMemAllocNodeGetParams(node, params_out)
2542 return _static_cudaGraphMemAllocNodeGetParams(node, params_out)
2545cdef cudaError_t _cudaGraphAddMemFreeNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dptr) except ?cudaErrorCallRequiresNewerDriver nogil:
2546 cdef bint usePTDS = cudaPythonInit()
2547 if usePTDS:
2548 return ptds._cudaGraphAddMemFreeNode(pGraphNode, graph, pDependencies, numDependencies, dptr)
2549 return _static_cudaGraphAddMemFreeNode(pGraphNode, graph, pDependencies, numDependencies, dptr)
2552cdef cudaError_t _cudaGraphMemFreeNodeGetParams(cudaGraphNode_t node, void* dptr_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2553 cdef bint usePTDS = cudaPythonInit()
2554 if usePTDS:
2555 return ptds._cudaGraphMemFreeNodeGetParams(node, dptr_out)
2556 return _static_cudaGraphMemFreeNodeGetParams(node, dptr_out)
2559cdef cudaError_t _cudaDeviceGraphMemTrim(int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2560 cdef bint usePTDS = cudaPythonInit()
2561 if usePTDS:
2562 return ptds._cudaDeviceGraphMemTrim(device)
2563 return _static_cudaDeviceGraphMemTrim(device)
2566cdef cudaError_t _cudaDeviceGetGraphMemAttribute(int device, cudaGraphMemAttributeType attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2567 cdef bint usePTDS = cudaPythonInit()
2568 if usePTDS:
2569 return ptds._cudaDeviceGetGraphMemAttribute(device, attr, value)
2570 return _static_cudaDeviceGetGraphMemAttribute(device, attr, value)
2573cdef cudaError_t _cudaDeviceSetGraphMemAttribute(int device, cudaGraphMemAttributeType attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2574 cdef bint usePTDS = cudaPythonInit()
2575 if usePTDS:
2576 return ptds._cudaDeviceSetGraphMemAttribute(device, attr, value)
2577 return _static_cudaDeviceSetGraphMemAttribute(device, attr, value)
2580cdef cudaError_t _cudaGraphClone(cudaGraph_t* pGraphClone, cudaGraph_t originalGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2581 cdef bint usePTDS = cudaPythonInit()
2582 if usePTDS:
2583 return ptds._cudaGraphClone(pGraphClone, originalGraph)
2584 return _static_cudaGraphClone(pGraphClone, originalGraph)
2587cdef cudaError_t _cudaGraphNodeFindInClone(cudaGraphNode_t* pNode, cudaGraphNode_t originalNode, cudaGraph_t clonedGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2588 cdef bint usePTDS = cudaPythonInit()
2589 if usePTDS:
2590 return ptds._cudaGraphNodeFindInClone(pNode, originalNode, clonedGraph) 1E
2591 return _static_cudaGraphNodeFindInClone(pNode, originalNode, clonedGraph) 1E
2594cdef cudaError_t _cudaGraphNodeGetType(cudaGraphNode_t node, cudaGraphNodeType* pType) except ?cudaErrorCallRequiresNewerDriver nogil:
2595 cdef bint usePTDS = cudaPythonInit()
2596 if usePTDS:
2597 return ptds._cudaGraphNodeGetType(node, pType)
2598 return _static_cudaGraphNodeGetType(node, pType)
2601cdef cudaError_t _cudaGraphGetNodes(cudaGraph_t graph, cudaGraphNode_t* nodes, size_t* numNodes) except ?cudaErrorCallRequiresNewerDriver nogil:
2602 cdef bint usePTDS = cudaPythonInit() 1E
2603 if usePTDS: 1aE
2604 return ptds._cudaGraphGetNodes(graph, nodes, numNodes) 1z
2605 return _static_cudaGraphGetNodes(graph, nodes, numNodes) 1zE
2608cdef cudaError_t _cudaGraphGetRootNodes(cudaGraph_t graph, cudaGraphNode_t* pRootNodes, size_t* pNumRootNodes) except ?cudaErrorCallRequiresNewerDriver nogil:
2609 cdef bint usePTDS = cudaPythonInit()
2610 if usePTDS:
2611 return ptds._cudaGraphGetRootNodes(graph, pRootNodes, pNumRootNodes) 1o
2612 return _static_cudaGraphGetRootNodes(graph, pRootNodes, pNumRootNodes) 1o
2615cdef cudaError_t _cudaGraphGetEdges(cudaGraph_t graph, cudaGraphNode_t* from_, cudaGraphNode_t* to, cudaGraphEdgeData* edgeData, size_t* numEdges) except ?cudaErrorCallRequiresNewerDriver nogil:
2616 cdef bint usePTDS = cudaPythonInit() 1z
2617 if usePTDS: 1az
2618 return ptds._cudaGraphGetEdges(graph, from_, to, edgeData, numEdges) 1o
2619 return _static_cudaGraphGetEdges(graph, from_, to, edgeData, numEdges) 1zo
2622cdef cudaError_t _cudaGraphNodeGetDependencies(cudaGraphNode_t node, cudaGraphNode_t* pDependencies, cudaGraphEdgeData* edgeData, size_t* pNumDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2623 cdef bint usePTDS = cudaPythonInit() 1o
2624 if usePTDS: 1ao
2625 return ptds._cudaGraphNodeGetDependencies(node, pDependencies, edgeData, pNumDependencies)
2626 return _static_cudaGraphNodeGetDependencies(node, pDependencies, edgeData, pNumDependencies) 1o
2629cdef cudaError_t _cudaGraphNodeGetDependentNodes(cudaGraphNode_t node, cudaGraphNode_t* pDependentNodes, cudaGraphEdgeData* edgeData, size_t* pNumDependentNodes) except ?cudaErrorCallRequiresNewerDriver nogil:
2630 cdef bint usePTDS = cudaPythonInit() 1o
2631 if usePTDS: 1ao
2632 return ptds._cudaGraphNodeGetDependentNodes(node, pDependentNodes, edgeData, pNumDependentNodes)
2633 return _static_cudaGraphNodeGetDependentNodes(node, pDependentNodes, edgeData, pNumDependentNodes) 1o
2636cdef cudaError_t _cudaGraphAddDependencies(cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2637 cdef bint usePTDS = cudaPythonInit()
2638 if usePTDS:
2639 return ptds._cudaGraphAddDependencies(graph, from_, to, edgeData, numDependencies) 1P
2640 return _static_cudaGraphAddDependencies(graph, from_, to, edgeData, numDependencies) 1P
2643cdef cudaError_t _cudaGraphRemoveDependencies(cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2644 cdef bint usePTDS = cudaPythonInit()
2645 if usePTDS:
2646 return ptds._cudaGraphRemoveDependencies(graph, from_, to, edgeData, numDependencies) 1efdcO
2647 return _static_cudaGraphRemoveDependencies(graph, from_, to, edgeData, numDependencies) 1efdcO
2650cdef cudaError_t _cudaGraphDestroyNode(cudaGraphNode_t node) except ?cudaErrorCallRequiresNewerDriver nogil:
2651 cdef bint usePTDS = cudaPythonInit() 1P
2652 if usePTDS: 1aP
2653 return ptds._cudaGraphDestroyNode(node)
2654 return _static_cudaGraphDestroyNode(node) 1P
2657cdef cudaError_t _cudaGraphInstantiate(cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2658 cdef bint usePTDS = cudaPythonInit() 1efdcO
2659 if usePTDS: 1aefdcO
2660 return ptds._cudaGraphInstantiate(pGraphExec, graph, flags)
2661 return _static_cudaGraphInstantiate(pGraphExec, graph, flags) 1efdcO
2664cdef cudaError_t _cudaGraphInstantiateWithFlags(cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2665 cdef bint usePTDS = cudaPythonInit()
2666 if usePTDS:
2667 return ptds._cudaGraphInstantiateWithFlags(pGraphExec, graph, flags)
2668 return _static_cudaGraphInstantiateWithFlags(pGraphExec, graph, flags)
2671cdef cudaError_t _cudaGraphInstantiateWithParams(cudaGraphExec_t* pGraphExec, cudaGraph_t graph, cudaGraphInstantiateParams* instantiateParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2672 cdef bint usePTDS = cudaPythonInit()
2673 if usePTDS:
2674 return ptds._cudaGraphInstantiateWithParams(pGraphExec, graph, instantiateParams)
2675 return _static_cudaGraphInstantiateWithParams(pGraphExec, graph, instantiateParams)
2678cdef cudaError_t _cudaGraphExecGetFlags(cudaGraphExec_t graphExec, unsigned long long* flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2679 cdef bint usePTDS = cudaPythonInit()
2680 if usePTDS:
2681 return ptds._cudaGraphExecGetFlags(graphExec, flags)
2682 return _static_cudaGraphExecGetFlags(graphExec, flags)
2685cdef cudaError_t _cudaGraphExecKernelNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2686 cdef bint usePTDS = cudaPythonInit()
2687 if usePTDS:
2688 return ptds._cudaGraphExecKernelNodeSetParams(hGraphExec, node, pNodeParams)
2689 return _static_cudaGraphExecKernelNodeSetParams(hGraphExec, node, pNodeParams)
2692cdef cudaError_t _cudaGraphExecMemcpyNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2693 cdef bint usePTDS = cudaPythonInit()
2694 if usePTDS:
2695 return ptds._cudaGraphExecMemcpyNodeSetParams(hGraphExec, node, pNodeParams)
2696 return _static_cudaGraphExecMemcpyNodeSetParams(hGraphExec, node, pNodeParams)
2699cdef cudaError_t _cudaGraphExecMemcpyNodeSetParams1D(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2700 cdef bint usePTDS = cudaPythonInit()
2701 if usePTDS:
2702 return ptds._cudaGraphExecMemcpyNodeSetParams1D(hGraphExec, node, dst, src, count, kind)
2703 return _static_cudaGraphExecMemcpyNodeSetParams1D(hGraphExec, node, dst, src, count, kind)
2706cdef cudaError_t _cudaGraphExecMemsetNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2707 cdef bint usePTDS = cudaPythonInit()
2708 if usePTDS:
2709 return ptds._cudaGraphExecMemsetNodeSetParams(hGraphExec, node, pNodeParams)
2710 return _static_cudaGraphExecMemsetNodeSetParams(hGraphExec, node, pNodeParams)
2713cdef cudaError_t _cudaGraphExecHostNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2714 cdef bint usePTDS = cudaPythonInit()
2715 if usePTDS:
2716 return ptds._cudaGraphExecHostNodeSetParams(hGraphExec, node, pNodeParams)
2717 return _static_cudaGraphExecHostNodeSetParams(hGraphExec, node, pNodeParams)
2720cdef cudaError_t _cudaGraphExecChildGraphNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, cudaGraph_t childGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2721 cdef bint usePTDS = cudaPythonInit()
2722 if usePTDS:
2723 return ptds._cudaGraphExecChildGraphNodeSetParams(hGraphExec, node, childGraph)
2724 return _static_cudaGraphExecChildGraphNodeSetParams(hGraphExec, node, childGraph)
2727cdef cudaError_t _cudaGraphExecEventRecordNodeSetEvent(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2728 cdef bint usePTDS = cudaPythonInit()
2729 if usePTDS:
2730 return ptds._cudaGraphExecEventRecordNodeSetEvent(hGraphExec, hNode, event)
2731 return _static_cudaGraphExecEventRecordNodeSetEvent(hGraphExec, hNode, event)
2734cdef cudaError_t _cudaGraphExecEventWaitNodeSetEvent(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2735 cdef bint usePTDS = cudaPythonInit()
2736 if usePTDS:
2737 return ptds._cudaGraphExecEventWaitNodeSetEvent(hGraphExec, hNode, event)
2738 return _static_cudaGraphExecEventWaitNodeSetEvent(hGraphExec, hNode, event)
2741cdef cudaError_t _cudaGraphExecExternalSemaphoresSignalNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2742 cdef bint usePTDS = cudaPythonInit()
2743 if usePTDS:
2744 return ptds._cudaGraphExecExternalSemaphoresSignalNodeSetParams(hGraphExec, hNode, nodeParams)
2745 return _static_cudaGraphExecExternalSemaphoresSignalNodeSetParams(hGraphExec, hNode, nodeParams)
2748cdef cudaError_t _cudaGraphExecExternalSemaphoresWaitNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2749 cdef bint usePTDS = cudaPythonInit()
2750 if usePTDS:
2751 return ptds._cudaGraphExecExternalSemaphoresWaitNodeSetParams(hGraphExec, hNode, nodeParams)
2752 return _static_cudaGraphExecExternalSemaphoresWaitNodeSetParams(hGraphExec, hNode, nodeParams)
2755cdef cudaError_t _cudaGraphNodeSetEnabled(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int isEnabled) except ?cudaErrorCallRequiresNewerDriver nogil:
2756 cdef bint usePTDS = cudaPythonInit()
2757 if usePTDS:
2758 return ptds._cudaGraphNodeSetEnabled(hGraphExec, hNode, isEnabled)
2759 return _static_cudaGraphNodeSetEnabled(hGraphExec, hNode, isEnabled)
2762cdef cudaError_t _cudaGraphNodeGetEnabled(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int* isEnabled) except ?cudaErrorCallRequiresNewerDriver nogil:
2763 cdef bint usePTDS = cudaPythonInit()
2764 if usePTDS:
2765 return ptds._cudaGraphNodeGetEnabled(hGraphExec, hNode, isEnabled)
2766 return _static_cudaGraphNodeGetEnabled(hGraphExec, hNode, isEnabled)
2769cdef cudaError_t _cudaGraphExecUpdate(cudaGraphExec_t hGraphExec, cudaGraph_t hGraph, cudaGraphExecUpdateResultInfo* resultInfo) except ?cudaErrorCallRequiresNewerDriver nogil:
2770 cdef bint usePTDS = cudaPythonInit()
2771 if usePTDS:
2772 return ptds._cudaGraphExecUpdate(hGraphExec, hGraph, resultInfo) 1fdc
2773 return _static_cudaGraphExecUpdate(hGraphExec, hGraph, resultInfo) 1fdc
2776cdef cudaError_t _cudaGraphUpload(cudaGraphExec_t graphExec, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2777 cdef bint usePTDS = cudaPythonInit()
2778 if usePTDS:
2779 return ptds._cudaGraphUpload(graphExec, stream) 1ecO
2780 return _static_cudaGraphUpload(graphExec, stream) 1ecO
2783cdef cudaError_t _cudaGraphLaunch(cudaGraphExec_t graphExec, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2784 cdef bint usePTDS = cudaPythonInit() 1fdc
2785 if usePTDS: 1afdc
2786 return ptds._cudaGraphLaunch(graphExec, stream) 1ueJnvwzocOP]
2787 return _static_cudaGraphLaunch(graphExec, stream) 1ueJnvwfdzocOP]
2790cdef cudaError_t _cudaGraphExecDestroy(cudaGraphExec_t graphExec) except ?cudaErrorCallRequiresNewerDriver nogil:
2791 cdef bint usePTDS = cudaPythonInit() 1ecO
2792 if usePTDS: 1aecO
2793 return ptds._cudaGraphExecDestroy(graphExec)
2794 return _static_cudaGraphExecDestroy(graphExec) 1ecO
2797cdef cudaError_t _cudaGraphDestroy(cudaGraph_t graph) except ?cudaErrorCallRequiresNewerDriver nogil:
2798 cdef bint usePTDS = cudaPythonInit() 1ueJnvwzocOP]
2799 if usePTDS: 1aueJnvwzocOP]
2800 return ptds._cudaGraphDestroy(graph)
2801 return _static_cudaGraphDestroy(graph) 1ueJnvwzocOP]
2804cdef cudaError_t _cudaGraphDebugDotPrint(cudaGraph_t graph, const char* path, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2805 cdef bint usePTDS = cudaPythonInit()
2806 if usePTDS:
2807 return ptds._cudaGraphDebugDotPrint(graph, path, flags)
2808 return _static_cudaGraphDebugDotPrint(graph, path, flags)
2811cdef cudaError_t _cudaUserObjectCreate(cudaUserObject_t* object_out, void* ptr, cudaHostFn_t destroy, unsigned int initialRefcount, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2812 cdef bint usePTDS = cudaPythonInit()
2813 if usePTDS:
2814 return ptds._cudaUserObjectCreate(object_out, ptr, destroy, initialRefcount, flags)
2815 return _static_cudaUserObjectCreate(object_out, ptr, destroy, initialRefcount, flags)
2818cdef cudaError_t _cudaUserObjectRetain(cudaUserObject_t object, unsigned int count) except ?cudaErrorCallRequiresNewerDriver nogil:
2819 cdef bint usePTDS = cudaPythonInit()
2820 if usePTDS:
2821 return ptds._cudaUserObjectRetain(object, count)
2822 return _static_cudaUserObjectRetain(object, count)
2825cdef cudaError_t _cudaUserObjectRelease(cudaUserObject_t object, unsigned int count) except ?cudaErrorCallRequiresNewerDriver nogil:
2826 cdef bint usePTDS = cudaPythonInit()
2827 if usePTDS:
2828 return ptds._cudaUserObjectRelease(object, count)
2829 return _static_cudaUserObjectRelease(object, count)
2832cdef cudaError_t _cudaGraphRetainUserObject(cudaGraph_t graph, cudaUserObject_t object, unsigned int count, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2833 cdef bint usePTDS = cudaPythonInit()
2834 if usePTDS:
2835 return ptds._cudaGraphRetainUserObject(graph, object, count, flags) 1nL
2836 return _static_cudaGraphRetainUserObject(graph, object, count, flags) 1nL
2839cdef cudaError_t _cudaGraphReleaseUserObject(cudaGraph_t graph, cudaUserObject_t object, unsigned int count) except ?cudaErrorCallRequiresNewerDriver nogil:
2840 cdef bint usePTDS = cudaPythonInit()
2841 if usePTDS:
2842 return ptds._cudaGraphReleaseUserObject(graph, object, count)
2843 return _static_cudaGraphReleaseUserObject(graph, object, count)
2846cdef cudaError_t _cudaGraphAddNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2847 cdef bint usePTDS = cudaPythonInit() 1nL
2848 if usePTDS: 1anL
2849 return ptds._cudaGraphAddNode(pGraphNode, graph, pDependencies, dependencyData, numDependencies, nodeParams)
2850 return _static_cudaGraphAddNode(pGraphNode, graph, pDependencies, dependencyData, numDependencies, nodeParams) 1nL
2853cdef cudaError_t _cudaGraphNodeSetParams(cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2854 cdef bint usePTDS = cudaPythonInit()
2855 if usePTDS:
2856 return ptds._cudaGraphNodeSetParams(node, nodeParams) 1L
2857 return _static_cudaGraphNodeSetParams(node, nodeParams) 1L
2860cdef cudaError_t _cudaGraphExecNodeSetParams(cudaGraphExec_t graphExec, cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2861 cdef bint usePTDS = cudaPythonInit()
2862 if usePTDS:
2863 return ptds._cudaGraphExecNodeSetParams(graphExec, node, nodeParams)
2864 return _static_cudaGraphExecNodeSetParams(graphExec, node, nodeParams)
2867cdef cudaError_t _cudaGraphConditionalHandleCreate(cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, unsigned int defaultLaunchValue, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2868 cdef bint usePTDS = cudaPythonInit() 1L
2869 if usePTDS: 1aL
2870 return ptds._cudaGraphConditionalHandleCreate(pHandle_out, graph, defaultLaunchValue, flags)
2871 return _static_cudaGraphConditionalHandleCreate(pHandle_out, graph, defaultLaunchValue, flags) 1L
2874cdef cudaError_t _cudaGetDriverEntryPoint(const char* symbol, void** funcPtr, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) except ?cudaErrorCallRequiresNewerDriver nogil:
2875 cdef bint usePTDS = cudaPythonInit()
2876 if usePTDS:
2877 return ptds._cudaGetDriverEntryPoint(symbol, funcPtr, flags, driverStatus)
2878 return _static_cudaGetDriverEntryPoint(symbol, funcPtr, flags, driverStatus)
2881cdef cudaError_t _cudaGetDriverEntryPointByVersion(const char* symbol, void** funcPtr, unsigned int cudaVersion, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) except ?cudaErrorCallRequiresNewerDriver nogil:
2882 cdef bint usePTDS = cudaPythonInit()
2883 if usePTDS:
2884 return ptds._cudaGetDriverEntryPointByVersion(symbol, funcPtr, cudaVersion, flags, driverStatus)
2885 return _static_cudaGetDriverEntryPointByVersion(symbol, funcPtr, cudaVersion, flags, driverStatus)
2888cdef cudaError_t _cudaLibraryLoadData(cudaLibrary_t* library, const void* code, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) except ?cudaErrorCallRequiresNewerDriver nogil:
2889 cdef bint usePTDS = cudaPythonInit()
2890 if usePTDS:
2891 return ptds._cudaLibraryLoadData(library, code, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2892 return _static_cudaLibraryLoadData(library, code, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2895cdef cudaError_t _cudaLibraryLoadFromFile(cudaLibrary_t* library, const char* fileName, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) except ?cudaErrorCallRequiresNewerDriver nogil:
2896 cdef bint usePTDS = cudaPythonInit()
2897 if usePTDS:
2898 return ptds._cudaLibraryLoadFromFile(library, fileName, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2899 return _static_cudaLibraryLoadFromFile(library, fileName, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2902cdef cudaError_t _cudaLibraryUnload(cudaLibrary_t library) except ?cudaErrorCallRequiresNewerDriver nogil:
2903 cdef bint usePTDS = cudaPythonInit()
2904 if usePTDS:
2905 return ptds._cudaLibraryUnload(library)
2906 return _static_cudaLibraryUnload(library)
2909cdef cudaError_t _cudaLibraryGetKernel(cudaKernel_t* pKernel, cudaLibrary_t library, const char* name) except ?cudaErrorCallRequiresNewerDriver nogil:
2910 cdef bint usePTDS = cudaPythonInit()
2911 if usePTDS:
2912 return ptds._cudaLibraryGetKernel(pKernel, library, name)
2913 return _static_cudaLibraryGetKernel(pKernel, library, name)
2916cdef cudaError_t _cudaLibraryGetGlobal(void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) except ?cudaErrorCallRequiresNewerDriver nogil:
2917 cdef bint usePTDS = cudaPythonInit()
2918 if usePTDS:
2919 return ptds._cudaLibraryGetGlobal(dptr, bytes, library, name)
2920 return _static_cudaLibraryGetGlobal(dptr, bytes, library, name)
2923cdef cudaError_t _cudaLibraryGetManaged(void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) except ?cudaErrorCallRequiresNewerDriver nogil:
2924 cdef bint usePTDS = cudaPythonInit()
2925 if usePTDS:
2926 return ptds._cudaLibraryGetManaged(dptr, bytes, library, name)
2927 return _static_cudaLibraryGetManaged(dptr, bytes, library, name)
2930cdef cudaError_t _cudaLibraryGetUnifiedFunction(void** fptr, cudaLibrary_t library, const char* symbol) except ?cudaErrorCallRequiresNewerDriver nogil:
2931 cdef bint usePTDS = cudaPythonInit()
2932 if usePTDS:
2933 return ptds._cudaLibraryGetUnifiedFunction(fptr, library, symbol)
2934 return _static_cudaLibraryGetUnifiedFunction(fptr, library, symbol)
2937cdef cudaError_t _cudaLibraryGetKernelCount(unsigned int* count, cudaLibrary_t lib) except ?cudaErrorCallRequiresNewerDriver nogil:
2938 cdef bint usePTDS = cudaPythonInit()
2939 if usePTDS:
2940 return ptds._cudaLibraryGetKernelCount(count, lib)
2941 return _static_cudaLibraryGetKernelCount(count, lib)
2944cdef cudaError_t _cudaLibraryEnumerateKernels(cudaKernel_t* kernels, unsigned int numKernels, cudaLibrary_t lib) except ?cudaErrorCallRequiresNewerDriver nogil:
2945 cdef bint usePTDS = cudaPythonInit()
2946 if usePTDS:
2947 return ptds._cudaLibraryEnumerateKernels(kernels, numKernels, lib)
2948 return _static_cudaLibraryEnumerateKernels(kernels, numKernels, lib)
2951cdef cudaError_t _cudaKernelSetAttributeForDevice(cudaKernel_t kernel, cudaFuncAttribute attr, int value, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2952 cdef bint usePTDS = cudaPythonInit()
2953 if usePTDS:
2954 return ptds._cudaKernelSetAttributeForDevice(kernel, attr, value, device)
2955 return _static_cudaKernelSetAttributeForDevice(kernel, attr, value, device)
2958cdef cudaError_t _cudaGetExportTable(const void** ppExportTable, const cudaUUID_t* pExportTableId) except ?cudaErrorCallRequiresNewerDriver nogil:
2959 cdef bint usePTDS = cudaPythonInit()
2960 if usePTDS:
2961 return ptds._cudaGetExportTable(ppExportTable, pExportTableId) 12
2962 return _static_cudaGetExportTable(ppExportTable, pExportTableId) 12
2965cdef cudaError_t _cudaGetKernel(cudaKernel_t* kernelPtr, const void* entryFuncAddr) except ?cudaErrorCallRequiresNewerDriver nogil:
2966 cdef bint usePTDS = cudaPythonInit()
2967 if usePTDS:
2968 return ptds._cudaGetKernel(kernelPtr, entryFuncAddr) 12
2969 return _static_cudaGetKernel(kernelPtr, entryFuncAddr) 12
2972cdef cudaError_t _cudaProfilerStart() except ?cudaErrorCallRequiresNewerDriver nogil:
2973 cdef bint usePTDS = cudaPythonInit() 12
2974 if usePTDS: 1a2
2975 return ptds._cudaProfilerStart() 2gbhb
2976 return _static_cudaProfilerStart() 2gbhb2
2979cdef cudaError_t _cudaProfilerStop() except ?cudaErrorCallRequiresNewerDriver nogil:
2980 cdef bint usePTDS = cudaPythonInit() 12
2981 if usePTDS: 1a2
2982 return ptds._cudaProfilerStop()
2983 return _static_cudaProfilerStop() 12
2986cdef cudaError_t _cudaGetDeviceProperties(cudaDeviceProp* prop, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2987 cdef bint usePTDS = cudaPythonInit() 2gbhb
2988 if usePTDS: 2a gbhb
2989 return ptds._cudaGetDeviceProperties(prop, device)
2990 return _static_cudaGetDeviceProperties(prop, device) 2gbhb
2993cdef cudaError_t _cudaDeviceGetHostAtomicCapabilities(unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2994 cdef bint usePTDS = cudaPythonInit()
2995 if usePTDS:
2996 return ptds._cudaDeviceGetHostAtomicCapabilities(capabilities, operations, count, device) 1C
2997 return _static_cudaDeviceGetHostAtomicCapabilities(capabilities, operations, count, device) 1C
3000cdef cudaError_t _cudaDeviceGetP2PAtomicCapabilities(unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int srcDevice, int dstDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
3001 cdef bint usePTDS = cudaPythonInit()
3002 if usePTDS:
3003 return ptds._cudaDeviceGetP2PAtomicCapabilities(capabilities, operations, count, srcDevice, dstDevice)
3004 return _static_cudaDeviceGetP2PAtomicCapabilities(capabilities, operations, count, srcDevice, dstDevice)
3007cdef cudaError_t _cudaStreamGetCaptureInfo(cudaStream_t stream, cudaStreamCaptureStatus* captureStatus_out, unsigned long long* id_out, cudaGraph_t* graph_out, const cudaGraphNode_t** dependencies_out, const cudaGraphEdgeData** edgeData_out, size_t* numDependencies_out) except ?cudaErrorCallRequiresNewerDriver nogil:
3008 cdef bint usePTDS = cudaPythonInit() 1C
3009 if usePTDS: 1aC
3010 return ptds._cudaStreamGetCaptureInfo(stream, captureStatus_out, id_out, graph_out, dependencies_out, edgeData_out, numDependencies_out)
3011 return _static_cudaStreamGetCaptureInfo(stream, captureStatus_out, id_out, graph_out, dependencies_out, edgeData_out, numDependencies_out) 1C
3014cdef cudaError_t _cudaSignalExternalSemaphoresAsync(const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreSignalParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3015 cdef bint usePTDS = cudaPythonInit()
3016 if usePTDS:
3017 return ptds._cudaSignalExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3018 return _static_cudaSignalExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3021cdef cudaError_t _cudaWaitExternalSemaphoresAsync(const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreWaitParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3022 cdef bint usePTDS = cudaPythonInit()
3023 if usePTDS:
3024 return ptds._cudaWaitExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3025 return _static_cudaWaitExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3028cdef cudaError_t _cudaMemPrefetchBatchAsync(void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3029 cdef bint usePTDS = cudaPythonInit()
3030 if usePTDS:
3031 return ptds._cudaMemPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3032 return _static_cudaMemPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3035cdef cudaError_t _cudaMemDiscardBatchAsync(void** dptrs, size_t* sizes, size_t count, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3036 cdef bint usePTDS = cudaPythonInit()
3037 if usePTDS:
3038 return ptds._cudaMemDiscardBatchAsync(dptrs, sizes, count, flags, stream)
3039 return _static_cudaMemDiscardBatchAsync(dptrs, sizes, count, flags, stream)
3042cdef cudaError_t _cudaMemDiscardAndPrefetchBatchAsync(void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3043 cdef bint usePTDS = cudaPythonInit()
3044 if usePTDS:
3045 return ptds._cudaMemDiscardAndPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3046 return _static_cudaMemDiscardAndPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3049cdef cudaError_t _cudaMemGetDefaultMemPool(cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3050 cdef bint usePTDS = cudaPythonInit()
3051 if usePTDS:
3052 return ptds._cudaMemGetDefaultMemPool(memPool, location, type)
3053 return _static_cudaMemGetDefaultMemPool(memPool, location, type)
3056cdef cudaError_t _cudaMemGetMemPool(cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3057 cdef bint usePTDS = cudaPythonInit()
3058 if usePTDS:
3059 return ptds._cudaMemGetMemPool(memPool, location, type)
3060 return _static_cudaMemGetMemPool(memPool, location, type)
3063cdef cudaError_t _cudaMemSetMemPool(cudaMemLocation* location, cudaMemAllocationType type, cudaMemPool_t memPool) except ?cudaErrorCallRequiresNewerDriver nogil:
3064 cdef bint usePTDS = cudaPythonInit()
3065 if usePTDS:
3066 return ptds._cudaMemSetMemPool(location, type, memPool)
3067 return _static_cudaMemSetMemPool(location, type, memPool)
3070cdef cudaError_t _cudaLogsRegisterCallback(cudaLogsCallback_t callbackFunc, void* userData, cudaLogsCallbackHandle* callback_out) except ?cudaErrorCallRequiresNewerDriver nogil:
3071 cdef bint usePTDS = cudaPythonInit()
3072 if usePTDS:
3073 return ptds._cudaLogsRegisterCallback(callbackFunc, userData, callback_out)
3074 return _static_cudaLogsRegisterCallback(callbackFunc, userData, callback_out)
3077cdef cudaError_t _cudaLogsUnregisterCallback(cudaLogsCallbackHandle callback) except ?cudaErrorCallRequiresNewerDriver nogil:
3078 cdef bint usePTDS = cudaPythonInit()
3079 if usePTDS:
3080 return ptds._cudaLogsUnregisterCallback(callback)
3081 return _static_cudaLogsUnregisterCallback(callback)
3084cdef cudaError_t _cudaLogsCurrent(cudaLogIterator* iterator_out, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3085 cdef bint usePTDS = cudaPythonInit()
3086 if usePTDS:
3087 return ptds._cudaLogsCurrent(iterator_out, flags)
3088 return _static_cudaLogsCurrent(iterator_out, flags)
3091cdef cudaError_t _cudaLogsDumpToFile(cudaLogIterator* iterator, const char* pathToFile, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3092 cdef bint usePTDS = cudaPythonInit()
3093 if usePTDS:
3094 return ptds._cudaLogsDumpToFile(iterator, pathToFile, flags) 1n
3095 return _static_cudaLogsDumpToFile(iterator, pathToFile, flags) 1n
3098cdef cudaError_t _cudaLogsDumpToMemory(cudaLogIterator* iterator, char* buffer, size_t* size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3099 cdef bint usePTDS = cudaPythonInit()
3100 if usePTDS:
3101 return ptds._cudaLogsDumpToMemory(iterator, buffer, size, flags) 1v
3102 return _static_cudaLogsDumpToMemory(iterator, buffer, size, flags) 1v
3105cdef cudaError_t _cudaGraphNodeGetContainingGraph(cudaGraphNode_t hNode, cudaGraph_t* phGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
3106 cdef bint usePTDS = cudaPythonInit() 1n
3107 if usePTDS: 1an
3108 return ptds._cudaGraphNodeGetContainingGraph(hNode, phGraph) 1w
3109 return _static_cudaGraphNodeGetContainingGraph(hNode, phGraph) 1nw
3112cdef cudaError_t _cudaGraphNodeGetLocalId(cudaGraphNode_t hNode, unsigned int* nodeId) except ?cudaErrorCallRequiresNewerDriver nogil:
3113 cdef bint usePTDS = cudaPythonInit() 1v
3114 if usePTDS: 1av
3115 return ptds._cudaGraphNodeGetLocalId(hNode, nodeId) 1J
3116 return _static_cudaGraphNodeGetLocalId(hNode, nodeId) 1Jv
3119cdef cudaError_t _cudaGraphNodeGetToolsId(cudaGraphNode_t hNode, unsigned long long* toolsNodeId) except ?cudaErrorCallRequiresNewerDriver nogil:
3120 cdef bint usePTDS = cudaPythonInit() 1w
3121 if usePTDS: 1aw
3122 return ptds._cudaGraphNodeGetToolsId(hNode, toolsNodeId) 1e
3123 return _static_cudaGraphNodeGetToolsId(hNode, toolsNodeId) 1ew
3126cdef cudaError_t _cudaGraphGetId(cudaGraph_t hGraph, unsigned int* graphID) except ?cudaErrorCallRequiresNewerDriver nogil:
3127 cdef bint usePTDS = cudaPythonInit() 1J
3128 if usePTDS: 1aJ
3129 return ptds._cudaGraphGetId(hGraph, graphID) 1u
3130 return _static_cudaGraphGetId(hGraph, graphID) 1uJ
3133cdef cudaError_t _cudaGraphExecGetId(cudaGraphExec_t hGraphExec, unsigned int* graphID) except ?cudaErrorCallRequiresNewerDriver nogil:
3134 cdef bint usePTDS = cudaPythonInit() 1e
3135 if usePTDS: 1ae
3136 return ptds._cudaGraphExecGetId(hGraphExec, graphID) 2W X } ebs
3137 return _static_cudaGraphExecGetId(hGraphExec, graphID) 2W X } ebe s
3140cdef cudaError_t _cudaGraphConditionalHandleCreate_v2(cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, cudaExecutionContext_t ctx, unsigned int defaultLaunchValue, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3141 cdef bint usePTDS = cudaPythonInit() 1u
3142 if usePTDS: 1au
3143 return ptds._cudaGraphConditionalHandleCreate_v2(pHandle_out, graph, ctx, defaultLaunchValue, flags) 1X
3144 return _static_cudaGraphConditionalHandleCreate_v2(pHandle_out, graph, ctx, defaultLaunchValue, flags) 1Xu
3147cdef cudaError_t _cudaDeviceGetDevResource(int device, cudaDevResource* resource, cudaDevResourceType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3148 cdef bint usePTDS = cudaPythonInit() 2W X } ebs
3149 if usePTDS: 2a W X } ebs
3150 return ptds._cudaDeviceGetDevResource(device, resource, type) 1}
3151 return _static_cudaDeviceGetDevResource(device, resource, type) 2W X } ebs
3154cdef cudaError_t _cudaDevSmResourceSplitByCount(cudaDevResource* result, unsigned int* nbGroups, const cudaDevResource* input, cudaDevResource* remaining, unsigned int flags, unsigned int minCount) except ?cudaErrorCallRequiresNewerDriver nogil:
3155 cdef bint usePTDS = cudaPythonInit() 1X
3156 if usePTDS: 1aX
3157 return ptds._cudaDevSmResourceSplitByCount(result, nbGroups, input, remaining, flags, minCount) 1Ws
3158 return _static_cudaDevSmResourceSplitByCount(result, nbGroups, input, remaining, flags, minCount) 1WXs
3161cdef cudaError_t _cudaDevSmResourceSplit(cudaDevResource* result, unsigned int nbGroups, const cudaDevResource* input, cudaDevResource* remainder, unsigned int flags, cudaDevSmResourceGroupParams* groupParams) except ?cudaErrorCallRequiresNewerDriver nogil:
3162 cdef bint usePTDS = cudaPythonInit() 1}
3163 if usePTDS: 1a}
3164 return ptds._cudaDevSmResourceSplit(result, nbGroups, input, remainder, flags, groupParams) 1s
3165 return _static_cudaDevSmResourceSplit(result, nbGroups, input, remainder, flags, groupParams) 1}s
3168cdef cudaError_t _cudaDevResourceGenerateDesc(cudaDevResourceDesc_t* phDesc, cudaDevResource* resources, unsigned int nbResources) except ?cudaErrorCallRequiresNewerDriver nogil:
3169 cdef bint usePTDS = cudaPythonInit() 1Ws
3170 if usePTDS: 1aWs
3171 return ptds._cudaDevResourceGenerateDesc(phDesc, resources, nbResources) 1s
3172 return _static_cudaDevResourceGenerateDesc(phDesc, resources, nbResources) 1Ws
3175cdef cudaError_t _cudaGreenCtxCreate(cudaExecutionContext_t* phCtx, cudaDevResourceDesc_t desc, int device, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3176 cdef bint usePTDS = cudaPythonInit() 1s
3177 if usePTDS: 1as
3178 return ptds._cudaGreenCtxCreate(phCtx, desc, device, flags) 1Y
3179 return _static_cudaGreenCtxCreate(phCtx, desc, device, flags) 1Ys
3182cdef cudaError_t _cudaExecutionCtxDestroy(cudaExecutionContext_t ctx) except ?cudaErrorCallRequiresNewerDriver nogil:
3183 cdef bint usePTDS = cudaPythonInit() 1s
3184 if usePTDS: 1as
3185 return ptds._cudaExecutionCtxDestroy(ctx) 1Z
3186 return _static_cudaExecutionCtxDestroy(ctx) 1Zs
3189cdef cudaError_t _cudaExecutionCtxGetDevResource(cudaExecutionContext_t ctx, cudaDevResource* resource, cudaDevResourceType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3190 cdef bint usePTDS = cudaPythonInit() 1Y
3191 if usePTDS: 1aY
3192 return ptds._cudaExecutionCtxGetDevResource(ctx, resource, type) 10
3193 return _static_cudaExecutionCtxGetDevResource(ctx, resource, type) 1Y0
3196cdef cudaError_t _cudaExecutionCtxGetDevice(int* device, cudaExecutionContext_t ctx) except ?cudaErrorCallRequiresNewerDriver nogil:
3197 cdef bint usePTDS = cudaPythonInit() 1Z
3198 if usePTDS: 1aZ
3199 return ptds._cudaExecutionCtxGetDevice(device, ctx) 1I
3200 return _static_cudaExecutionCtxGetDevice(device, ctx) 1ZI
3203cdef cudaError_t _cudaExecutionCtxGetId(cudaExecutionContext_t ctx, unsigned long long* ctxId) except ?cudaErrorCallRequiresNewerDriver nogil:
3204 cdef bint usePTDS = cudaPythonInit() 10
3205 if usePTDS: 1a0
3206 return ptds._cudaExecutionCtxGetId(ctx, ctxId)
3207 return _static_cudaExecutionCtxGetId(ctx, ctxId) 10
3210cdef cudaError_t _cudaExecutionCtxStreamCreate(cudaStream_t* phStream, cudaExecutionContext_t ctx, unsigned int flags, int priority) except ?cudaErrorCallRequiresNewerDriver nogil:
3211 cdef bint usePTDS = cudaPythonInit() 1I
3212 if usePTDS: 1aI
3213 return ptds._cudaExecutionCtxStreamCreate(phStream, ctx, flags, priority) 1K
3214 return _static_cudaExecutionCtxStreamCreate(phStream, ctx, flags, priority) 1IK
3217cdef cudaError_t _cudaExecutionCtxSynchronize(cudaExecutionContext_t ctx) except ?cudaErrorCallRequiresNewerDriver nogil:
3218 cdef bint usePTDS = cudaPythonInit()
3219 if usePTDS:
3220 return ptds._cudaExecutionCtxSynchronize(ctx)
3221 return _static_cudaExecutionCtxSynchronize(ctx)
3224cdef cudaError_t _cudaStreamGetDevResource(cudaStream_t hStream, cudaDevResource* resource, cudaDevResourceType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3225 cdef bint usePTDS = cudaPythonInit() 1K
3226 if usePTDS: 1aK
3227 return ptds._cudaStreamGetDevResource(hStream, resource, type)
3228 return _static_cudaStreamGetDevResource(hStream, resource, type) 1K
3231cdef cudaError_t _cudaExecutionCtxRecordEvent(cudaExecutionContext_t ctx, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
3232 cdef bint usePTDS = cudaPythonInit()
3233 if usePTDS:
3234 return ptds._cudaExecutionCtxRecordEvent(ctx, event) 1YZ0Iu
3235 return _static_cudaExecutionCtxRecordEvent(ctx, event) 1YZ0Iu
3238cdef cudaError_t _cudaExecutionCtxWaitEvent(cudaExecutionContext_t ctx, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
3239 cdef bint usePTDS = cudaPythonInit()
3240 if usePTDS:
3241 return ptds._cudaExecutionCtxWaitEvent(ctx, event)
3242 return _static_cudaExecutionCtxWaitEvent(ctx, event)
3245cdef cudaError_t _cudaDeviceGetExecutionCtx(cudaExecutionContext_t* ctx, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
3246 cdef bint usePTDS = cudaPythonInit() 1YZ0Iu
3247 if usePTDS: 1aYZ0Iu
3248 return ptds._cudaDeviceGetExecutionCtx(ctx, device)
3249 return _static_cudaDeviceGetExecutionCtx(ctx, device) 1YZ0Iu
3252cdef cudaError_t _cudaFuncGetParamCount(const void* func, size_t* paramCount) except ?cudaErrorCallRequiresNewerDriver nogil:
3253 cdef bint usePTDS = cudaPythonInit()
3254 if usePTDS:
3255 return ptds._cudaFuncGetParamCount(func, paramCount)
3256 return _static_cudaFuncGetParamCount(func, paramCount)
3259cdef cudaError_t _cudaLaunchHostFunc_v2(cudaStream_t stream, cudaHostFn_t fn, void* userData, unsigned int syncMode) except ?cudaErrorCallRequiresNewerDriver nogil:
3260 cdef bint usePTDS = cudaPythonInit()
3261 if usePTDS:
3262 return ptds._cudaLaunchHostFunc_v2(stream, fn, userData, syncMode)
3263 return _static_cudaLaunchHostFunc_v2(stream, fn, userData, syncMode)
3266cdef cudaError_t _cudaMemcpyWithAttributesAsync(void* dst, const void* src, size_t size, cudaMemcpyAttributes* attr, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3267 cdef bint usePTDS = cudaPythonInit()
3268 if usePTDS:
3269 return ptds._cudaMemcpyWithAttributesAsync(dst, src, size, attr, stream)
3270 return _static_cudaMemcpyWithAttributesAsync(dst, src, size, attr, stream)
3273cdef cudaError_t _cudaMemcpy3DWithAttributesAsync(cudaMemcpy3DBatchOp* op, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3274 cdef bint usePTDS = cudaPythonInit()
3275 if usePTDS:
3276 return ptds._cudaMemcpy3DWithAttributesAsync(op, flags, stream)
3277 return _static_cudaMemcpy3DWithAttributesAsync(op, flags, stream)
3280cdef cudaError_t _cudaGraphNodeGetParams(cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
3281 cdef bint usePTDS = cudaPythonInit()
3282 if usePTDS:
3283 return ptds._cudaGraphNodeGetParams(node, nodeParams)
3284 return _static_cudaGraphNodeGetParams(node, nodeParams)
3287cdef cudaError_t _cudaStreamBeginRecaptureToGraph(cudaStream_t stream, cudaStreamCaptureMode mode, cudaGraph_t graph, cudaGraphRecaptureCallbackData* callbackData) except ?cudaErrorCallRequiresNewerDriver nogil:
3288 cdef bint usePTDS = cudaPythonInit()
3289 if usePTDS:
3290 return ptds._cudaStreamBeginRecaptureToGraph(stream, mode, graph, callbackData)
3291 return _static_cudaStreamBeginRecaptureToGraph(stream, mode, graph, callbackData)
3294cdef cudaError_t _cudaMemGetLocationInfo(void* devPtr, size_t size, size_t summaryGranularity, size_t samplingGranularity, cudaMemLocation* location_out) except ?cudaErrorCallRequiresNewerDriver nogil:
3295 cdef bint usePTDS = cudaPythonInit()
3296 if usePTDS:
3297 return ptds._cudaMemGetLocationInfo(devPtr, size, summaryGranularity, samplingGranularity, location_out)
3298 return _static_cudaMemGetLocationInfo(devPtr, size, summaryGranularity, samplingGranularity, location_out)